@@ -21,8 +21,6 @@ AboutPlugins::AboutPlugins( Config *_config, QWidget* parent, Qt::WFlags f )
     setButtons( KDialog::Close );
     setButtonFocus( KDialog::Close );
 
-    resize( 500, 300 );
-
     QWidget *widget = new QWidget( this );
     setMainWidget( widget );
     QHBoxLayout *box = new QHBoxLayout( widget );
@@ -46,6 +44,15 @@ AboutPlugins::AboutPlugins( Config *_config, QWidget* parent, Qt::WFlags f )
     pluginNames.sort();
     pluginsList->addItems( pluginNames );
 
+    pluginNames.clear();
+    QList<FilterPlugin*> filterPlugins = config->pluginLoader()->getAllFilterPlugins();
+    for( int i=0; i<filterPlugins.count(); i++ )
+    {
+        pluginNames += filterPlugins.at(i)->name();
+    }
+    pluginNames.sort();
+    pluginsList->addItems( pluginNames );
+
     pluginNames.clear();
     QList<ReplayGainPlugin*> replaygainPlugins = config->pluginLoader()->getAllReplayGainPlugins();
     for( int i=0; i<replaygainPlugins.count(); i++ )
@@ -94,10 +101,19 @@ AboutPlugins::AboutPlugins( Config *_config, QWidget* parent, Qt::WFlags f )
     {
         currentPluginChanged( currentItem->text() );
     }
+
+    setInitialSize( QSize(500,300) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "AboutPlugins" );
+    restoreDialogSize( group );
 }
 
 AboutPlugins::~AboutPlugins()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "AboutPlugins" );
+    saveDialogSize( group );
+}
 
 void AboutPlugins::currentPluginChanged( const QString& pluginName )
 {
@@ -134,16 +150,51 @@ void AboutPlugins::currentPluginChanged( const QString& pluginName )
         CodecPlugin *codecPlugin = (CodecPlugin*)currentPlugin;
 
         QStringList codecsString;
-        QMap<QString,bool> encodeCodecs;
-        QMap<QString,bool> decodeCodecs;
+        QMap<QString,int> encodeCodecs;
+        QMap<QString,int> decodeCodecs;
         QList<ConversionPipeTrunk> codecTable = codecPlugin->codecTable();
         for( int i=0; i<codecTable.count(); i++ )
         {
-            if( codecTable.at(i).codecTo != "wav" && ( !encodeCodecs.contains(codecTable.at(i).codecTo) || !encodeCodecs[codecTable.at(i).codecTo] ) )
-                encodeCodecs[codecTable.at(i).codecTo] = codecTable.at(i).enabled;
+            if( codecTable.at(i).codecTo != "wav" )
+                encodeCodecs[codecTable.at(i).codecTo] += codecTable.at(i).enabled;
 
-            if( codecTable.at(i).codecFrom != "wav" && ( !decodeCodecs.contains(codecTable.at(i).codecFrom) || !decodeCodecs[codecTable.at(i).codecFrom] ) )
-                decodeCodecs[codecTable.at(i).codecFrom] = codecTable.at(i).enabled;
+            if( codecTable.at(i).codecFrom != "wav" )
+                decodeCodecs[codecTable.at(i).codecFrom] += codecTable.at(i).enabled;
+        }
+        codecsString += i18n("Supported codecs:");
+        QStringList list;
+        for( int i=0; i<encodeCodecs.count(); i++ )
+        {
+            const QString codecName = encodeCodecs.keys().at(i);
+            problemInfos["encode-"+codecName] = i18n("Currently deactivated.") + "\n\n" + config->pluginLoader()->pluginEncodeProblems( pluginName, codecName );
+            list += encodeCodecs.values().at(i) ? "<span style=\"color:green\">" + codecName + "</span>" : "<a style=\"color:red\" href=\"encode-"+codecName+"\">" + codecName + "</a>";
+        }
+        codecsString += i18n("Encode: %1",list.join(", "));
+        list.clear();
+        for( int i=0; i<decodeCodecs.count(); i++ )
+        {
+            const QString codecName = decodeCodecs.keys().at(i);
+            problemInfos["decode-"+codecName] = i18n("Currently deactivated.") + "\n\n" + config->pluginLoader()->pluginDecodeProblems( pluginName, codecName );
+            list += decodeCodecs.values().at(i) ? "<span style=\"color:green\">" + codecName + "</span>" : "<a style=\"color:red\" href=\"decode-"+codecName+"\">" + codecName + "</a>";
+        }
+        codecsString += i18n("Decode: %1",list.join(", "));
+        info += codecsString.join("<br>");
+    }
+    else if( currentPlugin->type() == "filter" )
+    {
+        CodecPlugin *codecPlugin = (CodecPlugin*)currentPlugin;
+
+        QStringList codecsString;
+        QMap<QString,int> encodeCodecs;
+        QMap<QString,int> decodeCodecs;
+        QList<ConversionPipeTrunk> codecTable = codecPlugin->codecTable();
+        for( int i=0; i<codecTable.count(); i++ )
+        {
+            if( codecTable.at(i).codecTo != "wav" )
+                encodeCodecs[codecTable.at(i).codecTo] += codecTable.at(i).enabled;
+
+            if( codecTable.at(i).codecFrom != "wav" )
+                decodeCodecs[codecTable.at(i).codecFrom] += codecTable.at(i).enabled;
         }
         codecsString += i18n("Supported codecs:");
         QStringList list;
