@@ -34,14 +34,15 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~ConfigAdvancedPage();
+    ~ConfigAdvancedPage();
 
 private:
     KComboBox *cPreferredOggVorbisExtension;
-    KIntSpinBox *iUpdateDelay;
+    KComboBox *cPreferredVorbisCommentCommentTag;
+    KComboBox *cPreferredVorbisCommentTrackTotalTag;
+    KComboBox *cPreferredVorbisCommentDiscTotalTag;
     QCheckBox *cUseVFATNames;
     QCheckBox *cWriteLogFiles;
-    QCheckBox *cRemoveFailedFiles;
     QCheckBox *cUseSharedMemoryForTempFiles;
     KIntSpinBox *iMaxSizeForSharedMemoryTempFiles;
     QCheckBox *cUsePipes;
@@ -52,6 +53,9 @@ public slots:
     void resetDefaults();
     void saveSettings();
 
+private slots:
+    void somethingChanged();
+
 };
 
 #endif
