@@ -16,6 +16,9 @@
 
 class Config;
 class QRadioButton;
+class QLabel;
+class QAbstractButton;
+class KLineEdit;
 
 /**
 	@author Daniel Faust <hessijames@gmail.com>
@@ -32,19 +35,29 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~ConfigCoverArtPage();
+    ~ConfigCoverArtPage();
 
 private:
     QRadioButton *rWriteCoversAlways;
     QRadioButton *rWriteCoversAuto;
     QRadioButton *rWriteCoversNever;
 
+    QLabel       *lWriteCoverName;
+    QRadioButton *rWriteCoverNameTitle;
+    QRadioButton *rWriteCoverNameDefault;
+    QLabel       *lWriteCoverNameDefaultLabel;
+    KLineEdit    *lWriteCoverNameDefaultEdit;
+
 //     QCheckBox *cCopyCover;
 //     QCheckBox *cEmbedCover;
 //     QListView *lCoverList;
 
     Config *config;
 
+private slots:
+    void somethingChanged();
+    void writeCoversChanged( QAbstractButton *button );
+
 public slots:
     void resetDefaults();
     void saveSettings();
