@@ -27,7 +27,12 @@ ConfigDialog::ConfigDialog( Config *_config, QWidget *parent/*, Page startPage*/
 {
     setButtons( KDialog::Help | KDialog::Default | KDialog::Apply | KDialog::Ok | KDialog::Cancel );
     setCaption( i18n("Settings") );
-    configChanged(false);
+
+    generalPageChanged = false;
+    advancedlPageChanged = false;
+    coverArtPageChanged = false;
+    backendsPageChanged = false;
+    button(KDialog::Apply)->setEnabled( false );
 
     connect( this, SIGNAL(applyClicked()), this, SLOT(applyClicked()) );
     connect( this, SIGNAL(okClicked()), this, SLOT(okClicked()) );
@@ -35,26 +40,28 @@ ConfigDialog::ConfigDialog( Config *_config, QWidget *parent/*, Page startPage*/
 
     configGeneralPage = new ConfigGeneralPage( config, this );
     generalPage = addPage( (QWidget*)configGeneralPage, i18n("General") );
+    generalPage->setHeader( "" );
     generalPage->setIcon( KIcon("configure") );
     connect( configGeneralPage, SIGNAL(configChanged(bool)), this, SLOT(configChanged(bool)) );
 
     configAdvancedPage = new ConfigAdvancedPage( config, this );
     advancedPage = addPage( (QWidget*)configAdvancedPage, i18n("Advanced") );
+    advancedPage->setHeader( "" );
     advancedPage->setIcon( KIcon("preferences-desktop-gaming") );
     connect( configAdvancedPage, SIGNAL(configChanged(bool)), this, SLOT(configChanged(bool)) );
 
     configCoverArtPage = new ConfigCoverArtPage( config, this );
     coverArtPage = addPage( (QWidget*)configCoverArtPage, i18n("Cover art") );
+    coverArtPage->setHeader( "" );
     coverArtPage->setIcon( KIcon("image-x-generic") );
     connect( configCoverArtPage, SIGNAL(configChanged(bool)), this, SLOT(configChanged(bool)) );
 
     configBackendsPage = new ConfigBackendsPage( config, this );
     backendsPage = addPage( (QWidget*)configBackendsPage, i18n("Backends") );
+    backendsPage->setHeader( "" );
     backendsPage->setIcon( KIcon("applications-system") );
     connect( configBackendsPage, SIGNAL(configChanged(bool)), this, SLOT(configChanged(bool)) );
 
-    connect( this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), this, SLOT(pageChanged(KPageWidgetItem*,KPageWidgetItem*)) );
-
     lastUseVFATNames = config->data.general.useVFATNames;
     lastConflictHandling = (int)config->data.general.conflictHandling;
 }
@@ -62,22 +69,39 @@ ConfigDialog::ConfigDialog( Config *_config, QWidget *parent/*, Page startPage*/
 ConfigDialog::~ConfigDialog()
 {}
 
-void ConfigDialog::pageChanged( KPageWidgetItem *current, KPageWidgetItem *before )
-{
-    Q_UNUSED(before)
-
-    button(KDialog::Default)->setEnabled( current != backendsPage );
-}
-
 void ConfigDialog::configChanged( bool state )
 {
-    button(KDialog::Apply)->setEnabled(state);
+    if( QObject::sender() == configGeneralPage )
+    {
+        generalPageChanged = state;
+    }
+    else if( QObject::sender() == configAdvancedPage )
+    {
+        advancedlPageChanged = state;
+    }
+    else if( QObject::sender() == configCoverArtPage )
+    {
+        coverArtPageChanged = state;
+    }
+    else if( QObject::sender() == configBackendsPage )
+    {
+        backendsPageChanged = state;
+    }
+
+    const bool changed = ( generalPageChanged || advancedlPageChanged || coverArtPageChanged || backendsPageChanged );
+
+    button(KDialog::Apply)->setEnabled( changed );
 }
 
 void ConfigDialog::applyClicked()
 {
     okClicked();
-    configChanged(false);
+
+    generalPageChanged = false;
+    advancedlPageChanged = false;
+    coverArtPageChanged = false;
+    backendsPageChanged = false;
+    button(KDialog::Apply)->setEnabled( false );
 }
 
 void ConfigDialog::okClicked()
