@@ -1,7 +1,7 @@
 //
 // C++ Interface: configpagebase
 //
-// Description: 
+// Description:
 //
 //
 // Author: Daniel Faust <hessijames@gmail.com>, (C) 2007
@@ -16,6 +16,12 @@
 
 class Config;
 
+#define ConfigDialogOffset 20
+
+#define ConfigDialogSpacingSmall 5
+#define ConfigDialogSpacingMedium 10
+#define ConfigDialogSpacingBig 20
+
 /**
 	@author Daniel Faust <hessijames@gmail.com>
 */
@@ -23,14 +29,7 @@ class ConfigPageBase : public QWidget
 {
     Q_OBJECT
 public:
-    /**
-     * Constructor
-     */
     ConfigPageBase( QWidget *parent=0 );
-
-    /**
-     * Destructor
-     */
     virtual ~ConfigPageBase();
 
 public slots:
