@@ -3,24 +3,16 @@
 #include "codecwidget.h"
 
 
-//
-// class CodecPluginItem
-//
-////////////////////
-
 CodecPluginItem::CodecPluginItem( QObject *parent )
     : BackendPluginItem( parent )
-{}
+{
+    data.length = 0;
+}
 
 CodecPluginItem::~CodecPluginItem()
 {}
 
 
-//
-// class CodecPlugin
-//
-////////////////////
-
 CodecPlugin::CodecPlugin( QObject *parent )
     : BackendPlugin( parent )
 {
@@ -35,7 +27,7 @@ QString CodecPlugin::type()
     return "codec";
 }
 
-QWidget *CodecPlugin::deleteCodecWidget( QWidget *codecWidget )
+CodecWidget *CodecPlugin::deleteCodecWidget( CodecWidget *codecWidget )
 {
     if( !codecWidget )
         return 0;
@@ -43,16 +35,16 @@ QWidget *CodecPlugin::deleteCodecWidget( QWidget *codecWidget )
     if( lastUsedConversionOptions )
         delete lastUsedConversionOptions;
 
-    lastUsedConversionOptions = qobject_cast<CodecWidget*>(codecWidget)->currentConversionOptions();
+    lastUsedConversionOptions = codecWidget->currentConversionOptions();
     delete codecWidget;
 
     return 0;
 }
 
-ConversionOptions *CodecPlugin::conversionOptionsFromXml( QDomElement conversionOptions )
+ConversionOptions *CodecPlugin::conversionOptionsFromXml( QDomElement conversionOptions, QList<QDomElement> *filterOptionsElements )
 {
     ConversionOptions *options = new ConversionOptions();
-    options->fromXml( conversionOptions );
+    options->fromXml( conversionOptions, filterOptionsElements );
     return options;
 }
 
