@@ -10,7 +10,6 @@
 #include "codecproblems.h"
 
 #include <KApplication>
-#include <KLocale>
 #include <KIcon>
 #include <KAction>
 // #include <kactioncollection.h>
@@ -127,34 +126,43 @@ void FileList::dropEvent( QDropEvent *event )
     QMap< QString, QList<QStringList> > problems;
     QString fileName;
 
+    const bool canDecodeAac = config->pluginLoader()->canDecode( "m4a/aac" );
+    const bool canDecodeAlac = config->pluginLoader()->canDecode( "m4a/alac" );
+    const bool checkM4a = ( !canDecodeAac || !canDecodeAlac ) && canDecodeAac != canDecodeAlac;
+
     for( int i=0; i<q_urls.size(); i++ )
     {
-        QString codecName = config->pluginLoader()->getCodecFromFile( q_urls.at(i) );
+        QString mimeType;
+        QString codecName = config->pluginLoader()->getCodecFromFile( q_urls.at(i), &mimeType, checkM4a );
 
-        if( codecName == "inode/directory" || config->pluginLoader()->canDecode(codecName,&errorList) )
+        if( mimeType == "inode/directory" || config->pluginLoader()->canDecode(codecName,&errorList) )
         {
             k_urls += q_urls.at(i);
         }
         else
         {
-            if( !codecName.startsWith("audio") && !codecName.startsWith("video") && !codecName.startsWith("application") )
+            if( codecName.isEmpty() && !mimeType.startsWith("audio") && !mimeType.startsWith("video") && !mimeType.startsWith("application") )
                 continue;
 
-            if( codecName == "application/x-ole-storage" || // Thumbs.db
-                codecName == "application/x-wine-extension-ini" ||
-                codecName == "application/x-cue" ||
-                codecName == "application/x-k3b" ||
-                codecName == "application/pdf" ||
-                codecName == "application/x-trash" ||
-                codecName.startsWith("application/vnd.oasis.opendocument") ||
-                codecName.startsWith("application/vnd.openxmlformats-officedocument") ||
-                codecName.startsWith("application/vnd.sun.xml")
+            if( mimeType == "application/x-ole-storage" || // Thumbs.db
+                mimeType == "application/x-wine-extension-ini" ||
+                mimeType == "application/x-cue" ||
+                mimeType == "application/x-k3b" ||
+                mimeType == "application/pdf" ||
+                mimeType == "application/x-trash" ||
+                mimeType.startsWith("application/vnd.oasis.opendocument") ||
+                mimeType.startsWith("application/vnd.openxmlformats-officedocument") ||
+                mimeType.startsWith("application/vnd.sun.xml")
             )
                 continue;
 
             fileName = KUrl(q_urls.at(i)).pathOrUrl();
+
+            if( codecName.isEmpty() )
+                codecName = mimeType;
             if( codecName.isEmpty() )
                 codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
             if( problems.value(codecName).count() < 2 )
             {
                 problems[codecName] += QStringList();
@@ -219,6 +227,9 @@ void FileList::dropEvent( QDropEvent *event )
 
     if( k_urls.count() > 0 )
     {
+        ConversionOptions *conversionOptions = config->data.profiles.value("soundkonverter_last_used");
+        if( conversionOptions )
+            optionsLayer->setCurrentConversionOptions( conversionOptions );
         optionsLayer->addUrls( k_urls );
         optionsLayer->fadeIn();
     }
@@ -237,14 +248,38 @@ void FileList::resizeEvent( QResizeEvent *event )
     setColumnWidth( Column_Quality, 120 );
 }
 
-int FileList::listDir( const QString& directory, const QStringList& filter, bool recursive, int conversionOptionsId, bool fast, int count )
+int FileList::countDir( const QString& directory, bool recursive, int count )
 {
-//     debug
-//     if( fast )
-//         logger->log( 1000, "@listDir fast: " + directory );
-//     else
-//         logger->log( 1000, "@listDir: " + directory );
+    QDir dir( directory );
+    dir.setFilter( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+    dir.setSorting( QDir::Unsorted );
 
+    count += dir.count();
+
+    if( recursive )
+    {
+        dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+
+        const QStringList list = dir.entryList();
+
+        foreach( const QString fileName, list )
+        {
+            count = countDir( directory + "/" + fileName, recursive, count );
+        }
+    }
+
+    if( tScanStatus.elapsed() > ConfigUpdateDelay * 10 )
+    {
+        pScanStatus->setMaximum( count );
+        kapp->processEvents();
+        tScanStatus.start();
+    }
+
+    return count;
+}
+
+int FileList::listDir( const QString& directory, const QStringList& filter, bool recursive, int conversionOptionsId, int count )
+{
     QString codecName;
 
     QDir dir( directory );
@@ -253,35 +288,34 @@ int FileList::listDir( const QString& directory, const QStringList& filter, bool
 
     const QStringList list = dir.entryList();
 
+    const bool containsAac = filter.contains("m4a/aac");
+    const bool containsAlac = filter.contains("m4a/alac");
+    const bool checkM4a = ( containsAac || containsAlac ) && containsAac != containsAlac;
+
     foreach( const QString fileName, list )
     {
         QFileInfo fileInfo( directory + "/" + fileName );
 
-        if( fileInfo.isDir() && recursive )
+        const bool isDir = fileInfo.isDir(); // NOTE checking for isFile might not work with all file names
+        if( isDir && recursive )
         {
-            count = listDir( directory + "/" + fileName, filter, recursive, conversionOptionsId, fast, count );
+            count = listDir( directory + "/" + fileName, filter, recursive, conversionOptionsId, count );
         }
-        else if( !fileInfo.isDir() ) // NOTE checking for isFile may not work with all file names
+        else if( !isDir )
         {
             count++;
 
-            if( fast )
-            {
-                pScanStatus->setMaximum( count );
-            }
-            else
-            {
-                codecName = config->pluginLoader()->getCodecFromFile( directory + "/" + fileName );
+            codecName = config->pluginLoader()->getCodecFromFile( directory + "/" + fileName, 0, checkM4a );
 
-                if( filter.count() == 0 || filter.contains(codecName) )
-                {
-                    addFiles( KUrl(directory + "/" + fileName), 0, "", codecName, conversionOptionsId );
-                    if( tScanStatus.elapsed() > config->data.general.updateDelay * 10 )
-                    {
-                        pScanStatus->setValue( count );
-                        tScanStatus.start();
-                    }
-                }
+            if( filter.contains(codecName) )
+            {
+                addFiles( KUrl(directory + "/" + fileName), 0, "", codecName, conversionOptionsId );
+            }
+
+            if( tScanStatus.elapsed() > ConfigUpdateDelay * 10 )
+            {
+                pScanStatus->setValue( count );
+                tScanStatus.start();
             }
         }
     }
@@ -289,18 +323,14 @@ int FileList::listDir( const QString& directory, const QStringList& filter, bool
     return count;
 }
 
-void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversionOptions, const QString& command, const QString& _codecName, int conversionOptionsId, FileListItem *after, bool enabled )
+void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversionOptions, const QString& command, const QString& _codecName, int conversionOptionsId )
 {
-    FileListItem *lastListItem;
-    if( !after && !enabled )
-        lastListItem = topLevelItem( topLevelItemCount()-1 );
-    else
-        lastListItem = after;
-
     QString codecName;
     QString filePathName;
     QString device;
 
+    int lastConversionOptionsId = -1;
+
     bool optionsLayerHidden = false; // shouldn't be necessary
 
     if( !conversionOptions && conversionOptionsId == -1 )
@@ -312,36 +342,43 @@ void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversi
     int batchNumber = 0;
     foreach( const KUrl fileName, fileList )
     {
-        QFileInfo fileInfo( fileName.toLocalFile() );
-        if( fileInfo.isDir() )
-        {
-            if( !optionsLayerHidden && QObject::sender() == optionsLayer )
-            {
-                optionsLayerHidden = true;
-                optionsLayer->hide();
-                kapp->processEvents();
-            }
-
-//             debug
-//             logger->log( 1000, "@addFiles: adding dir: " + fileName.toLocalFile() );
-
-            addDir( fileName, true, config->pluginLoader()->formatList(PluginLoader::Decode,PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid)), conversionOptions );
-            continue;
-        }
-
         if( !_codecName.isEmpty() )
         {
             codecName = _codecName;
         }
         else
         {
-            codecName = config->pluginLoader()->getCodecFromFile( fileName );
+            QFileInfo fileInfo( fileName.toLocalFile() );
+            if( fileInfo.isDir() )
+            {
+                if( !optionsLayerHidden && QObject::sender() == optionsLayer )
+                {
+                    optionsLayerHidden = true;
+                    optionsLayer->hide();
+                    kapp->processEvents();
+                }
 
-            if( !config->pluginLoader()->canDecode(codecName) )
+                //             debug
+                //             logger->log( 1000, "@addFiles: adding dir: " + fileName.toLocalFile() );
+
+                addDir( fileName, true, config->pluginLoader()->formatList(PluginLoader::Decode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid)), conversionOptions );
                 continue;
+            }
+            else
+            {
+                const bool canDecodeAac = config->pluginLoader()->canDecode( "m4a/aac" );
+                const bool canDecodeAlac = config->pluginLoader()->canDecode( "m4a/alac" );
+                const bool checkM4a = ( !canDecodeAac || !canDecodeAlac ) && canDecodeAac != canDecodeAlac;
+                codecName = config->pluginLoader()->getCodecFromFile( fileName, 0, checkM4a );
+
+                if( !config->pluginLoader()->canDecode(codecName) )
+                    continue;
+            }
         }
 
-        FileListItem * const newItem = new FileListItem( this, lastListItem );
+//         logger->log( 1000, "adding file: " + fileName.toLocalFile() + ", codec: " + codecName );
+
+        FileListItem * const newItem = new FileListItem( this );
         if( conversionOptionsId == -1 )
         {
             if( batchNumber == 0 )
@@ -350,14 +387,15 @@ void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversi
             }
             else
             {
-                newItem->conversionOptionsId = config->conversionOptionsManager()->increaseReferences( lastListItem->conversionOptionsId );
+                newItem->conversionOptionsId = config->conversionOptionsManager()->increaseReferences( lastConversionOptionsId );
             }
         }
         else
         {
             newItem->conversionOptionsId = config->conversionOptionsManager()->increaseReferences( conversionOptionsId );
         }
-        lastListItem = newItem;
+
+        lastConversionOptionsId = newItem->conversionOptionsId;
         newItem->codecName = codecName;
         newItem->track = -1;
         newItem->url = fileName;
@@ -373,6 +411,7 @@ void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversi
             newItem->length = ( newItem->tags && newItem->tags->length > 0 ) ? newItem->tags->length : 200.0f;
         }
         newItem->notifyCommand = command;
+
         addTopLevelItem( newItem );
         updateItem( newItem );
         emit timeChanged( newItem->length );
@@ -383,16 +422,17 @@ void FileList::addFiles( const KUrl::List& fileList, ConversionOptions *conversi
             kapp->processEvents();
     }
 
-    emit fileCountChanged( topLevelItemCount() );
+    if( !pScanStatus->isVisible() )
+    {
+        emit fileCountChanged( topLevelItemCount() );
+
+        if( queue )
+            convertNextItem();
+    }
 }
 
 void FileList::addDir( const KUrl& directory, bool recursive, const QStringList& codecList, ConversionOptions *conversionOptions )
 {
-//     debug
-//     logger->log( 1000, "@addDir: " + directory.toLocalFile() );
-
-    TimeCount = 0;
-
     if( !conversionOptions )
     {
         logger->log( 1000, "@addDir: No conversion options given" );
@@ -404,21 +444,24 @@ void FileList::addDir( const KUrl& directory, bool recursive, const QStringList&
     pScanStatus->setValue( 0 );
     pScanStatus->setMaximum( 0 );
     pScanStatus->show(); // show the status while scanning the directories
-//     kapp->processEvents();
     tScanStatus.start();
 
-    Time.start();
-    listDir( directory.toLocalFile(), codecList, recursive, conversionOptionsId, true );
+    const int count = countDir( directory.toLocalFile(), recursive );
+
+    pScanStatus->setMaximum( count );
     kapp->processEvents();
+
     listDir( directory.toLocalFile(), codecList, recursive, conversionOptionsId );
-    TimeCount += Time.elapsed();
 
     pScanStatus->hide(); // hide the status bar, when the scan is done
 
-    qDebug() << "TimeCount: " << TimeCount;
+    emit fileCountChanged( topLevelItemCount() );
+
+    if( queue )
+        convertNextItem();
 }
 
-void FileList::addTracks( const QString& device, QList<int> trackList, int tracks, QList<TagData*> tagList, ConversionOptions *conversionOptions )
+void FileList::addTracks( const QString& device, QList<int> trackList, int tracks, QList<TagData*> tagList, ConversionOptions *conversionOptions, const QString& notifyCommand )
 {
     FileListItem *lastListItem = 0;
 
@@ -441,7 +484,7 @@ void FileList::addTracks( const QString& device, QList<int> trackList, int track
         }
         lastListItem = newItem;
         newItem->codecName = "audio cd";
-//         newItem->notifyCommand = notifyCommand;
+        newItem->notifyCommand = notifyCommand;
         newItem->track = trackList.at(i);
         newItem->tracks = tracks;
         newItem->device = device;
@@ -453,6 +496,9 @@ void FileList::addTracks( const QString& device, QList<int> trackList, int track
     }
 
     emit fileCountChanged( topLevelItemCount() );
+
+    if( queue )
+        convertNextItem();
 }
 
 void FileList::updateItem( FileListItem *item )
@@ -460,25 +506,30 @@ void FileList::updateItem( FileListItem *item )
     if( !item )
         return;
 
-    KUrl outputUrl;
-
-    if( !item->outputUrl.toLocalFile().isEmpty() )
-    {
-        outputUrl = item->outputUrl;
-    }
-    else
-    {
-        outputUrl = OutputDirectory::calcPath( item, config );
-    }
-//     if( QFile::exists(outputUrl.toLocalFile()) )
-//     {
-//         if( config->data.general.conflictHandling == Config::Data::General::ConflictHandling::NewFileName )
-//         {
-//             outputUrl = OutputDirectory::uniqueFileName( outputUrl );
-//         }
-//     }
+    // KUrl outputUrl;
+    // if( !item->outputUrl.toLocalFile().isEmpty() )
+    // {
+    //     outputUrl = item->outputUrl;
+    // }
+    // else
+    // {
+    //     outputUrl = OutputDirectory::calcPath( item, config );
+    // }
+    const KUrl outputUrl = OutputDirectory::calcPath( item, config );
     item->setText( Column_Output, outputUrl.toLocalFile() );
 
+    removeItemWidget( item, Column_State );
+    if( item->lInfo.data() )
+    {
+        disconnect( item->lInfo.data(), SIGNAL(linkActivated(const QString&)), this, 0 );
+        delete item->lInfo.data();
+    }
+    item->setText( Column_State, "" );
+    item->setToolTip( Column_State, "" );
+    item->setToolTip( Column_Input, "" );
+    item->setToolTip( Column_Output, "" );
+    item->setToolTip( Column_Quality, "" );
+
     switch( item->state )
     {
         case FileListItem::WaitingForConversion:
@@ -520,22 +571,46 @@ void FileList::updateItem( FileListItem *item )
         }
         case FileListItem::Stopped:
         {
-            item->setText( Column_State, i18n("Stopped") );
-            break;
-        }
-        case FileListItem::BackendNeedsConfiguration:
-        {
-            item->setText( Column_State, i18n("Backend not configured") );
-            break;
-        }
-        case FileListItem::DiscFull:
-        {
-            item->setText( Column_State, i18n("Disc full") );
-            break;
-        }
-        case FileListItem::Failed:
-        {
-            item->setText( Column_State, i18n("Failed") );
+            switch( item->returnCode )
+            {
+                case FileListItem::Succeeded:
+                case FileListItem::SucceededWithProblems:
+                {
+                    break;
+                }
+                case FileListItem::StoppedByUser:
+                {
+                    item->setText( Column_State, i18n("Stopped") );
+                    break;
+                }
+                case FileListItem::BackendNeedsConfiguration:
+                {
+                    item->setText( Column_State, i18n("Backend not configured") );
+                    break;
+                }
+                case FileListItem::DiscFull:
+                {
+                    item->setText( Column_State, i18n("Disc full") );
+                    break;
+                }
+                case FileListItem::Skipped:
+                {
+                    item->setText( Column_State, i18n("Will be skipped") );
+                    break;
+                }
+                case FileListItem::Failed:
+                {
+                    item->lInfo = new QLabel( "<a href=\"" + QString::number(item->logId) + "\">" + i18n("Failed") + "</a>" );
+                    connect( item->lInfo.data(), SIGNAL(linkActivated(const QString&)), this, SLOT(showLogClicked(const QString&)) );
+                    setItemWidget( item, Column_State, item->lInfo.data() );
+                    const QString toolTip = i18n("The conversion has failed.\nSee the log for more information.");
+                    item->setToolTip( Column_State, toolTip );
+                    item->setToolTip( Column_Input, toolTip );
+                    item->setToolTip( Column_Output, toolTip );
+                    item->setToolTip( Column_Quality, toolTip );
+                    break;
+                }
+            }
             break;
         }
     }
@@ -558,13 +633,17 @@ void FileList::updateItem( FileListItem *item )
     else
     {
         item->setText( Column_Input, item->url.pathOrUrl() );
-        //if( options ) item->setToolTip( 0, i18n("The file %1 will be converted from %2 to %3 using the %4 profile.\nIt will be saved to: %5").arg(item->url.pathOrUrl()).arg(item->codecName).arg(options->codecName).arg(options->profile).arg(outputUrl.toLocalFile()) );
     }
+}
 
-    update( indexFromItem( item, 0 ) );
-    update( indexFromItem( item, 1 ) );
-    update( indexFromItem( item, 2 ) );
-    update( indexFromItem( item, 3 ) );
+void FileList::showLogClicked( const QString& logIdString )
+{
+    const int logId = logIdString.toInt();
+
+    if( !logId )
+        return;
+
+    emit showLog( logId );
 }
 
 void FileList::updateItems( QList<FileListItem*> items )
@@ -610,15 +689,6 @@ void FileList::startConversion()
                 case FileListItem::Stopped:
                     isStopped = true;
                     break;
-                case FileListItem::BackendNeedsConfiguration:
-                    isStopped = true;
-                    break;
-                case FileListItem::DiscFull:
-                    isStopped = true;
-                    break;
-                case FileListItem::Failed:
-                    isStopped = true;
-                    break;
             }
         }
         if( isStopped )
@@ -665,12 +735,6 @@ void FileList::killConversion()
                     break;
                 case FileListItem::Stopped:
                     break;
-                case FileListItem::BackendNeedsConfiguration:
-                    break;
-                case FileListItem::DiscFull:
-                    break;
-                case FileListItem::Failed:
-                    break;
             }
         }
         if( canKill )
@@ -698,13 +762,13 @@ void FileList::convertNextItem()
         return;
 
     int count = convertingCount();
+    bool callItemsSelected = false;
     QStringList devices;
-    FileListItem *item;
 
     // look for tracks that are being ripped
     for( int i=0; i<topLevelItemCount(); i++ )
     {
-        item = topLevelItem( i );
+        FileListItem *item = topLevelItem( i );
         if( item->state == FileListItem::Ripping )
         {
             devices += item->device;
@@ -714,7 +778,7 @@ void FileList::convertNextItem()
     // look for waiting files
     for( int i=0; i<topLevelItemCount() && count < config->data.general.numFiles; i++ )
     {
-        item = topLevelItem( i );
+        FileListItem *item = topLevelItem( i );
         if( item->state == FileListItem::WaitingForConversion )
         {
             if( item->track >= 0 && !devices.contains(item->device) )
@@ -722,19 +786,24 @@ void FileList::convertNextItem()
                 count++;
                 devices += item->device;
                 emit convertItem( item );
+                if( selectedFiles.contains(item) )
+                    callItemsSelected = true;
             }
             else if( item->track < 0 )
             {
                 count++;
                 emit convertItem( item );
+                if( selectedFiles.contains(item) )
+                    callItemsSelected = true;
             }
         }
     }
 
-//     itemsSelected();
+    if( callItemsSelected )
+        itemsSelected();
 
     if( count == 0 )
-        itemFinished( 0, 0 );
+        itemFinished( 0, FileListItem::Succeeded );
 }
 
 int FileList::waitingCount()
@@ -752,7 +821,7 @@ int FileList::waitingCount()
     return count;
 }
 
-int FileList::convertingCount()
+int FileList::convertingCount() // TODO use Convert
 {
     int count = 0;
     FileListItem *item;
@@ -781,12 +850,6 @@ int FileList::convertingCount()
                 break;
             case FileListItem::Stopped:
                 break;
-            case FileListItem::BackendNeedsConfiguration:
-                break;
-            case FileListItem::DiscFull:
-                break;
-            case FileListItem::Failed:
-                break;
         }
         if( isConverting )
             count++;
@@ -814,46 +877,38 @@ int FileList::convertingCount()
 //     return mBSize - mBUsed;
 // }
 
-void FileList::itemFinished( FileListItem *item, int state )
+void FileList::itemFinished( FileListItem *item, FileListItem::ReturnCode returnCode, bool waitingForAlbumGain )
 {
     if( item )
     {
-        if( state == 0 )
+        if( waitingForAlbumGain )
+        {
+            item->state = FileListItem::WaitingForAlbumGain;
+
+            item->returnCode = returnCode;
+            updateItem( item );
+        }
+        else if( returnCode == FileListItem::Succeeded || returnCode == FileListItem::SucceededWithProblems )
         {
             config->conversionOptionsManager()->removeConversionOptions( item->conversionOptionsId );
-            emit itemRemoved( item );
+            if( selectedFiles.contains(item) )
+                itemsSelected();
             delete item;
             item = 0;
         }
-        else if( state == 1 )
-        {
-            item->state = FileListItem::Stopped;
-        }
-        else if( state == 100 )
-        {
-            item->state = FileListItem::BackendNeedsConfiguration;
-        }
-        else if( state == 101 )
-        {
-            item->state = FileListItem::DiscFull;
-        }
-        else if( state == 102 )
-        {
-            item->state = FileListItem::WaitingForAlbumGain;
-        }
         else
         {
-            item->state = FileListItem::Failed;
+            item->state = FileListItem::Stopped;
+
+            item->returnCode = returnCode;
+            updateItem( item );
         }
     }
 
-    if( item )
-        updateItem( item );
-
     // FIXME disabled until saving gets faster
 //     save( false );
 
-    if( waitingCount() > 0 && queue )
+    if( queue && waitingCount() > 0 )
     {
         convertNextItem();
     }
@@ -862,15 +917,16 @@ void FileList::itemFinished( FileListItem *item, int state )
         queue = false;
         save( false );
         emit queueModeChanged( queue );
-        float time = 0;
-        for( int i=0; i<topLevelItemCount(); i++ )
-        {
-            FileListItem *temp_item = topLevelItem( i );
-            updateItem( temp_item ); // TODO why?
-            time += temp_item->length;
-        }
-        emit finished( time );
-        emit conversionStopped( state );
+//         float time = 0;
+//         for( int i=0; i<topLevelItemCount(); i++ )
+//         {
+//             FileListItem *temp_item = topLevelItem( i );
+//             updateItem( temp_item ); // TODO why?
+//             time += temp_item->length;
+//         }
+//         emit finished( time );
+        emit finished( true );
+        emit conversionStopped( returnCode != FileListItem::Succeeded );
         emit fileCountChanged( topLevelItemCount() );
     }
 }
@@ -927,17 +983,17 @@ void FileList::rippingFinished( const QString& device )
 {
     if( waitingCount() > 0 && queue )
     {
-        FileListItem *item;
-
         // look for waiting files
         for( int i=0; i<topLevelItemCount(); i++ )
         {
-            item = topLevelItem( i );
+            FileListItem *item = topLevelItem( i );
             if( item->state == FileListItem::WaitingForConversion )
             {
                 if( item->track >= 0 && item->device == device )
                 {
                     emit convertItem( item );
+                    if( selectedFiles.contains(item) )
+                        itemsSelected();
                     return;
                 }
             }
@@ -983,12 +1039,6 @@ void FileList::showContextMenu( const QPoint& point )
                 break;
             case FileListItem::Stopped:
                 break;
-            case FileListItem::BackendNeedsConfiguration:
-                break;
-            case FileListItem::DiscFull:
-                break;
-            case FileListItem::Failed:
-                break;
         }
     }
     if( item->state == FileListItem::ApplyingAlbumGain )
@@ -1113,21 +1163,11 @@ void FileList::removeSelectedItems()
                 case FileListItem::Stopped:
                     canRemove = true;
                     break;
-                case FileListItem::BackendNeedsConfiguration:
-                    canRemove = true;
-                    break;
-                case FileListItem::DiscFull:
-                    canRemove = true;
-                    break;
-                case FileListItem::Failed:
-                    canRemove = true;
-                    break;
             }
             if( canRemove )
             {
                 emit timeChanged( -item->length );
                 config->conversionOptionsManager()->removeConversionOptions( item->conversionOptionsId );
-                emit itemRemoved( item );
                 delete item;
             }
         }
@@ -1140,6 +1180,7 @@ void FileList::removeSelectedItems()
 void FileList::convertSelectedItems()
 {
     bool started = false;
+    bool callItemsSelected = false;
     FileListItem *item;
     QList<QTreeWidgetItem*> items = selectedItems();
     for( int i=0; i<items.size(); i++ )
@@ -1166,15 +1207,6 @@ void FileList::convertSelectedItems()
                 case FileListItem::Stopped:
                     canConvert = true;
                     break;
-                case FileListItem::BackendNeedsConfiguration:
-                    canConvert = true;
-                    break;
-                case FileListItem::DiscFull:
-                    canConvert = true;
-                    break;
-                case FileListItem::Failed:
-                    canConvert = true;
-                    break;
             }
         }
         if( canConvert )
@@ -1185,10 +1217,17 @@ void FileList::convertSelectedItems()
             if( !started )
                 emit conversionStarted();
 
-            emit convertItem( (FileListItem*)items.at(i) );
+            emit convertItem( item );
+
+            if( selectedFiles.contains(item) )
+                callItemsSelected = true;
+
             started = true;
         }
     }
+
+    if( callItemsSelected )
+        itemsSelected();
 }
 
 void FileList::killSelectedItems()
@@ -1220,12 +1259,6 @@ void FileList::killSelectedItems()
                     break;
                 case FileListItem::Stopped:
                     break;
-                case FileListItem::BackendNeedsConfiguration:
-                    break;
-                case FileListItem::DiscFull:
-                    break;
-                case FileListItem::Failed:
-                    break;
             }
         }
         if( canKill )
@@ -1238,9 +1271,9 @@ void FileList::itemsSelected()
     selectedFiles.clear();
 
     QList<QTreeWidgetItem*> items = selectedItems();
-    for( int i=0; i<items.size(); i++ )
+    foreach( QTreeWidgetItem* item, items )
     {
-        selectedFiles.append( (FileListItem*)items.at(i) );
+        selectedFiles.append( (FileListItem*)item );
     }
 
     if( selectedFiles.count() > 0 )
@@ -1289,29 +1322,22 @@ void FileList::load( bool user )
                         case FileListItem::Stopped:
                             canRemove = true;
                             break;
-                        case FileListItem::BackendNeedsConfiguration:
-                            canRemove = true;
-                            break;
-                        case FileListItem::DiscFull:
-                            canRemove = true;
-                            break;
-                        case FileListItem::Failed:
-                            canRemove = true;
-                            break;
                     }
                 }
                 if( canRemove )
                 {
                     config->conversionOptionsManager()->removeConversionOptions( item->conversionOptionsId );
-                    emit itemRemoved( item );
                     delete item;
                     i--;
                 }
             }
+
+            itemsSelected();
         }
     }
 
     QMap<int,int> conversionOptionsIds;
+    QMap<int,int> conversionOptionsReferences;
     QString fileName = user ? "filelist.xml" : "filelist_autosave.xml";
     QFile listFile( KStandardDirs::locateLocal("data","soundkonverter/"+fileName) );
     if( listFile.open( QIODevice::ReadOnly ) )
@@ -1322,33 +1348,65 @@ void FileList::load( bool user )
             QDomElement root = list.documentElement();
             if( root.nodeName() == "soundkonverter" && root.attribute("type") == "filelist" )
             {
-                QDomNodeList conversionOptions = root.elementsByTagName("conversionOptions");
-                for( int i=0; i<conversionOptions.count(); i++ )
+                QDomNodeList conversionOptionsElements = root.elementsByTagName("conversionOptions");
+                for( int i=0; i<conversionOptionsElements.count(); i++ )
                 {
-                    CodecPlugin *plugin = (CodecPlugin*)config->pluginLoader()->backendPluginByName( conversionOptions.at(i).toElement().attribute("pluginName") );
-                    if( !plugin )
+                    ConversionOptions *conversionOptions = 0;
+                    QList<QDomElement> filterOptionsElements;
+                    const QString pluginName = conversionOptionsElements.at(i).toElement().attribute("pluginName");
+                    CodecPlugin *plugin = (CodecPlugin*)config->pluginLoader()->backendPluginByName( pluginName );
+                    if( plugin )
+                    {
+                        conversionOptions = plugin->conversionOptionsFromXml( conversionOptionsElements.at(i).toElement(), &filterOptionsElements );
+                    }
+                    else
+                    {
                         continue;
-
-                    conversionOptionsIds[conversionOptions.at(i).toElement().attribute("id").toInt()] = config->conversionOptionsManager()->addConversionOptions( plugin->conversionOptionsFromXml(conversionOptions.at(i).toElement()) );
+                    }
+                    if( conversionOptions )
+                    {
+                        foreach( QDomElement filterOptionsElement, filterOptionsElements )
+                        {
+                            FilterOptions *filterOptions = 0;
+                            const QString filterPluginName = filterOptionsElement.attribute("pluginName");
+                            FilterPlugin *filterPlugin = (FilterPlugin*)config->pluginLoader()->backendPluginByName( filterPluginName );
+                            if( filterPlugin )
+                            {
+                                filterOptions = filterPlugin->filterOptionsFromXml( filterOptionsElement );
+                            }
+                            else
+                            {
+                                continue;
+                            }
+                            conversionOptions->filterOptions.append( filterOptions );
+                        }
+                    }
+                    const int id = conversionOptionsElements.at(i).toElement().attribute("id").toInt();
+                    conversionOptionsIds[id] = config->conversionOptionsManager()->addConversionOptions( conversionOptions );
+                    conversionOptionsReferences[conversionOptionsIds[id]] = 0;
                 }
                 QDomNodeList files = root.elementsByTagName("file");
-                pScanStatus->setRange( 0, files.count() );
+                pScanStatus->setValue( 0 );
+                pScanStatus->setMaximum( files.count() );
                 pScanStatus->show();
+                tScanStatus.start();
                 for( int i=0; i<files.count(); i++ )
                 {
                     QDomElement file = files.at(i).toElement();
                     FileListItem *item = new FileListItem( this );
                     item->url = KUrl(file.attribute("url"));
-                    item->outputUrl = KUrl(file.attribute("outputUrl"));
+                    // item->outputUrl = KUrl(file.attribute("outputUrl"));
                     item->codecName = file.attribute("codecName");
-                    item->conversionOptionsId = conversionOptionsIds[file.attribute("conversionOptionsId").toInt()];
+                    item->conversionOptionsId = conversionOptionsIds[file.attribute("conversionOptionsId").toInt()]; // TODO check if id exists
                     item->local = file.attribute("local").toInt();
                     item->track = file.attribute("track").toInt();
                     item->tracks = file.attribute("tracks").toInt();
                     item->device = file.attribute("device");
                     item->length = file.attribute("time").toInt();
                     item->notifyCommand = file.attribute("notifyCommand");
-                    config->conversionOptionsManager()->increaseReferences( item->conversionOptionsId );
+                    if( conversionOptionsReferences[item->conversionOptionsId] != 0 )
+                        config->conversionOptionsManager()->increaseReferences( item->conversionOptionsId );
+                    conversionOptionsReferences[item->conversionOptionsId]++;
                     if( file.elementsByTagName("tags").count() > 0 )
                     {
                         QDomElement tags = file.elementsByTagName("tags").at(0).toElement();
@@ -1360,19 +1418,23 @@ void FileList::load( bool user )
                         item->tags->genre = tags.attribute("genre");
                         item->tags->comment = tags.attribute("comment");
                         item->tags->track = tags.attribute("track").toInt();
+                        item->tags->trackTotal = tags.attribute("trackTotal").toInt();
                         item->tags->disc = tags.attribute("disc").toInt();
+                        item->tags->discTotal = tags.attribute("discTotal").toInt();
                         item->tags->year = tags.attribute("year").toInt();
-                        item->tags->track_gain = tags.attribute("track_gain").toFloat();
-                        item->tags->album_gain = tags.attribute("album_gain").toFloat();
+                        item->tags->trackGain = tags.attribute("track_gain").toFloat();
+                        item->tags->albumGain = tags.attribute("album_gain").toFloat();
                         item->tags->length = tags.attribute("length").toInt();
-                        item->tags->fileSize = tags.attribute("fileSize").toInt();
-                        item->tags->bitrate = tags.attribute("bitrate").toInt();
                         item->tags->samplingRate = tags.attribute("samplingRate").toInt();
                     }
                     addTopLevelItem( item );
                     updateItem( item );
                     emit timeChanged( item->length );
-                    pScanStatus->setValue( i );
+                    if( tScanStatus.elapsed() > ConfigUpdateDelay * 10 )
+                    {
+                        pScanStatus->setValue( i );
+                        tScanStatus.start();
+                    }
                 }
                 pScanStatus->hide();
             }
@@ -1416,7 +1478,7 @@ void FileList::save( bool user )
 
         QDomElement file = list.createElement("file");
         file.setAttribute("url",item->url.pathOrUrl());
-        file.setAttribute("outputUrl",item->outputUrl.pathOrUrl());
+        // file.setAttribute("outputUrl",item->outputUrl.pathOrUrl());
         file.setAttribute("codecName",item->codecName);
         file.setAttribute("conversionOptionsId",item->conversionOptionsId);
         file.setAttribute("local",item->local);
@@ -1436,13 +1498,13 @@ void FileList::save( bool user )
             tags.setAttribute("genre",item->tags->genre);
             tags.setAttribute("comment",item->tags->comment);
             tags.setAttribute("track",item->tags->track);
+            tags.setAttribute("trackTotal",item->tags->trackTotal);
             tags.setAttribute("disc",item->tags->disc);
+            tags.setAttribute("discTotal",item->tags->discTotal);
             tags.setAttribute("year",item->tags->year);
-            tags.setAttribute("track_gain",item->tags->track_gain);
-            tags.setAttribute("album_gain",item->tags->album_gain);
+            tags.setAttribute("track_gain",item->tags->trackGain);
+            tags.setAttribute("album_gain",item->tags->albumGain);
             tags.setAttribute("length",item->tags->length);
-            tags.setAttribute("fileSize",item->tags->fileSize);
-            tags.setAttribute("bitrate",item->tags->bitrate);
             tags.setAttribute("samplingRate",item->tags->samplingRate);
             file.appendChild(tags);
         }
