@@ -25,10 +25,10 @@ Logger::Logger( QObject *parent)
     writeLogFiles = group.readEntry( "writeLogFiles", false );
 
     LoggerItem *item = new LoggerItem();
-    item->filename = KUrl("soundKonverter");
+    item->identifier = "soundKonverter";
     item->id = 1000;
     item->completed = true;
-    item->state = 1;
+    item->succeeded = true;
     item->file.setFileName( KStandardDirs::locateLocal("data",QString("soundkonverter/log/%1.log").arg(item->id)) );
     if( writeLogFiles )
     {
@@ -71,10 +71,10 @@ Logger::~Logger()
 //     processes.clear();
 // }
 
-int Logger::registerProcess( const KUrl& filename )
+int Logger::registerProcess( const QString& identifier )
 {
     LoggerItem *item = new LoggerItem();
-    item->filename = filename;
+    item->identifier = identifier;
     item->id = getNewID();
     item->completed = false;
     item->file.setFileName( KStandardDirs::locateLocal("data",QString("soundkonverter/log/%1.log").arg(item->id)) );
@@ -87,7 +87,7 @@ int Logger::registerProcess( const KUrl& filename )
 
     processes.append( item );
 
-    log( item->id, i18n("Filename") + ": " + item->filename.pathOrUrl() );
+    log( item->id, i18n("Identifier") + ": " + item->identifier );
     log( item->id, i18n("Log ID") + ": " + QString::number(item->id) );
 
     emit updateProcess( item->id );
@@ -163,21 +163,23 @@ QList<LoggerItem*> Logger::getLogs()
     return processes;
 }
 
-void Logger::processCompleted( int id, int state )
+void Logger::processCompleted( int id, bool succeeded, bool waitingForAlbumGain )
 {
+    Q_UNUSED( waitingForAlbumGain )
+
     LoggerItem* removeItem = 0;
     QTime time = QTime::currentTime();
 
     for( int i=0; i<processes.count(); i++ )
     {
-        if( processes.at(i)->time < time && processes.at(i)->completed && processes.at(i)->state == 0 )
+        if( processes.at(i)->time < time && processes.at(i)->completed && processes.at(i)->succeeded && processes.at(i)->id != 1000 )
         {
             time = processes.at(i)->time;
             removeItem = processes.at(i);
         }
         else if( processes.at(i)->id == id )
         {
-            processes.at(i)->state = state;
+            processes.at(i)->succeeded = succeeded;
             processes.at(i)->completed = true;
             processes.at(i)->time = processes.at(i)->time.currentTime();
             processes.at(i)->data.append( i18n("Finished logging") );
