@@ -3,7 +3,6 @@
 #ifndef LOGGER_H
 #define LOGGER_H
 
-// #include <qobject.h>
 #include <QStringList>
 #include <QTime>
 #include <QFile>
@@ -14,22 +13,18 @@
 /**
  * @short An item for every process that is logged
  * @author Daniel Faust <hessijames@gmail.com>
- * @version 0.3
  */
 class LoggerItem
 {
 public:
-    /** Constructor */
     LoggerItem();
+    ~LoggerItem();
 
-    /** Destructor */
-    virtual ~LoggerItem();
-
-    KUrl filename;
+    QString identifier;
     int id;
     QStringList data;
     bool completed;
-    int state; // 0 = ok, -1 = failed, 1 = other (soundKonverter)
+    bool succeeded;
     QTime time;
     QFile file;
     QTextStream textStream;
@@ -39,22 +34,16 @@ public:
 /**
  * @short All data about the processes are collected here
  * @author Daniel Faust <hessijames@gmail.com>
- * @version 0.3
  */
 class Logger : public QObject
 {
     Q_OBJECT
 public:
-    /** Constructor */
     Logger( QObject *parent );
-
-    /** Destructor */
-    virtual ~Logger();
-
-//     void cleanUp();
+    ~Logger();
 
     /** Creates a new logger item and returns the id of it, @p filename is added to the new logger item */
-    int registerProcess( const KUrl& filename );
+    int registerProcess( const QString& identifier );
 
     /** Adds the string @p data to the data of the logger item with id @p id */
     void log( int id, const QString& data );
@@ -78,8 +67,8 @@ private:
     int getNewID();
 
 public slots:
-    void processCompleted( int id, int state );
-    /// connected to config
+    void processCompleted( int id, bool succeeded, bool waitingForAlbumGain = false );
+    // connected to config
     void updateWriteSetting( bool _writeLogFiles );
 
 signals:
