@@ -4,6 +4,7 @@
 
 #include <QLayout>
 #include <QLabel>
+#include <QApplication>
 
 #include <KLocale>
 #include <KIcon>
@@ -31,7 +32,6 @@ LogViewer::LogViewer( Logger* _logger, QWidget *parent, Qt::WFlags f )
     setButtonIcon( KDialog::User2, KIcon("document-save") );
     connect( this, SIGNAL(user2Clicked()), this, SLOT(save()) );
     setButtonFocus( KDialog::Close );
-    resize( 600, 390 );
 
     QWidget *widget = new QWidget( this );
     setMainWidget( widget );
@@ -53,10 +53,19 @@ LogViewer::LogViewer( Logger* _logger, QWidget *parent, Qt::WFlags f )
     kLog->setTextInteractionFlags( Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard );
 
     refillLogs();
+
+    setInitialSize( QSize(600,390) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "LogViewer" );
+    restoreDialogSize( group );
 }
 
 LogViewer::~LogViewer()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "LogViewer" );
+    saveDialogSize( group );
+}
 
 void LogViewer::refillLogs()
 {
@@ -64,18 +73,17 @@ void LogViewer::refillLogs()
 
     cItem->clear();
 
-    QList<LoggerItem*> logs = logger->getLogs();
-    for( QList<LoggerItem*>::Iterator a = logs.begin(); a != logs.end(); ++a )
+    foreach( LoggerItem *log, logger->getLogs() )
     {
-        QString name = (*a)->filename.pathOrUrl();
+        QString name = log->identifier;
         // TODO make the string width dependend on the window width
         if( name.length() > 73 )
             name = name.left(35) + "..." + name.right(35);
 
-        if( (*a)->id == 1000 )
-            cItem->addItem( i18n("soundKonverter application log"), QVariant((*a)->id) );
+        if( log->id == 1000 )
+            cItem->addItem( i18n("soundKonverter application log"), QVariant(log->id) );
         else
-            cItem->addItem( name, QVariant((*a)->id) );
+            cItem->addItem( name, QVariant(log->id) );
     }
 
     if( cItem->findData(currentProcess) != -1 )
@@ -88,21 +96,24 @@ void LogViewer::refillLogs()
 
 void LogViewer::itemChanged()
 {
+    // HACK avoid Qt bug? changing the color of 'uncolored' text when switching the log file
+    QTextCursor cursor = kLog->textCursor();
+    cursor.setPosition( 0 );
+    kLog->setTextCursor( cursor );
+
     kLog->clear();
     LoggerItem* item = logger->getLog( cItem->itemData(cItem->currentIndex()).toInt() );
 
     if( !item )
         return;
 
-    for( QStringList::Iterator b = item->data.begin(); b != item->data.end(); ++b )
-    {
-        kLog->append( *b );
-    }
+    foreach( const QString line, item->data )
+        kLog->append( line );
 
     QPalette currentPalette = kLog->palette();
     if( item->completed )
     {
-        currentPalette.setColor( QPalette::Base, QColor(255,255,255) );
+        currentPalette.setColor( QPalette::Base, QApplication::palette().base().color() );
     }
     else
     {
@@ -148,4 +159,13 @@ void LogViewer::updateProcess( int id )
     refillLogs();
 }
 
+void LogViewer::showLog( int id )
+{
+    if( cItem->findData(QVariant(id)) != -1 )
+        cItem->setCurrentIndex( cItem->findData(QVariant(id)) );
+    else
+        cItem->setCurrentIndex( 0 );
+
+    itemChanged();
+}
 
