@@ -5,11 +5,9 @@
 
 #include <KUrl>
 
-#include <QString>
 #include <QStringList>
-#include <QImage>
 
-// #include <MediaInfo/MediaInfo.h>
+class Config;
 
 class CoverData : public QObject
 {
@@ -64,7 +62,7 @@ public:
     };
 
     CoverData( const QByteArray& _data = QByteArray(), const QString& _mimyType = QString::null, Role _role = Other, const QString& _description = QString::null, QObject *parent = 0 );
-    virtual ~CoverData();
+    ~CoverData();
 
     QByteArray data;
     QString mimeType;
@@ -74,20 +72,13 @@ public:
     static QString roleName( Role role );
 };
 
-/**
- * @short All metainformation can be stored in this class
- * @author Daniel Faust <hessijames@gmail.com>
- * @version 0.3
- */
+
 class TagData : public QObject
 {
     Q_OBJECT
 public:
-    /** Constructor */
     TagData();
-
-    /** Destructor */
-    virtual ~TagData();
+    ~TagData();
 
     /** The tags */
     QString artist;
@@ -96,52 +87,50 @@ public:
     QString title;
     QString genre;
     QString comment;
-    int track;
-    int disc;
-    int discTotal;
-    int year;
-    float track_gain;
-    float album_gain;
+    short track;
+    short trackTotal;
+    short disc;
+    short discTotal;
+    short year;
+    float trackGain;
+    float albumGain;
+
+    QString musicBrainzTrackId;
+    QString musicBrainzReleaseId;
 
     /** Covers */
     QList<CoverData*> covers;
-    bool coversRead;
+
+    enum TagsRead {
+        TrackGain = 0x01,
+        AlbumGain = 0x02,
+        Covers    = 0x04
+    } tagsRead;
 
     /** The technical information */
     int length;
-    int fileSize;
-    int bitrate;
     int samplingRate;
 };
 
 
-/**
- * @short Manages everything that has something to do with tags
- * @author Daniel Faust <hessijames@gmail.com>
- * @version 0.3
- */
 class TagEngine
 {
 public:
-    /** Constructor */
-    TagEngine();
-
-    /** Destructor */
-    virtual ~TagEngine();
+    TagEngine( Config *_config );
+    ~TagEngine();
 
     /** A list of all genre */
     QStringList genreList;
 
-//     MediaInfoLib::MediaInfo* MI;
-
     TagData* readTags( const KUrl& fileName );
     bool writeTags( const KUrl& fileName, TagData *tagData );
 
     QList<CoverData*> readCovers( const KUrl& fileName );
     bool writeCovers( const KUrl& fileName, QList<CoverData*> covers );
-    bool writeCoversToDirectory( const QString& directoryName, QList<CoverData*> covers );
+    bool writeCoversToDirectory( const QString& directoryName, TagData *tags );
 
-//     bool canWrite( QString format ); // NOTE no const because this string is being modyfied
+private:
+    Config *config;
 };
 
 #endif // TAGENGINE_H
