@@ -18,11 +18,11 @@
 #include <KInputDialog>
 
 #include <QLayout>
+#include <QBoxLayout>
 #include <QGridLayout>
 #include <QLabel>
 #include <QGroupBox>
 #include <QTreeWidget>
-// #include <QList>
 #include <QDateTime>
 #include <QColor>
 #include <QDir>
@@ -30,13 +30,16 @@
 #include <QCheckBox>
 #include <QHeaderView>
 
+// #include <solid/device.h>
+// #include <solid/block.h>
+
 
 PlayerWidget::PlayerWidget( Phonon::MediaObject *mediaObject, int _track, QTreeWidgetItem *_treeWidgetItem, QWidget *parent, Qt::WindowFlags f )
     : QWidget( parent, f ),
     track( _track ),
     m_treeWidgetItem( _treeWidgetItem )
 {
-    QHBoxLayout *trackPlayerBox = new QHBoxLayout( 0 );
+    QHBoxLayout *trackPlayerBox = new QHBoxLayout();
     setLayout( trackPlayerBox );
 
     pStartPlayback = new KPushButton( KIcon("media-playback-start"), "", this );
@@ -116,7 +119,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
 
     QWidget *widget = new QWidget( this );
     QGridLayout *mainGrid = new QGridLayout( widget );
-    QGridLayout *topGrid = new QGridLayout( 0 );
+    QGridLayout *topGrid = new QGridLayout();
     mainGrid->addLayout( topGrid, 0, 0 );
     setMainWidget( widget );
 
@@ -144,7 +147,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     QGridLayout *gridLayout = new QGridLayout( cdOpenerWidget );
 
     // the box for the cover and artist/album grid
-    QHBoxLayout *topBoxLayout = new QHBoxLayout( 0 );
+    QHBoxLayout *topBoxLayout = new QHBoxLayout();
     gridLayout->addLayout( topBoxLayout, 0, 0 );
 
     // the album cover
@@ -154,7 +157,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     lAlbumCover->setContentsMargins( 0, 0, 6, 0 );
 
     // the grid for the artist and album input
-    QGridLayout *topGridLayout = new QGridLayout( 0 );
+    QGridLayout *topGridLayout = new QGridLayout();
     topBoxLayout->addLayout( topGridLayout );
 
     // set up the first row at the top
@@ -167,7 +170,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     cArtist->setEditText( "" );
     connect( cArtist, SIGNAL(textChanged(const QString&)), this, SLOT(artistChanged(const QString&)) );
     // add a horizontal box layout for the composer
-    QHBoxLayout *artistBox = new QHBoxLayout( 0 );
+    QHBoxLayout *artistBox = new QHBoxLayout();
     topGridLayout->addLayout( artistBox, 0, 3 );
     // and fill it up
     QLabel *lComposerLabel = new QLabel( i18n("Composer:"), cdOpenerWidget );
@@ -188,7 +191,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     lAlbum = new KLineEdit( cdOpenerWidget );
     topGridLayout->addWidget( lAlbum, 1, 1 );
     // add a horizontal box layout for the disc number
-    QHBoxLayout *albumBox = new QHBoxLayout( 0 );
+    QHBoxLayout *albumBox = new QHBoxLayout();
     topGridLayout->addLayout( albumBox, 1, 3 );
     // and fill it up
     QLabel *lDiscLabel = new QLabel( i18n("Disc No.:"), cdOpenerWidget );
@@ -197,12 +200,18 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     iDisc = new KIntSpinBox( 1, 99, 1, 1, cdOpenerWidget );
     albumBox->addWidget( iDisc );
     albumBox->addStretch();
+    QLabel *lDiscTotalLabel = new QLabel( i18nc("Track/Disc No. x of y","of"), cdOpenerWidget );
+    lDiscTotalLabel->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
+    albumBox->addWidget( lDiscTotalLabel );
+    albumBox->addStretch();
+    iDiscTotal = new KIntSpinBox( 1, 99, 1, 1, cdOpenerWidget );
+    albumBox->addWidget( iDiscTotal );
 
     // set up the third row at the top
     QLabel *lYearLabel = new QLabel( i18n("Year:"), cdOpenerWidget );
     topGridLayout->addWidget( lYearLabel, 2, 0 );
     // add a horizontal box layout for the year and genre
-    QHBoxLayout *yearBox = new QHBoxLayout( 0 );
+    QHBoxLayout *yearBox = new QHBoxLayout();
     topGridLayout->addLayout( yearBox, 2, 1 );
     // and fill it up
     iYear = new KIntSpinBox( 0, 99999, 1, QDate::currentDate().year(), cdOpenerWidget );
@@ -270,7 +279,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
 
     // add the inputs
     // add a horizontal box layout for the title
-    QHBoxLayout *trackTitleBox = new QHBoxLayout( 0 );
+    QHBoxLayout *trackTitleBox = new QHBoxLayout();
     tagGridLayout->addLayout( trackTitleBox, 0, 2 );
     // and fill it up
     QLabel *lTrackTitleLabel = new QLabel( i18n("Title:"), tagGroupBox );
@@ -285,7 +294,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     trackTitleBox->addWidget( pTrackTitleEdit );
     connect( pTrackTitleEdit, SIGNAL(clicked()), this, SLOT(editTrackTitleClicked()) );
     // add a horizontal box layout for the composer
-    QHBoxLayout *trackArtistBox = new QHBoxLayout( 0 );
+    QHBoxLayout *trackArtistBox = new QHBoxLayout();
     tagGridLayout->addLayout( trackArtistBox, 1, 2 );
     // and fill it up
     QLabel *lTrackArtistLabel = new QLabel( i18n("Artist:"), tagGroupBox );
@@ -311,7 +320,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     trackArtistBox->addWidget( pTrackComposerEdit );
     connect( pTrackComposerEdit, SIGNAL(clicked()), this, SLOT(editTrackComposerClicked()) );
     // add a horizontal box layout for the comment
-    QHBoxLayout *trackCommentBox = new QHBoxLayout( 0 );
+    QHBoxLayout *trackCommentBox = new QHBoxLayout();
     tagGridLayout->addLayout( trackCommentBox, 2, 2 );
     // and fill it up
     QLabel *lTrackCommentLabel = new QLabel( i18n("Comment:"), tagGroupBox );
@@ -338,9 +347,6 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     mediaController = new Phonon::MediaController( mediaObject );
     mediaController->setAutoplayTitles( false );
 
-    mediaSource = new Phonon::MediaSource( Phonon::Cd, _device );
-    mediaObject->setCurrentSource( *mediaSource ); // WARNING doesn't work with phonon-xine
-
     connect( mediaController, SIGNAL(titleChanged(int)), this, SLOT(playbackTitleChanged(int)) );
     connect( mediaObject, SIGNAL(stateChanged(Phonon::State,Phonon::State)), this, SLOT(playbackStateChanged(Phonon::State,Phonon::State)) );
 
@@ -381,7 +387,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     mainGrid->addWidget( buttonLineFrame, 4, 0 );
 
     // add a horizontal box layout for the control elements
-    QHBoxLayout *controlBox = new QHBoxLayout( 0 );
+    QHBoxLayout *controlBox = new QHBoxLayout();
     mainGrid->addLayout( controlBox, 5, 0 );
 
     // add the control elements
@@ -401,8 +407,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     if( !cEntireCd->isEnabled() )
     {
         QPalette notificationPalette = cEntireCd->palette();
-//         notificationPalette.setColor( QPalette::Disabled, QPalette::WindowText, QColor(181,96,101) );
-        notificationPalette.setColor( QPalette::Disabled, QPalette::WindowText, QColor(174,127,130) );
+        notificationPalette.setColor( QPalette::Disabled, QPalette::WindowText, QColor(174,127,130) ); // QColor(181,96,101)
         cEntireCd->setPalette( notificationPalette );
         if( !errorList.isEmpty() )
         {
@@ -410,7 +415,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
         }
         else
         {
-            errorList += i18n("Ripping an entire cd to a single file is not supported by the installed backends.\nPlease check your distribution's package manager in order to install an additional ripper plugin wich supports ripping to one file.");
+            errorList += i18n("Ripping an entire cd to a single file is not supported by the installed backends.\nPlease check your distribution's package manager in order to install an additional ripper plugin which supports ripping to one file.");
         }
         cEntireCd->setToolTip( errorList.join("\n") );
     }
@@ -433,12 +438,6 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
 
 
     cddb = new KCDDB::Client();
-//     if( !cddb )
-//     {
-//         kDebug() << "Unable to create KCDDB object. Low mem?";
-//         error = Error(i18n("Unable to create KCDDB object."), i18n("This is an internal error. Check your hardware. If all okay please make bug report."), Error::ERROR, this);
-//         return;
-//     }
     connect( cddb, SIGNAL(finished(KCDDB::Result)), this, SLOT(lookup_cddb_done(KCDDB::Result)) );
 
 
@@ -447,11 +446,9 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
     connect( &timeoutTimer, SIGNAL(timeout()), this, SLOT(timeout()) );
 
 
-    bool success = false;
-
     if( !_device.isEmpty() )
     {
-        success = openCdDevice( _device );
+        device = _device;
     }
     else
     {
@@ -463,7 +460,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
         }
         else if( devices.count() == 1 )
         {
-            success = openCdDevice( devices.keys().at(0) );
+            device = devices.keys().at(0);
         }
         else
         {
@@ -478,7 +475,7 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
             if( ok )
             {
                 // The user selected an item and pressed OK
-                success = openCdDevice( devices.keys().at(list.indexOf(selection)) );
+                device = devices.keys().at(list.indexOf(selection));
             }
             else
             {
@@ -488,16 +485,34 @@ CDOpener::CDOpener( Config *_config, const QString& _device, QWidget *parent, Qt
         }
     }
 
+    const bool success = openCdDevice( device );
     if( !success )
     {
         KMessageBox::information(this,"success = false, couldn't open audio device.\nplease report this bug.");
         noCdFound = true;
         return;
     }
+
+
+    mediaSource = new Phonon::MediaSource( Phonon::Cd, device );
+    mediaObject->setCurrentSource( *mediaSource ); // WARNING doesn't work with phonon-xine
+
+
+    // Prevent the dialog from beeing too wide because of the directory history
+    if( parent && width() > parent->width() )
+        setInitialSize( QSize(parent->width()-10,sizeHint().height()) );
+
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "CDOpener" );
+    restoreDialogSize( group );
 }
 
 CDOpener::~CDOpener()
 {
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "CDOpener" );
+    saveDialogSize( group );
+
     if( cdParanoia )
     {
         paranoia_free( cdParanoia );
@@ -513,8 +528,35 @@ CDOpener::~CDOpener()
         delete cddb;
 }
 
+void CDOpener::setProfile( const QString& profile )
+{
+    options->setProfile( profile );
+}
+
+void CDOpener::setFormat( const QString& format )
+{
+    options->setFormat( format );
+}
+
+void CDOpener::setOutputDirectory( const QString& directory )
+{
+    options->setOutputDirectory( directory );
+}
+
+void CDOpener::setCommand( const QString& _command )
+{
+    command = _command;
+}
+
 QMap<QString,QString> CDOpener::cdDevices()
 {
+//         QStringList deviceList;
+//         QList<Solid::Device> solidDeviceList = Solid::Device::listFromType(Solid::DeviceInterface::OpticalDrive, QString());
+//         foreach( Solid::Device solidDevice, solidDeviceList )
+//         {
+//             deviceList += solidDevice.as<Solid::Block>()->device();
+//         }
+
     QMap<QString,QString> devices;
 
     QFile *file;
@@ -621,8 +663,6 @@ bool CDOpener::openCdDevice( const QString& _device )
     }
     cdParanoia = paranoia_init( cdDrive );
 
-    device = _device;
-
     // cd text
 
 //     const int status = wm_cd_init( device.toAscii().data(), "", "", "", &wmHandle );
@@ -650,15 +690,20 @@ bool CDOpener::openCdDevice( const QString& _device )
     TagData *newTags = new TagData();
     newTags->artist = i18n("Unknown");
     newTags->album = i18n("Unknown");
+    newTags->track = 1;
+    newTags->trackTotal = 1;
     newTags->disc = 1;
+    newTags->discTotal = 1;
     newTags->year = (QDate::currentDate()).year();
     newTags->genre = i18n("Unknown");
     tags += newTags;
 
-    for( int i=0; i<cdda_audio_tracks(cdDrive); i++ )
+    const int trackTotal = cdda_audio_tracks( cdDrive );
+    for( int i=0; i<trackTotal; i++ )
     {
         TagData *newTags = new TagData();
         newTags->track = i+1;
+        newTags->trackTotal = trackTotal;
         newTags->artist = i18n("Unknown");
         newTags->title = i18n("Unknown");
         const long size = CD_FRAMESIZE_RAW * (cdda_track_lastsector(cdDrive,newTags->track)-cdda_track_firstsector(cdDrive,newTags->track));
@@ -692,6 +737,7 @@ bool CDOpener::openCdDevice( const QString& _device )
     cComposer->setEditText( tags.at(0)->composer );
     lAlbum->setText( tags.at(0)->album );
     iDisc->setValue( tags.at(0)->disc );
+    iDiscTotal->setValue( tags.at(0)->discTotal );
     iYear->setValue( tags.at(0)->year );
     cGenre->setEditText( tags.at(0)->genre );
 
@@ -733,7 +779,8 @@ void CDOpener::lookup_cddb_done( KCDDB::Result result )
 
     if( result != KCDDB::Success && result != KCDDB::MultipleRecordFound )
     {
-    //     error = Error(i18n("No entry found in CDDB."), i18n("This means no data found in the CDDB database. Please enter the data manually. Maybe try another CDDB server."), Error::ERROR, this);
+        // TODO error message if request was initiated by the user
+        // Error(i18n("No entry found in CDDB."), i18n("This means no data found in the CDDB database. Please enter the data manually. Maybe try another CDDB server."), Error::ERROR, this);
         fadeOut();
         return;
     }
@@ -747,7 +794,7 @@ void CDOpener::lookup_cddb_done( KCDDB::Result result )
         QStringList list;
         if( cdTextFound )
         {
-//             list.append( QString("CD Text: %1, %2").arg(compact_disc->discArtist()).arg(compact_disc->discTitle()) );
+            // list.append( QString("CD Text: %1, %2").arg(compact_disc->discArtist()).arg(compact_disc->discTitle()) );
         }
         for( int i=0; i<cddb_info.count(); i++ )
         {
@@ -788,22 +835,30 @@ void CDOpener::lookup_cddb_done( KCDDB::Result result )
         tags.at(i)->title = info.track(i-1).get(KCDDB::Title).toString();
         tags.at(i)->comment = info.track(i-1).get(KCDDB::Comment).toString();
 
-        if( artist == "" ) artist = tags.at(i)->artist;
-        else if( artist != tags.at(i)->artist ) various_artists = true;
+        if( artist == "" )
+            artist = tags.at(i)->artist;
+        else if( artist != tags.at(i)->artist )
+            various_artists = true;
 
-        if( composer == "" ) composer = tags.at(i)->composer;
-        else if( composer != tags.at(i)->composer ) various_composer = true;
+        if( composer == "" )
+            composer = tags.at(i)->composer;
+        else if( composer != tags.at(i)->composer )
+            various_composer = true;
 
         QTreeWidgetItem *item = trackList->topLevelItem(i-1);
         item->setText( 2, tags.at(i)->artist );
         item->setText( 4, tags.at(i)->title );
     }
 
-    if( various_artists ) tags.at(0)->artist = i18n("Various Artists");
-    else tags.at(0)->artist = artist;
+    if( various_artists )
+        tags.at(0)->artist = i18n("Various Artists");
+    else
+        tags.at(0)->artist = artist;
 
-    if( various_composer ) tags.at(0)->composer = i18n("Various Composer");
-    else tags.at(0)->composer = composer;
+    if( various_composer )
+        tags.at(0)->composer = i18n("Various Composer");
+    else
+        tags.at(0)->composer = composer;
 
     tags.at(0)->album = info.get(KCDDB::Title).toString();
     tags.at(0)->year = info.get(KCDDB::Year).toInt();
@@ -815,6 +870,7 @@ void CDOpener::lookup_cddb_done( KCDDB::Result result )
     cComposer->setEditText( tags.at(0)->composer );
     lAlbum->setText( tags.at(0)->album );
     iDisc->setValue( tags.at(0)->disc );
+    iDiscTotal->setValue( tags.at(0)->discTotal );
     iYear->setValue( tags.at(0)->year );
     cGenre->setEditText( tags.at(0)->genre );
 
@@ -920,11 +976,15 @@ void CDOpener::trackChanged()
     }
     else if( selectedTracks.count() > 1 )
     {
-        if( selectedTracks.first() > 1 ) pTrackUp->setEnabled( true );
-        else pTrackUp->setEnabled( false );
+        if( selectedTracks.first() > 1 )
+            pTrackUp->setEnabled( true );
+        else
+            pTrackUp->setEnabled( false );
 
-        if( selectedTracks.last() < trackList->topLevelItemCount() ) pTrackDown->setEnabled( true );
-        else pTrackDown->setEnabled( false );
+        if( selectedTracks.last() < trackList->topLevelItemCount() )
+            pTrackDown->setEnabled( true );
+        else
+            pTrackDown->setEnabled( false );
 
         QString trackListString = "";
         if( selectedTracks.count() == trackList->topLevelItemCount() )
@@ -951,56 +1011,76 @@ void CDOpener::trackChanged()
         bool equalComments = true;
         for( int i=1; i<selectedTracks.count(); i++ )
         {
-            if( title != tags.at(selectedTracks.at(i))->title ) equalTitles = false;
-            if( artist != tags.at(selectedTracks.at(i))->artist ) equalArtists = false;
-            if( composer != tags.at(selectedTracks.at(i))->composer ) equalComposers = false;
-            if( comment != tags.at(selectedTracks.at(i))->comment ) equalComments = false;
+            if( title != tags.at(selectedTracks.at(i))->title )
+                equalTitles = false;
+            if( artist != tags.at(selectedTracks.at(i))->artist )
+                equalArtists = false;
+            if( composer != tags.at(selectedTracks.at(i))->composer )
+                equalComposers = false;
+            if( comment != tags.at(selectedTracks.at(i))->comment )
+                equalComments = false;
         }
 
-        if( equalTitles ) {
+        if( equalTitles )
+        {
             lTrackTitle->setEnabled( true );
             lTrackTitle->setText( title );
             pTrackTitleEdit->hide();
-        } else {
+        }
+        else
+        {
             lTrackTitle->setEnabled( false );
             lTrackTitle->setText( "" );
             pTrackTitleEdit->show();
         }
 
-        if( cArtist->currentText() == i18n("Various Artists") && equalArtists ) {
+        if( cArtist->currentText() == i18n("Various Artists") && equalArtists )
+        {
             lTrackArtist->setEnabled( true );
             lTrackArtist->setText( artist );
             pTrackArtistEdit->hide();
-        } else if( cArtist->currentText() == i18n("Various Artists") ) {
+        }
+        else if( cArtist->currentText() == i18n("Various Artists") )
+        {
             lTrackArtist->setEnabled( false );
             lTrackArtist->setText( "" );
             pTrackArtistEdit->show();
-        } else {
+        }
+        else
+        {
             lTrackArtist->setEnabled( false );
             lTrackArtist->setText( cArtist->currentText() );
             pTrackArtistEdit->hide();
         }
 
-        if( cComposer->currentText() == i18n("Various Composer") && equalComposers ) {
+        if( cComposer->currentText() == i18n("Various Composer") && equalComposers )
+        {
             lTrackComposer->setEnabled( true );
             lTrackComposer->setText( composer );
             pTrackComposerEdit->hide();
-        } else if( cComposer->currentText() == i18n("Various Composer") ) {
+        }
+        else if( cComposer->currentText() == i18n("Various Composer") )
+        {
             lTrackComposer->setEnabled( false );
             lTrackComposer->setText( "" );
             pTrackComposerEdit->show();
-        } else {
+        }
+        else
+        {
             lTrackComposer->setEnabled( false );
             lTrackComposer->setText( cComposer->currentText() );
             pTrackComposerEdit->hide();
         }
 
-        if( equalComments ) {
+        if( equalComments )
+        {
             tTrackComment->setEnabled( true );
             tTrackComment->setReadOnly( false );
             tTrackComment->setText( comment );
             pTrackCommentEdit->hide();
-        } else {
+        }
+        else
+        {
             tTrackComment->setEnabled( false );
             tTrackComment->setReadOnly( true );
             tTrackComment->setText( "" );
@@ -1009,11 +1089,15 @@ void CDOpener::trackChanged()
     }
     else
     {
-        if( selectedTracks.first() > 1 ) pTrackUp->setEnabled( true );
-        else pTrackUp->setEnabled( false );
+        if( selectedTracks.first() > 1 )
+            pTrackUp->setEnabled( true );
+        else
+            pTrackUp->setEnabled( false );
 
-        if( selectedTracks.last() < trackList->topLevelItemCount() ) pTrackDown->setEnabled( true );
-        else pTrackDown->setEnabled( false );
+        if( selectedTracks.last() < trackList->topLevelItemCount() )
+            pTrackDown->setEnabled( true );
+        else
+            pTrackDown->setEnabled( false );
 
         tagGroupBox->setTitle( i18n("Track") + QString().sprintf(" %02i",selectedTracks.at(0)) );
 
@@ -1021,21 +1105,27 @@ void CDOpener::trackChanged()
         lTrackTitle->setText( tags.at(selectedTracks.at(0))->title );
         pTrackTitleEdit->hide();
 
-        if( cArtist->currentText() == i18n("Various Artists") ) {
+        if( cArtist->currentText() == i18n("Various Artists") )
+        {
             lTrackArtist->setEnabled( true );
             lTrackArtist->setText( tags.at(selectedTracks.at(0))->artist );
             pTrackArtistEdit->hide();
-        } else {
+        }
+        else
+        {
             lTrackArtist->setEnabled( false );
             lTrackArtist->setText( cArtist->currentText() );
             pTrackArtistEdit->hide();
         }
 
-        if( cComposer->currentText() == i18n("Various Composer") ) {
+        if( cComposer->currentText() == i18n("Various Composer") )
+        {
             lTrackComposer->setEnabled( true );
             lTrackComposer->setText( tags.at(selectedTracks.at(0))->composer );
             pTrackComposerEdit->hide();
-        } else {
+        }
+        else
+        {
             lTrackComposer->setEnabled( false );
             lTrackComposer->setText( cComposer->currentText() );
             pTrackComposerEdit->hide();
@@ -1163,12 +1253,30 @@ void CDOpener::fadeOut()
 
 void CDOpener::fadeAnim()
 {
-    if( fadeMode == 1 ) fadeAlpha += 255.0f/50.0f*8.0f;
-    else if( fadeMode == 2 ) fadeAlpha -= 255.0f/50.0f*8.0f;
+    if( fadeMode == 1 )
+    {
+        fadeAlpha += 255.0f/50.0f*8.0f;
+    }
+    else if( fadeMode == 2 )
+    {
+        fadeAlpha -= 255.0f/50.0f*8.0f;
+    }
 
-    if( fadeAlpha <= 0.0f ) { fadeAlpha = 0.0f; fadeMode = 0; cdOpenerOverlayWidget->hide(); }
-    else if( fadeAlpha >= 255.0f ) { fadeAlpha = 255.0f; fadeMode = 0; }
-    else { fadeTimer.start( 50 ); }
+    if( fadeAlpha <= 0.0f )
+    {
+        fadeAlpha = 0.0f;
+        fadeMode = 0;
+        cdOpenerOverlayWidget->hide();
+    }
+    else if( fadeAlpha >= 255.0f )
+    {
+        fadeAlpha = 255.0f;
+        fadeMode = 0;
+    }
+    else
+    {
+        fadeTimer.start( 50 );
+    }
 
     QPalette newPalette = cdOpenerOverlayWidget->palette();
     newPalette.setBrush( QPalette::Window, brushSetAlpha( newPalette.window(), 192.0f/255.0f*fadeAlpha ) );
@@ -1231,6 +1339,7 @@ void CDOpener::addClicked()
             tags.at(0)->composer = cComposer->currentText();
             tags.at(0)->album = lAlbum->text();
             tags.at(0)->disc = iDisc->value();
+            tags.at(0)->discTotal = iDiscTotal->value();
             tags.at(0)->year = iYear->value();
             tags.at(0)->genre = cGenre->currentText();
             const long size = CD_FRAMESIZE_RAW * (cdda_track_lastsector(cdDrive,trackCount)-cdda_track_firstsector(cdDrive,1));
@@ -1245,10 +1354,13 @@ void CDOpener::addClicked()
             {
                 if( trackList->topLevelItem(i)->checkState(0) == Qt::Checked )
                 {
-                    if( cArtist->currentText() != i18n("Various Artists") ) tags.at(i+1)->artist = cArtist->currentText();
-                    if( cComposer->currentText() != i18n("Various Composer") ) tags.at(i+1)->composer = cComposer->currentText();
+                    if( cArtist->currentText() != i18n("Various Artists") )
+                        tags.at(i+1)->artist = cArtist->currentText();
+                    if( cComposer->currentText() != i18n("Various Composer") )
+                        tags.at(i+1)->composer = cComposer->currentText();
                     tags.at(i+1)->album = lAlbum->text();
                     tags.at(i+1)->disc = iDisc->value();
+                    tags.at(i+1)->discTotal = iDiscTotal->value();
                     tags.at(i+1)->year = iYear->value();
                     tags.at(i+1)->genre = cGenre->currentText();
                     const long size = CD_FRAMESIZE_RAW * (cdda_track_lastsector(cdDrive,i+1)-cdda_track_firstsector(cdDrive,i+1));
@@ -1262,7 +1374,7 @@ void CDOpener::addClicked()
 
         options->accepted();
 
-        emit addTracks( device, tracks, trackCount, tagList, conversionOptions );
+        emit addTracks( device, tracks, trackCount, tagList, conversionOptions, command );
 
         accept();
     }
