@@ -44,7 +44,7 @@ class PlayerWidget : public QWidget
      Q_OBJECT
 public:
     PlayerWidget( Phonon::MediaObject *mediaObject, int _track, QTreeWidgetItem *_treeWidgetItem, QWidget *parent = 0, Qt::WindowFlags f = 0 );
-    virtual ~PlayerWidget();
+    ~PlayerWidget();
 
     void trackChanged( int track );
     bool isPlaying() { return playing; }
@@ -97,11 +97,24 @@ public:
     CDOpener( Config *_config, const QString& _device, QWidget *parent = 0, Qt::WFlags f=0 );
 
     /** Destructor */
-    virtual ~CDOpener();
+    ~CDOpener();
 
     /** true if no CD was found (don't execute the dialog) */
     bool noCdFound;
 
+public slots:
+    /** Set the current profile */
+    void setProfile( const QString& profile );
+
+    /** Set the current format */
+    void setFormat( const QString& format );
+
+    /** Set the current output directory */
+    void setOutputDirectory( const QString& directory );
+
+    /** Set the command to execute after the conversion is complete */
+    void setCommand( const QString& _command );
+
 private:
     /** returns a list of devices holding audio cds plus a short description (track count) */
     QMap<QString,QString> cdDevices();
@@ -131,6 +144,8 @@ private:
     KLineEdit *lAlbum;
     /** A spinbox for entering or selecting the disc number */
     KIntSpinBox *iDisc;
+    /** A spinbox for entering or selecting the total disc number */
+    KIntSpinBox *iDiscTotal;
     /** A spinbox for entering or selecting the year of the album */
     KIntSpinBox *iYear;
     /** A combobox for entering or selecting the genre of the album */
@@ -203,6 +218,8 @@ private:
     float fadeAlpha;
     int fadeMode; // 1 = fade in, 2 = fade out
 
+    QString command;
+
     inline QBrush brushSetAlpha( QBrush brush, const int alpha )
     {
         QColor color = brush.color();
@@ -247,7 +264,7 @@ private slots:
     void fadeAnim();
 
 signals:
-    void addTracks( const QString& device, QList<int> trackList, int tracks, QList<TagData*> tagList, ConversionOptions *conversionOptions );
+    void addTracks( const QString& device, QList<int> trackList, int tracks, QList<TagData*> tagList, ConversionOptions *conversionOptions, const QString& command );
     void addDisc( const QString& device, ConversionOptions *conversionOptions );
     //void openCuesheetEditor( const QString& content );
 };
