@@ -19,6 +19,7 @@
 
 DirOpener::DirOpener( Config *_config, Mode _mode, QWidget *parent, Qt::WFlags f )
     : KDialog( parent, f ),
+    dialogAborted( false ),
     config( _config ),
     mode( _mode )
 {
@@ -44,7 +45,7 @@ DirOpener::DirOpener( Config *_config, Mode _mode, QWidget *parent, Qt::WFlags f
 
     QWidget *widget = new QWidget();
     QGridLayout *mainGrid = new QGridLayout( widget );
-    QGridLayout *topGrid = new QGridLayout( 0 );
+    QGridLayout *topGrid = new QGridLayout();
     mainGrid->addLayout( topGrid, 0, 0 );
     setMainWidget( widget );
 
@@ -96,11 +97,11 @@ DirOpener::DirOpener( Config *_config, Mode _mode, QWidget *parent, Qt::WFlags f
     fileTypes = new KListWidget( dirOpenerWidget );
     if( mode == Convert )
     {
-        codecList = config->pluginLoader()->formatList( PluginLoader::Decode, PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
+        codecList = config->pluginLoader()->formatList( PluginLoader::Decode, PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
     }
     else if( mode == ReplayGain )
     {
-        codecList = config->pluginLoader()->formatList( PluginLoader::ReplayGain, PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
+        codecList = config->pluginLoader()->formatList( PluginLoader::ReplayGain, PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
     }
     for( int i = 0; i < codecList.size(); i++ )
     {
@@ -145,18 +146,27 @@ DirOpener::DirOpener( Config *_config, Mode _mode, QWidget *parent, Qt::WFlags f
     adjustSize();
     options->hide();
 
-    // Prevent the dialog from beeing too wide because of the directory history
+
+    const KUrl url = KFileDialog::getExistingDirectoryUrl( uDirectory->url(), this );
+    if( !url.isEmpty() )
+        uDirectory->setUrl( url );
+    else
+        dialogAborted = true;
+
+        // Prevent the dialog from beeing too wide because of the directory history
     if( parent && width() > parent->width() )
-        resize( parent->width() - 10, sizeHint().height() );
-
-
-    KUrl url = KFileDialog::getExistingDirectoryUrl( uDirectory->url(), this );
-    if( !url.isEmpty() ) uDirectory->setUrl( url );
-    else emit reject(); // TODO reject properly
+        setInitialSize( QSize(parent->width()-10,sizeHint().height()) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "DirOpener" );
+    restoreDialogSize( group );
 }
 
 DirOpener::~DirOpener()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "DirOpener" );
+    saveDialogSize( group );
+}
 
 void DirOpener::proceedClicked()
 {
@@ -183,7 +193,6 @@ void DirOpener::addClicked()
             selectedCodecs += fileTypes->item(i)->text();
     }
 
-//     emit accept();
     if( mode == Convert )
     {
         ConversionOptions *conversionOptions = options->currentConversionOptions();
