@@ -18,6 +18,7 @@
 #include <KPushButton>
 #include <QLabel>
 #include <QLayout>
+#include <QBoxLayout>
 #include <KMessageBox>
 #include <KFileDialog>
 #include <QDir>
@@ -25,16 +26,13 @@
 
 FileOpener::FileOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     : KDialog( parent, f ),
+    dialogAborted( false ),
     config( _config )
 {
     setCaption( i18n("Add Files") );
     setWindowIcon( KIcon("audio-x-generic") );
     setButtons( 0 );
 
-    // Prevent the dialog from beeing too wide because of the directory history
-    if( parent && width() > parent->width() )
-        resize( parent->width() - 10, sizeHint().height() );
-
     QWidget *widget = new QWidget();
     setMainWidget( widget );
 
@@ -42,14 +40,15 @@ FileOpener::FileOpener( Config *_config, QWidget *parent, Qt::WFlags f )
 
     QStringList filterList;
     QStringList allFilter;
-    QStringList formats = config->pluginLoader()->formatList( PluginLoader::Decode, PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
-    for( int i=0; i<formats.count(); i++ )
+    const QStringList formats = config->pluginLoader()->formatList( PluginLoader::Decode, PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
+    foreach( QString format, formats )
     {
-        QString extensionFilter = config->pluginLoader()->codecExtensions(formats.at(i)).join(" *.");
-        if( extensionFilter.length() == 0 ) continue;
+        QString extensionFilter = config->pluginLoader()->codecExtensions(format).join(" *.");
+        if( extensionFilter.length() == 0 )
+            continue;
         extensionFilter = "*." + extensionFilter;
         allFilter += extensionFilter;
-        filterList += extensionFilter + "|" + i18n("%1 files",formats.at(i));
+        filterList += extensionFilter + "|" + i18n("%1 files",format.replace("/","\\/"));
     }
     filterList.prepend( allFilter.join(" ") + "|" + i18n("All supported files") );
     filterList += "*.*|" + i18n("All files");
@@ -58,7 +57,7 @@ FileOpener::FileOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     mainGrid->addWidget( options, 1, 0 );
 
     // add a horizontal box layout for the control elements
-    QHBoxLayout *controlBox = new QHBoxLayout( 0 );
+    QHBoxLayout *controlBox = new QHBoxLayout();
     mainGrid->addLayout( controlBox, 2, 0 );
     controlBox->addStretch();
 
@@ -78,11 +77,24 @@ FileOpener::FileOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     fileDialog->setMode( KFile::Files | KFile::ExistingOnly );
     connect( fileDialog, SIGNAL(accepted()), this, SLOT(fileDialogAccepted()) );
     connect( fileDialog, SIGNAL(rejected()), this, SLOT(reject()) );
-    fileDialog->show();
+    const int dialogReturnCode = fileDialog->exec();
+    if( dialogReturnCode == QDialog::Rejected )
+        dialogAborted = true;
+
+    // Prevent the dialog from beeing too wide because of the directory history
+    if( parent && width() > parent->width() )
+        setInitialSize( QSize(parent->width()-10,sizeHint().height()) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "FileOpener" );
+    restoreDialogSize( group );
 }
 
 FileOpener::~FileOpener()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "FileOpener" );
+    saveDialogSize( group );
+}
 
 void FileOpener::fileDialogAccepted()
 {
@@ -94,14 +106,24 @@ void FileOpener::fileDialogAccepted()
     urls.clear();
     urls = fileDialog->selectedUrls();
 
+    const bool canDecodeAac = config->pluginLoader()->canDecode( "m4a/aac" );
+    const bool canDecodeAlac = config->pluginLoader()->canDecode( "m4a/alac" );
+    const bool checkM4a = ( !canDecodeAac || !canDecodeAlac ) && canDecodeAac != canDecodeAlac;
+
     for( int i=0; i<urls.count(); i++ )
     {
-        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i) );
+        QString mimeType;
+        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i), &mimeType, checkM4a );
 
         if( !config->pluginLoader()->canDecode(codecName,&errorList) )
         {
             fileName = urls.at(i).pathOrUrl();
-            if( codecName.isEmpty() ) codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
+            if( codecName.isEmpty() )
+                codecName = mimeType;
+            if( codecName.isEmpty() )
+                codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
             if( problems.value(codecName).count() < 2 )
             {
                 problems[codecName] += QStringList();
@@ -166,7 +188,8 @@ void FileOpener::fileDialogAccepted()
         problemsDialog->exec();
     }
 
-    if( urls.count() <= 0 ) reject();
+    if( urls.count() <= 0 )
+        reject();
 }
 
 void FileOpener::okClickedSlot()
