@@ -25,16 +25,13 @@
 
 PlaylistOpener::PlaylistOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     : KDialog( parent, f ),
+    dialogAborted( false ),
     config( _config )
 {
     setCaption( i18n("Add playlist") );
     setWindowIcon( KIcon("view-media-playlist") );
     setButtons( 0 );
 
-    // Prevent the dialog from beeing too wide because of the directory history
-    if( parent && width() > parent->width() )
-        resize( parent->width() - 10, sizeHint().height() );
-
     QWidget *widget = new QWidget();
     setMainWidget( widget );
 
@@ -44,7 +41,7 @@ PlaylistOpener::PlaylistOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     mainGrid->addWidget( options, 1, 0 );
 
     // add a horizontal box layout for the control elements
-    QHBoxLayout *controlBox = new QHBoxLayout( 0 );
+    QHBoxLayout *controlBox = new QHBoxLayout();
     mainGrid->addLayout( controlBox, 2, 0 );
     controlBox->addStretch();
 
@@ -60,11 +57,24 @@ PlaylistOpener::PlaylistOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     fileDialog->setMode( KFile::File | KFile::ExistingOnly );
     connect( fileDialog, SIGNAL(accepted()), this, SLOT(fileDialogAccepted()) );
     connect( fileDialog, SIGNAL(rejected()), this, SLOT(reject()) );
-    fileDialog->show();
+    const int dialogReturnCode = fileDialog->exec();
+    if( dialogReturnCode == QDialog::Rejected )
+        dialogAborted = true;
+
+        // Prevent the dialog from beeing too wide because of the directory history
+    if( parent && width() > parent->width() )
+        setInitialSize( QSize(parent->width()-10,sizeHint().height()) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "PlaylistOpener" );
+    restoreDialogSize( group );
 }
 
 PlaylistOpener::~PlaylistOpener()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "PlaylistOpener" );
+    saveDialogSize( group );
+}
 
 void PlaylistOpener::fileDialogAccepted()
 {
@@ -98,14 +108,24 @@ void PlaylistOpener::fileDialogAccepted()
         playlistFile.close();
     }
 
+    const bool canDecodeAac = config->pluginLoader()->canDecode( "m4a/aac" );
+    const bool canDecodeAlac = config->pluginLoader()->canDecode( "m4a/alac" );
+    const bool checkM4a = ( !canDecodeAac || !canDecodeAlac ) && canDecodeAac != canDecodeAlac;
+
     for( int i=0; i<urls.count(); i++ )
     {
-        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i) );
+        QString mimeType;
+        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i), &mimeType, checkM4a );
 
         if( !config->pluginLoader()->canDecode(codecName,&errorList) )
         {
             fileName = urls.at(i).pathOrUrl();
-            if( codecName.isEmpty() ) codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
+            if( codecName.isEmpty() )
+                codecName = mimeType;
+            if( codecName.isEmpty() )
+                codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
             if( problems.value(codecName).count() < 2 )
             {
                 problems[codecName] += QStringList();
