@@ -59,7 +59,7 @@ UrlOpener::UrlOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     lineFrame->setFrameShadow( QFrame::Sunken );
     mainGrid->addWidget( lineFrame, 1, 0 );
 
-    QVBoxLayout *urlBox = new QVBoxLayout( 0 );
+    QVBoxLayout *urlBox = new QVBoxLayout();
     mainGrid->addLayout( urlBox, 2, 0 );
     urlBox->addSpacing( 60 );
     urlRequester = new KUrlRequester( widget );
@@ -72,13 +72,9 @@ UrlOpener::UrlOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     adjustSize();
     options->hide();
 
-    // Prevent the dialog from beeing too wide because of the directory history
-    if( parent && width() > parent->width() )
-        resize( parent->width() - 10, sizeHint().height() );
-
 
     // add a horizontal box layout for the control elements
-    QHBoxLayout *controlBox = new QHBoxLayout( 0 );
+    QHBoxLayout *controlBox = new QHBoxLayout();
     mainGrid->addLayout( controlBox, 5, 0 );
     controlBox->addStretch();
 
@@ -92,10 +88,22 @@ UrlOpener::UrlOpener( Config *_config, QWidget *parent, Qt::WFlags f )
     pCancel = new KPushButton( KIcon("dialog-cancel"), i18n("Cancel"), widget );
     controlBox->addWidget( pCancel );
     connect( pCancel, SIGNAL(clicked()), this, SLOT(reject()) );
+
+
+        // Prevent the dialog from beeing too wide because of the directory history
+    if( parent && width() > parent->width() )
+        setInitialSize( QSize(parent->width()-10,sizeHint().height()) );
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "UrlOpener" );
+    restoreDialogSize( group );
 }
 
 UrlOpener::~UrlOpener()
-{}
+{
+    KSharedConfig::Ptr conf = KGlobal::config();
+    KConfigGroup group = conf->group( "UrlOpener" );
+    saveDialogSize( group );
+}
 
 void UrlOpener::proceedClickedSlot()
 {
