@@ -2,22 +2,26 @@
 #ifndef OPTIONSDETAILED_H
 #define OPTIONSDETAILED_H
 
-#include <QWidget>
 #include <QCheckBox>
 #include <QDomDocument>
+#include <QMap>
+#include <QWidget>
 
-class Config;
-class OutputDirectory;
 class CodecPlugin;
+class Config;
 class ConversionOptions;
-// class CodecWidget;
+class FilterPlugin;
+class OutputDirectory;
+class CodecWidget;
+class FilterWidget;
 
-class QGridLayout;
-class QLabel;
 class KComboBox;
 class KPushButton;
+class QGridLayout;
+class QLabel;
 class QToolButton;
 
+
 /**
 	@author Daniel Faust <hessijames@gmail.com>
 */
@@ -31,21 +35,19 @@ public:
     void init();
 
     /** Return the current options */
-    ConversionOptions *currentConversionOptions();
+    ConversionOptions *currentConversionOptions( bool saveLastUsed = true );
     /** Set the current options */
     bool setCurrentConversionOptions( ConversionOptions *options );
 
     QString currentProfile();
-    void setCurrentProfile( const QString& profile );
+    bool setCurrentProfile( const QString& profile );
     QString currentFormat();
     void setCurrentFormat( const QString& format );
-    bool loadCustomProfile( const QString& profile );
+    void resetFilterOptions();
     void setReplayGainChecked( bool enabled );
-//     void setBpmEnabled( bool enabled ) { cBpm->setChecked(enabled); }
 
     bool isReplayGainEnabled( QString *toolTip = 0 );
     bool isReplayGainChecked();
-//     bool isBpmEnabled() { return cBpm->isChecked(); }
     CodecPlugin *getCurrentPlugin();
 
     OutputDirectory *outputDirectory; // this way it's easier to sync simple and detailed options
@@ -55,10 +57,12 @@ public:
 private:
     QGridLayout *grid;
     KComboBox *cFormat;
+    QLabel *lPlugin;
     KComboBox *cPlugin;
-    QWidget *wPlugin;
+    KPushButton *pConfigurePlugin;
+    CodecWidget *wPlugin;
+    QMap<FilterWidget*,FilterPlugin*> wFilter;
     QCheckBox *cReplayGain;
-//     QCheckBox *cBpm;
     QLabel *lEstimSize;
     KPushButton *pProfileSave;
     QToolButton *pProfileLoad;
@@ -78,6 +82,7 @@ public slots:
 private slots:
     void formatChanged( const QString& format );
     void encoderChanged( const QString& encoder );
+    void configurePlugin();
 
 signals:
     // connected to optionsSimple
