@@ -4,7 +4,7 @@
 // Description:
 //
 //
-// Author: Daniel Faust <hessijames@gmail.com>, (C) 2008
+// Author: Daniel Faust <hessijames@gmail.com>, (C) 2008 - 2012
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -14,19 +14,19 @@
 #include "config.h"
 #include "filelistitem.h"
 
-#include <kicon.h>
-#include <klocale.h>
-
-#include <qlabel.h>
-#include <qdatetime.h>
-
-#include <kpushbutton.h>
-#include <klineedit.h>
-#include <kcombobox.h>
-#include <knuminput.h>
-#include <ktextedit.h>
 #include "global.h"
 
+#include <QBoxLayout>
+#include <KComboBox>
+#include <KIcon>
+#include <KLineEdit>
+#include <KLocale>
+#include <KNumInput>
+#include <KPushButton>
+#include <KTextEdit>
+#include <QDateTime>
+#include <QLabel>
+
 
 // TODO use QPointer or QSharedPointer
 
@@ -54,9 +54,8 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     // the grid for all widgets in the main window
     QGridLayout* conversionOptionsGridLayout = new QGridLayout( conversionOptionsWidget );
     // generate the options input area
-    options = new Options( config, i18n("Choose your prefered output options and click on \"Apply\"!"), conversionOptionsWidget );
+    options = new Options( config, i18n("Select your desired output options and click on \"Ok\"."), conversionOptionsWidget );
     conversionOptionsGridLayout->addWidget( options, 0, 0 );
-//     connect( options, SIGNAL(optionsChanged()), this, SLOT(optionsChanged()) );
     conversionOptionsGridLayout->setRowStretch( 1, 1 );
 
     lEditOptions = new QLabel( "", conversionOptionsWidget );
@@ -97,24 +96,35 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( lTitleLabel, 1, 0 );
     lTitle = new KLineEdit( tagsWidget );
     titleBox->addWidget( lTitle );
-//     connect( lTitle, SIGNAL(textChanged(const QString&)), this, SLOT(titleChanged(const QString&)) );
-    pTitleEdit = new KPushButton( " ", tagsWidget );
-    pTitleEdit->setIcon( KIcon("edit-rename") );
-    pTitleEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
+    pTitleEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pTitleEdit->setFixedSize( pTitleEdit->sizeHint().height(), lTitle->sizeHint().height() );
+    pTitleEdit->setFlat( true );
+    pTitleEdit->setToolTip( i18n("Edit") );
     pTitleEdit->hide();
     titleBox->addWidget( pTitleEdit );
     connect( pTitleEdit, SIGNAL(clicked()), this, SLOT(editTitleClicked()) );
-    lNumberLabel = new QLabel( i18n("Track No.:"), tagsWidget );
-    titleBox->addWidget( lNumberLabel );
-    iNumber = new KIntSpinBox( 0, 999, 1, 1, tagsWidget );
-    titleBox->addWidget( iNumber );
-//     connect( iNumber, SIGNAL(valueChanged(int)), this, SLOT(numberChanged(int)) );
-    pNumberEdit = new KPushButton( " ", tagsWidget );
-    pNumberEdit->setIcon( KIcon("edit-rename") );
-    pNumberEdit->setFixedSize( iNumber->sizeHint().height(), iNumber->sizeHint().height() );
-    pNumberEdit->hide();
-    titleBox->addWidget( pNumberEdit );
-    connect( pNumberEdit, SIGNAL(clicked()), this, SLOT(editNumberClicked()) );
+    lTrackLabel = new QLabel( i18n("Track No.:"), tagsWidget );
+    titleBox->addWidget( lTrackLabel );
+    iTrack = new KIntSpinBox( 0, 999, 1, 1, tagsWidget );
+    titleBox->addWidget( iTrack );
+    pTrackEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pTrackEdit->setFixedSize( pTrackEdit->sizeHint().height(), iTrack->sizeHint().height() );
+    pTrackEdit->setFlat( true );
+    pTrackEdit->setToolTip( i18n("Edit") );
+    pTrackEdit->hide();
+    titleBox->addWidget( pTrackEdit );
+    connect( pTrackEdit, SIGNAL(clicked()), this, SLOT(editTrackClicked()) );
+    lTrackTotalLabel = new QLabel( i18nc("Track/Disc No. x of y","of"), tagsWidget );
+    titleBox->addWidget( lTrackTotalLabel );
+    iTrackTotal = new KIntSpinBox( 0, 999, 1, 1, tagsWidget );
+    titleBox->addWidget( iTrackTotal );
+    pTrackTotalEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pTrackTotalEdit->setFixedSize( pTrackTotalEdit->sizeHint().height(), iTrackTotal->sizeHint().height() );
+    pTrackTotalEdit->setFlat( true );
+    pTrackTotalEdit->setToolTip( i18n("Edit") );
+    pTrackTotalEdit->hide();
+    titleBox->addWidget( pTrackTotalEdit );
+    connect( pTrackTotalEdit, SIGNAL(clicked()), this, SLOT(editTrackTotalClicked()) );
 
     // add a horizontal box layout for the artist and the composer
     QHBoxLayout *artistBox = new QHBoxLayout();
@@ -124,10 +134,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( lArtistLabel, 2, 0 );
     lArtist = new KLineEdit( tagsWidget );
     artistBox->addWidget( lArtist );
-//     connect( lArtist, SIGNAL(textChanged(const QString&)), this, SLOT(artistChanged(const QString&)) );
-    pArtistEdit = new KPushButton( " ", tagsWidget );
-    pArtistEdit->setIcon( KIcon("edit-rename") );
-    pArtistEdit->setFixedSize( lArtist->sizeHint().height(), lArtist->sizeHint().height() );
+    pArtistEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pArtistEdit->setFixedSize( pArtistEdit->sizeHint().height(), lArtist->sizeHint().height() );
+    pArtistEdit->setFlat( true );
+    pArtistEdit->setToolTip( i18n("Edit") );
     pArtistEdit->hide();
     artistBox->addWidget( pArtistEdit );
     connect( pArtistEdit, SIGNAL(clicked()), this, SLOT(editArtistClicked()) );
@@ -135,10 +145,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     artistBox->addWidget( lComposerLabel );
     lComposer = new KLineEdit( tagsWidget );
     artistBox->addWidget( lComposer );
-//     connect( lComposer, SIGNAL(textChanged(const QString&)), this, SLOT(composerChanged(const QString&)) );
-    pComposerEdit = new KPushButton( " ", tagsWidget );
-    pComposerEdit->setIcon( KIcon("edit-rename") );
-    pComposerEdit->setFixedSize( lComposer->sizeHint().height(), lComposer->sizeHint().height() );
+    pComposerEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pComposerEdit->setFixedSize( pComposerEdit->sizeHint().height(), lComposer->sizeHint().height() );
+    pComposerEdit->setFlat( true );
+    pComposerEdit->setToolTip( i18n("Edit") );
     pComposerEdit->hide();
     artistBox->addWidget( pComposerEdit );
     connect( pComposerEdit, SIGNAL(clicked()), this, SLOT(editComposerClicked()) );
@@ -151,10 +161,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( lAlbumLabel, 3, 0 );
     lAlbum = new KLineEdit( tagsWidget );
     albumBox->addWidget( lAlbum );
-//     connect( lAlbum, SIGNAL(textChanged(const QString&)), this, SLOT(albumChanged(const QString&)) );
-    pAlbumEdit = new KPushButton( " ", tagsWidget );
-    pAlbumEdit->setIcon( KIcon("edit-rename") );
-    pAlbumEdit->setFixedSize( lAlbum->sizeHint().height(), lAlbum->sizeHint().height() );
+    pAlbumEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pAlbumEdit->setFixedSize( pAlbumEdit->sizeHint().height(), lAlbum->sizeHint().height() );
+    pAlbumEdit->setFlat( true );
+    pAlbumEdit->setToolTip( i18n("Edit") );
     pAlbumEdit->hide();
     albumBox->addWidget( pAlbumEdit );
     connect( pAlbumEdit, SIGNAL(clicked()), this, SLOT(editAlbumClicked()) );
@@ -167,21 +177,21 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( lDiscLabel, 4, 0 );
     iDisc = new KIntSpinBox( 0, 99, 1, 1, tagsWidget );
     albumdataBox->addWidget( iDisc );
-//     connect( iDisc, SIGNAL(valueChanged(int)), this, SLOT(discChanged(int)) );
-    pDiscEdit = new KPushButton( " ", tagsWidget );
-    pDiscEdit->setIcon( KIcon("edit-rename") );
-    pDiscEdit->setFixedSize( iDisc->sizeHint().height(), iDisc->sizeHint().height() );
+    pDiscEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pDiscEdit->setFixedSize( pDiscEdit->sizeHint().height(), iDisc->sizeHint().height() );
+    pDiscEdit->setFlat( true );
+    pDiscEdit->setToolTip( i18n("Edit") );
     pDiscEdit->hide();
     albumdataBox->addWidget( pDiscEdit );
     connect( pDiscEdit, SIGNAL(clicked()), this, SLOT(editDiscClicked()) );
-    lDiscTotalLabel = new QLabel( i18nc("Disc No. x of y","of"), tagsWidget );
+    lDiscTotalLabel = new QLabel( i18nc("Track/Disc No. x of y","of"), tagsWidget );
     albumdataBox->addWidget( lDiscTotalLabel );
     iDiscTotal = new KIntSpinBox( 0, 99, 1, 1, tagsWidget );
     albumdataBox->addWidget( iDiscTotal );
-//     connect( iDisc, SIGNAL(valueChanged(int)), this, SLOT(discChanged(int)) );
-    pDiscTotalEdit = new KPushButton( " ", tagsWidget );
-    pDiscTotalEdit->setIcon( KIcon("edit-rename") );
-    pDiscTotalEdit->setFixedSize( iDisc->sizeHint().height(), iDisc->sizeHint().height() );
+    pDiscTotalEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pDiscTotalEdit->setFixedSize( pDiscTotalEdit->sizeHint().height(), iDiscTotal->sizeHint().height() );
+    pDiscTotalEdit->setFlat( true );
+    pDiscTotalEdit->setToolTip( i18n("Edit") );
     pDiscTotalEdit->hide();
     albumdataBox->addWidget( pDiscTotalEdit );
     connect( pDiscTotalEdit, SIGNAL(clicked()), this, SLOT(editDiscTotalClicked()) );
@@ -190,10 +200,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     albumdataBox->addWidget( lYearLabel );
     iYear = new KIntSpinBox( 0, 99999, 1, QDate::currentDate().year(), tagsWidget );
     albumdataBox->addWidget( iYear );
-//     connect( iYear, SIGNAL(valueChanged(int)), this, SLOT(yearChanged(int)) );
-    pYearEdit = new KPushButton( " ", tagsWidget );
-    pYearEdit->setIcon( KIcon("edit-rename") );
-    pYearEdit->setFixedSize( iYear->sizeHint().height(), iYear->sizeHint().height() );
+    pYearEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pYearEdit->setFixedSize( pYearEdit->sizeHint().height(), iYear->sizeHint().height() );
+    pYearEdit->setFlat( true );
+    pYearEdit->setToolTip( i18n("Edit") );
     pYearEdit->hide();
     albumdataBox->addWidget( pYearEdit );
     connect( pYearEdit, SIGNAL(clicked()), this, SLOT(editYearClicked()) );
@@ -207,10 +217,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     cGenreCompletion->insertItems( tagEngine->genreList );
     cGenreCompletion->setIgnoreCase( tagsWidget );
     albumdataBox->addWidget( cGenre );
-//     connect( cGenre, SIGNAL(textChanged(const QString&)), this, SLOT(genreChanged(const QString&)) );
-    pGenreEdit = new KPushButton( " ", tagsWidget );
-    pGenreEdit->setIcon( KIcon("edit-rename") );
-    pGenreEdit->setFixedSize( cGenre->sizeHint().height(), cGenre->sizeHint().height() );
+    pGenreEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pGenreEdit->setFixedSize( pGenreEdit->sizeHint().height(), cGenre->sizeHint().height() );
+    pGenreEdit->setFlat( true );
+    pGenreEdit->setToolTip( i18n("Edit") );
     pGenreEdit->hide();
     albumdataBox->addWidget( pGenreEdit );
     connect( pGenreEdit, SIGNAL(clicked()), this, SLOT(editGenreClicked()) );
@@ -223,10 +233,10 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( lCommentLabel, 5, 0 );
     tComment = new KTextEdit( tagsWidget );
     commentBox->addWidget( tComment );
-//     connect( tComment, SIGNAL(textChanged()), this, SLOT(commentChanged()) );
-    pCommentEdit = new KPushButton( " ", tagsWidget );
-    pCommentEdit->setIcon( KIcon("edit-rename") );
-    pCommentEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
+    pCommentEdit = new KPushButton( KIcon("edit-rename"), " ", tagsWidget );
+    pCommentEdit->setFixedSize( pCommentEdit->sizeHint().height(), lTitle->sizeHint().height() );
+    pCommentEdit->setFlat( true );
+    pCommentEdit->setToolTip( i18n("Edit") );
     pCommentEdit->hide();
     commentBox->addWidget( pCommentEdit );
     connect( pCommentEdit, SIGNAL(clicked()), this, SLOT(editCommentClicked()) );
@@ -241,30 +251,21 @@ OptionsEditor::OptionsEditor( Config *_config, QWidget *parent )
     tagsGridLayout->addWidget( pEditTags, 7, 1, Qt::AlignHCenter );
     pEditTags->hide();
     connect( pEditTags, SIGNAL(clicked()), this, SLOT(editTagsClicked()) );
-
-
-
-    QWidget *infoWidget = new QWidget( this );
-    KPageWidgetItem *infoPage = addPage( infoWidget, i18n("Infos") );
-    infoPage->setIcon( KIcon( "dialog-information" ) );
-    QGridLayout *infoGridLayout = new QGridLayout( infoWidget );
-    lPipes = new QLabel( "", infoWidget );
-    infoGridLayout->addWidget( lPipes, 0, 0 );
 }
 
-
 OptionsEditor::~OptionsEditor()
 {}
 
-
 void OptionsEditor::setTagInputEnabled( bool enabled )
 {
     lTitleLabel->setEnabled( enabled );
     lTitle->setEnabled( enabled );
     pTitleEdit->hide();
-    lNumberLabel->setEnabled( enabled );
-    iNumber->setEnabled( enabled );
-    pNumberEdit->hide();
+    lTrackLabel->setEnabled( enabled );
+    iTrack->setEnabled( enabled );
+    lTrackTotalLabel->setEnabled( enabled );
+    iTrackTotal->setEnabled( enabled );
+    pTrackEdit->hide();
     lArtistLabel->setEnabled( enabled );
     lArtist->setEnabled( enabled );
     pArtistEdit->hide();
@@ -293,7 +294,8 @@ void OptionsEditor::setTagInputEnabled( bool enabled )
     if( !enabled )
     {
         lTitle->setText( "" );
-        iNumber->setValue( 0 );
+        iTrack->setValue( 0 );
+        iTrackTotal->setValue( 0 );
         lArtist->setText( "" );
         lComposer->setText( "" );
         lAlbum->setText( "" );
@@ -307,18 +309,36 @@ void OptionsEditor::setTagInputEnabled( bool enabled )
 
 void OptionsEditor::itemsSelected( QList<FileListItem*> items )
 {
-    applyChanges();
-
-    for( QList<FileListItem*>::Iterator it = items.begin(); it != items.end(); )
+    selectedItems.clear();
+    foreach( FileListItem *item, items )
     {
-        if( (*it)->state == FileListItem::Ripping || (*it)->state == FileListItem::Converting || (*it)->state == FileListItem::ApplyingReplayGain )
-            it = items.erase( it );
-        else
-            it++;
+        bool canEdit = false;
+        if( item )
+        {
+            switch( item->state )
+            {
+                case FileListItem::WaitingForConversion:
+                    canEdit = true;
+                    break;
+                case FileListItem::Ripping:
+                    break;
+                case FileListItem::Converting:
+                    break;
+                case FileListItem::ApplyingReplayGain:
+                    break;
+                case FileListItem::WaitingForAlbumGain:
+                    break;
+                case FileListItem::ApplyingAlbumGain:
+                    break;
+                case FileListItem::Stopped:
+                    canEdit = true;
+                    break;
+            }
+        }
+        if( canEdit )
+            selectedItems.append( item );
     }
 
-    selectedItems = items;
-
     // remove all cover widgets
     foreach( QLabel* label, lCovers )
     {
@@ -350,39 +370,15 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
 
     if( selectedItems.count() == 1 )
     {
+        FileListItem *item = selectedItems.first();
+
         setCaption( selectedItems.first()->url.fileName() );
-        // HACK ...but seems to work...
-        // FIXME directory does get set properly
-//         disconnect( options, SIGNAL(optionsChanged()), 0, 0 );
-//         options->setCurrentOptions( items.first()->options );
-//         connect( options, SIGNAL(optionsChanged()), this, SLOT(optionsChanged()) );
+
         const bool success = options->setCurrentConversionOptions( config->conversionOptionsManager()->getConversionOptions(selectedItems.first()->conversionOptionsId) );
         options->setEnabled( success );
-        // TODO show error message
+        // TODO show error message if !success
 
-        // info tab
-        ConversionOptions *conversionOptions = config->conversionOptionsManager()->getConversionOptions(items.first()->conversionOptionsId);
-        QString pipes_text;
-        if( conversionOptions )
-        {
-            pipes_text = i18n("Possible conversion strategies:");
-            const QString inputCodec = config->pluginLoader()->getCodecFromFile( items.first()->url );
-            QList<ConversionPipe> conversionPipes = config->pluginLoader()->getConversionPipes( inputCodec, conversionOptions->codecName, conversionOptions->pluginName );
-            for( int i=0; i<conversionPipes.size(); i++ )
-            {
-                QStringList pipe_str;
-
-                for( int j=0; j<conversionPipes.at(i).trunks.size(); j++ )
-                {
-                    pipe_str += QString("%1 %2 %3 (%4)").arg(conversionPipes.at(i).trunks.at(j).codecFrom).arg("->").arg(conversionPipes.at(i).trunks.at(j).codecTo).arg(conversionPipes.at(i).trunks.at(j).plugin->name());
-                }
-
-                pipes_text += "\n" + pipe_str.join(", ");
-            }
-        }
-        lPipes->setText( pipes_text );
-
-        if( items.first()->tags == 0 && !items.first()->local )
+        if( item->tags == 0 && !item->local )
         {
             setTagInputEnabled( false );
             lEditTags->setText( i18n("The tags could not be read, because this is not a local file.\n"
@@ -392,7 +388,7 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
             lEditTags->show();
             pEditTags->show();
         }
-        else if( items.first()->tags == 0 )
+        else if( item->tags == 0 )
         {
             setTagInputEnabled( false );
             lEditTags->setText( i18n("Reading the tags of this file failed.\n"
@@ -404,12 +400,12 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
         }
         else
         {
-            if( !items.first()->tags->coversRead )
+            if( !(item->tags->tagsRead & TagData::Covers) )
             {
-                items.first()->tags->covers = tagEngine->readCovers( items.first()->url );
-                items.first()->tags->coversRead = true;
+                item->tags->covers = tagEngine->readCovers( item->url );
+                item->tags->tagsRead = TagData::TagsRead(item->tags->tagsRead | TagData::Covers);
             }
-            foreach( CoverData* cover, items.first()->tags->covers )
+            foreach( CoverData* cover, item->tags->covers )
             {
                 QPixmap pixmap;
                 pixmap.loadFromData( cover->data );
@@ -432,37 +428,41 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
 
                 label->setPixmap( pixmap.scaledToHeight( 48, Qt::SmoothTransformation ) );
             }
-            lCoversLabel->setEnabled( items.first()->tags->covers.count() > 0 );
-            lTitle->setText( items.first()->tags->title );
-            iNumber->setValue( items.first()->tags->track );
-            lArtist->setText( items.first()->tags->artist );
-            lComposer->setText( items.first()->tags->composer );
-            lAlbum->setText( items.first()->tags->album );
-            iDisc->setValue( items.first()->tags->disc );
-            iDiscTotal->setValue( items.first()->tags->discTotal );
-            iYear->setValue( items.first()->tags->year );
-            cGenre->setEditText( items.first()->tags->genre );
-            tComment->setText( items.first()->tags->comment );
+            lCoversLabel->setEnabled( item->tags->covers.count() > 0 );
+            lTitle->setText( item->tags->title );
+            iTrack->setValue( item->tags->track );
+            iTrackTotal->setValue( item->tags->trackTotal );
+            lArtist->setText( item->tags->artist );
+            lComposer->setText( item->tags->composer );
+            lAlbum->setText( item->tags->album );
+            iDisc->setValue( item->tags->disc );
+            iDiscTotal->setValue( item->tags->discTotal );
+            iYear->setValue( item->tags->year );
+            cGenre->setEditText( item->tags->genre );
+            tComment->setText( item->tags->comment );
         }
     }
     else // selectedItems.count() > 1
     {
-        setCaption( i18n("%1 Files").arg(items.count()) );
-        QList<FileListItem*>::Iterator it = items.begin();
-        const int conversionOptionsId = (*it)->conversionOptionsId;
-        const QString title = ( (*it)->tags == 0 ) ? "" : (*it)->tags->title;
-        const int number = ( (*it)->tags == 0 ) ? 0 : (*it)->tags->track;
-        const QString artist = ( (*it)->tags == 0 ) ? "" : (*it)->tags->artist;
-        const QString composer = ( (*it)->tags == 0 ) ? "" : (*it)->tags->composer;
-        const QString album = ( (*it)->tags == 0 ) ? "" : (*it)->tags->album;
-        const int disc = ( (*it)->tags == 0 ) ? 0 : (*it)->tags->disc;
-        const int discTotal = ( (*it)->tags == 0 ) ? 0 : (*it)->tags->discTotal;
-        const int year = ( (*it)->tags == 0 ) ? 0 : (*it)->tags->year;
-        const QString genre = ( (*it)->tags == 0 ) ? "" : (*it)->tags->genre;
-        const QString comment = ( (*it)->tags == 0 ) ? "" : (*it)->tags->comment;
-        while( it != items.end() )
+        setCaption( i18n("%1 Files").arg(selectedItems.count()) );
+
+        FileListItem *firstItem = selectedItems.first();
+        const int     conversionOptionsId = firstItem->conversionOptionsId;
+        const QString title               = ( firstItem->tags == 0 ) ? "" : firstItem->tags->title;
+        const int     track               = ( firstItem->tags == 0 ) ? 0  : firstItem->tags->track;
+        const int     trackTotal          = ( firstItem->tags == 0 ) ? 0  : firstItem->tags->trackTotal;
+        const QString artist              = ( firstItem->tags == 0 ) ? "" : firstItem->tags->artist;
+        const QString composer            = ( firstItem->tags == 0 ) ? "" : firstItem->tags->composer;
+        const QString album               = ( firstItem->tags == 0 ) ? "" : firstItem->tags->album;
+        const int     disc                = ( firstItem->tags == 0 ) ? 0  : firstItem->tags->disc;
+        const int     discTotal           = ( firstItem->tags == 0 ) ? 0  : firstItem->tags->discTotal;
+        const int     year                = ( firstItem->tags == 0 ) ? 0  : firstItem->tags->year;
+        const QString genre               = ( firstItem->tags == 0 ) ? "" : firstItem->tags->genre;
+        const QString comment             = ( firstItem->tags == 0 ) ? "" : firstItem->tags->comment;
+
+        foreach( FileListItem *item, selectedItems )
         {
-            if( (*it)->conversionOptionsId != conversionOptionsId )
+            if( item->conversionOptionsId != conversionOptionsId )
             {
                 options->setEnabled( false );
                 lEditOptions->setText( i18n("You have selected multiple files with different conversion options.\nYou can change the options of all files by hitting the button below.") );
@@ -470,7 +470,7 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
                 pEditOptions->show();
             }
 
-            if( (*it)->tags == 0 )
+            if( item->tags == 0 )
             {
                 setTagInputEnabled( false );
                 lEditTags->setText( i18n("Reading the tags of one or more files failed.\n"
@@ -479,90 +479,93 @@ void OptionsEditor::itemsSelected( QList<FileListItem*> items )
                         "to read the tags a second time.") );
                 lEditTags->show();
                 pEditTags->show();
-                it++;
                 continue;
             }
 
-            if( title != (*it)->tags->title && lTitle->isEnabled() )
+            if( title != item->tags->title && lTitle->isEnabled() )
             {
                 lTitle->setEnabled( false );
                 lTitle->setText( "" );
                 pTitleEdit->show();
             }
-            if( number != (*it)->tags->track && iNumber->isEnabled() )
+            if( track != item->tags->track && iTrack->isEnabled() )
             {
-                iNumber->setEnabled( false );
-                iNumber->setValue( 1 );
-                pNumberEdit->show();
+                iTrack->setEnabled( false );
+                iTrack->setValue( 1 );
+                pTrackEdit->show();
             }
-            if( artist != (*it)->tags->artist && lArtist->isEnabled() )
+            if( trackTotal != item->tags->trackTotal && iTrackTotal->isEnabled() )
+            {
+                iTrackTotal->setEnabled( false );
+                iTrackTotal->setValue( 1 );
+                pTrackTotalEdit->show();
+            }
+            if( artist != item->tags->artist && lArtist->isEnabled() )
             {
                 lArtist->setEnabled( false );
                 lArtist->setText( "" );
                 pArtistEdit->show();
             }
-            if( composer != (*it)->tags->composer && lComposer->isEnabled() )
+            if( composer != item->tags->composer && lComposer->isEnabled() )
             {
                 lComposer->setEnabled( false );
                 lComposer->setText( "" );
                 pComposerEdit->show();
             }
-            if( album != (*it)->tags->album && lAlbum->isEnabled() )
+            if( album != item->tags->album && lAlbum->isEnabled() )
             {
                 lAlbum->setEnabled( false );
                 lAlbum->setText( "" );
                 pAlbumEdit->show();
             }
-            if( disc != (*it)->tags->disc && iDisc->isEnabled() )
+            if( disc != item->tags->disc && iDisc->isEnabled() )
             {
                 iDisc->setEnabled( false );
                 iDisc->setValue( 1 );
                 pDiscEdit->show();
             }
-            if( discTotal != (*it)->tags->discTotal && iDiscTotal->isEnabled() )
+            if( discTotal != item->tags->discTotal && iDiscTotal->isEnabled() )
             {
                 iDiscTotal->setEnabled( false );
                 iDiscTotal->setValue( 1 );
                 pDiscTotalEdit->show();
             }
-            if( year != (*it)->tags->year && iYear->isEnabled() )
+            if( year != item->tags->year && iYear->isEnabled() )
             {
                 iYear->setEnabled( false );
                 iYear->setValue( QDate::currentDate().year() );
                 pYearEdit->show();
             }
-            if( genre != (*it)->tags->genre && cGenre->isEnabled() )
+            if( genre != item->tags->genre && cGenre->isEnabled() )
             {
                 cGenre->setEnabled( false );
                 cGenre->setEditText( "" );
                 pGenreEdit->show();
             }
-            if( comment != (*it)->tags->comment && tComment->isEnabled() )
+            if( comment != item->tags->comment && tComment->isEnabled() )
             {
                 tComment->setEnabled( false );
                 tComment->setReadOnly( true );
                 tComment->setText( "" );
                 pCommentEdit->show();
             }
-            it++;
         }
 
         if( options->isEnabled() )
         {
-            // HACK ...but seems to work...
-            // FIXME directory does get set properly
-//             disconnect( options, SIGNAL(optionsChanged()), 0, 0 );
-//             options->setCurrentOptions( items.first()->options );
-//             connect( options, SIGNAL(optionsChanged()), this, SLOT(optionsChanged()) );
             const bool success = options->setCurrentConversionOptions( config->conversionOptionsManager()->getConversionOptions(conversionOptionsId) );
             options->setEnabled( success );
+            // TODO show error message if !success
         }
 
         if( lTitle->isEnabled() )
             lTitle->setText( title );
 
-        if( iNumber->isEnabled() )
-            iNumber->setValue( number );
+        if( iTrack->isEnabled() )
+            iTrack->setValue( track );
+
+        if( iTrackTotal->isEnabled() )
+            iTrackTotal->setValue( trackTotal );
 
         if( lArtist->isEnabled() )
             lArtist->setText( artist );
@@ -600,13 +603,6 @@ void OptionsEditor::setNextEnabled( bool enabled )
     enableButton( User1, enabled );
 }
 
-void OptionsEditor::itemRemoved( FileListItem *item )
-{
-    selectedItems.removeAll( item );
-
-    itemsSelected( selectedItems );
-}
-
 void OptionsEditor::applyChanges()
 {
     ConversionOptions *newConversionOptions = options->currentConversionOptions();
@@ -614,10 +610,7 @@ void OptionsEditor::applyChanges()
     for( int i=0; i<selectedItems.count(); i++ )
     {
         if( !selectedItems.at(i) )
-        {
-            // FIXME error message, null pointer for file list item
             continue;
-        }
 
         if( newConversionOptions && options->isEnabled() )
         {
@@ -633,8 +626,11 @@ void OptionsEditor::applyChanges()
             if( lTitle->isEnabled() )
                 selectedItems.at(i)->tags->title = lTitle->text();
 
-            if( iNumber->isEnabled() )
-                selectedItems.at(i)->tags->track = iNumber->value();
+            if( iTrack->isEnabled() )
+                selectedItems.at(i)->tags->track = iTrack->value();
+
+            if( iTrackTotal->isEnabled() )
+                selectedItems.at(i)->tags->trackTotal = iTrackTotal->value();
 
             if( lArtist->isEnabled() )
                 selectedItems.at(i)->tags->artist = lArtist->text();
@@ -688,10 +684,9 @@ void OptionsEditor::editTagsClicked()
         selectedItems.at(i)->tags = new TagData();
     }
 
-//     itemsSelected( selectedItems );
-
     editTitleClicked();
-    editNumberClicked();
+    editTrackClicked();
+    editTrackTotalClicked();
     editArtistClicked();
     editComposerClicked();
     editAlbumClicked();
@@ -714,15 +709,27 @@ void OptionsEditor::editTitleClicked()
     }
 }
 
-void OptionsEditor::editNumberClicked()
+void OptionsEditor::editTrackClicked()
 {
-    iNumber->setEnabled( true );
-    iNumber->setFocus();
-    pNumberEdit->hide();
+    iTrack->setEnabled( true );
+    iTrack->setFocus();
+    pTrackEdit->hide();
 
     if( selectedItems.count() > 0 && selectedItems.first() && selectedItems.first()->tags )
     {
-        iNumber->setValue( selectedItems.first()->tags->track );
+        iTrack->setValue( selectedItems.first()->tags->track );
+    }
+}
+
+void OptionsEditor::editTrackTotalClicked()
+{
+    iTrackTotal->setEnabled( true );
+    iTrackTotal->setFocus();
+    pTrackTotalEdit->hide();
+
+    if( selectedItems.count() > 0 && selectedItems.first() && selectedItems.first()->tags )
+    {
+        iTrackTotal->setValue( selectedItems.first()->tags->trackTotal );
     }
 }
 
