@@ -42,14 +42,9 @@ public:
 private:
     void setTagInputEnabled( bool enabled );
 
-
-    TagEngine *tagEngine;
-
-
     /** The widget, where we can set our output options */
     Options *options;
 
-
     /** A list of all covers */
     QLabel* lCoversLabel;
     QHBoxLayout *bCovers;
@@ -59,9 +54,13 @@ private:
     KLineEdit* lTitle;
     KPushButton* pTitleEdit;
     /** A spinbox for entering or selecting the track number */
-    QLabel* lNumberLabel;
-    KIntSpinBox* iNumber;
-    KPushButton* pNumberEdit;
+    QLabel* lTrackLabel;
+    KIntSpinBox* iTrack;
+    KPushButton* pTrackEdit;
+    /** A spinbox for entering or selecting the total track number */
+    QLabel* lTrackTotalLabel;
+    KIntSpinBox* iTrackTotal;
+    KPushButton* pTrackTotalEdit;
     /** A lineedit for entering the artist of a track */
     QLabel* lArtistLabel;
     KLineEdit* lArtist;
@@ -103,18 +102,16 @@ private:
     QLabel* lEditTags;
     KPushButton* pEditTags;
 
-
-    QLabel *lPipes;
-
     QList<FileListItem*> selectedItems;
 
     Config *config;
+    TagEngine *tagEngine;
+
 public slots:
     // connected to FileList
     void itemsSelected( QList<FileListItem*> );
     void setPreviousEnabled( bool );
     void setNextEnabled( bool );
-    void itemRemoved( FileListItem* );
 
 private slots:
     void applyChanges();
@@ -123,7 +120,8 @@ private slots:
     void editTagsClicked();
 
     void editTitleClicked();
-    void editNumberClicked();
+    void editTrackClicked();
+    void editTrackTotalClicked();
     void editArtistClicked();
     void editComposerClicked();
     void editAlbumClicked();
