@@ -6,6 +6,7 @@
 #include "codecproblems.h"
 
 #include <QLayout>
+#include <QBoxLayout>
 #include <QLabel>
 #include <QString>
 #include <QToolTip>
@@ -28,51 +29,58 @@ OptionsSimple::OptionsSimple( Config *_config, /*OptionsDetailed* _optionsDetail
     config( _config )
 {
     QGridLayout *grid = new QGridLayout( this );
-    grid->setContentsMargins( 6, 6, 6, 6 );
-    grid->setSpacing( 6 );
+    grid->setMargin( 10 );
+    grid->setSpacing( 10 );
 
-    QHBoxLayout *topBox = new QHBoxLayout();
-    grid->addLayout( topBox, 0, 0 );
+    QLabel *lQuality = new QLabel( i18n("Quality:"), this );
+    grid->addWidget( lQuality, 0, 0 );
 
-    QLabel *lQuality = new QLabel( i18n("Quality")+":", this );
-    topBox->addWidget( lQuality );
+    QHBoxLayout *topBoxQuality = new QHBoxLayout();
+    grid->addLayout( topBoxQuality, 0, 1 );
     cProfile = new KComboBox( this );
-    topBox->addWidget( cProfile );
+    topBoxQuality->addWidget( cProfile );
     connect( cProfile, SIGNAL(activated(int)), this, SLOT(profileChanged()) );
-    topBox->addSpacing( 3 );
+    topBoxQuality->addSpacing( 3 );
     pProfileRemove = new KPushButton( KIcon("edit-delete"), i18n("Remove"), this );
-    topBox->addWidget( pProfileRemove );
+    topBoxQuality->addWidget( pProfileRemove );
     pProfileRemove->setToolTip( i18n("Remove the selected profile") );
     pProfileRemove->hide();
     connect( pProfileRemove, SIGNAL(clicked()), this, SLOT(profileRemove()) );
     pProfileInfo = new KPushButton( KIcon("dialog-information"), i18n("Info"), this );
-    topBox->addWidget( pProfileInfo );
+    topBoxQuality->addWidget( pProfileInfo );
     pProfileInfo->setToolTip( i18n("Information about the selected profile") );
 //     cProfile->setFixedHeight( pProfileInfo->minimumSizeHint().height() );
     connect( pProfileInfo, SIGNAL(clicked()), this, SLOT(profileInfo()) );
-    topBox->addSpacing( 18 );
+    topBoxQuality->addStretch( );
 
-    QLabel *lFormat = new QLabel( i18n("Output format")+":", this );
-    topBox->addWidget( lFormat );
+    topBoxQuality->addSpacing( 10 );
+
+    QLabel *lFormat = new QLabel( i18n("Format:"), this );
+    grid->addWidget( lFormat, 0, 2 );
+
+    QHBoxLayout *topBoxFormat = new QHBoxLayout();
+    grid->addLayout( topBoxFormat, 0, 3 );
     cFormat = new KComboBox( this );
-    topBox->addWidget( cFormat );
+    topBoxFormat->addWidget( cFormat );
 //     connect( cFormat, SIGNAL(activated(int)), this, SLOT(formatChanged()) );
     connect( cFormat, SIGNAL(activated(int)), this, SLOT(somethingChanged()) );
-    topBox->addSpacing( 3 );
+    topBoxFormat->addSpacing( 3 );
     pFormatInfo = new KPushButton( KIcon("dialog-information"), i18n("Info"), this );
-    topBox->addWidget( pFormatInfo );
+    topBoxFormat->addWidget( pFormatInfo );
     pFormatInfo->setToolTip( i18n("Information about the selected file format") );
 //     cFormat->setFixedHeight( pFormatInfo->minimumSizeHint().height() );
     connect( pFormatInfo, SIGNAL(clicked()), this, SLOT(formatInfo()) );
-    topBox->addSpacing( 3 );
-    QLabel *formatHelp = new QLabel( "<a href=\"format-help\">" + i18n("More") + "</a>", this );
-    topBox->addWidget( formatHelp );
+    topBoxFormat->addSpacing( 3 );
+    QLabel *formatHelp = new QLabel( "<a href=\"format-help\">" + i18n("More formats...") + "</a>", this );
+    topBoxFormat->addWidget( formatHelp );
     connect( formatHelp, SIGNAL(linkActivated(const QString&)), this, SLOT(showHelp()) );
-    topBox->addStretch( );
+    topBoxFormat->addStretch( );
 
-    QHBoxLayout *middleBox = new QHBoxLayout( );
-    grid->addLayout( middleBox, 1, 0 );
+    QLabel *lOutput = new QLabel( i18n("Destination:"), this );
+    grid->addWidget( lOutput, 1, 0 );
 
+    QHBoxLayout *middleBox = new QHBoxLayout();
+    grid->addLayout( middleBox, 1, 1, 1, 3 );
     outputDirectory = new OutputDirectory( config, this );
     middleBox->addWidget( outputDirectory );
     connect( outputDirectory, SIGNAL(modeChanged(int)), this, SLOT(outputDirectoryChanged()) );
@@ -85,24 +93,22 @@ OptionsSimple::OptionsSimple( Config *_config, /*OptionsDetailed* _optionsDetail
     lEstimSize->hide(); // hide for now because most plugins report inaccurate data
     estimSizeBox->addWidget( lEstimSize );
 
-    QHBoxLayout *optionalBox = new QHBoxLayout();
-    grid->addLayout( optionalBox, 3, 0 );
     QLabel *lOptional = new QLabel( i18n("Optional:") );
-    optionalBox->addWidget( lOptional );
-    optionalBox->addSpacing( 12 );
+    grid->addWidget( lOptional, 3, 0 );
+
+    QHBoxLayout *optionalBox = new QHBoxLayout();
+    grid->addLayout( optionalBox, 3, 1 );
     cReplayGain = new QCheckBox( i18n("Calculate Replay Gain tags"), this );
     optionalBox->addWidget( cReplayGain );
     connect( cReplayGain, SIGNAL(toggled(bool)), this, SLOT(somethingChanged()) );
-    optionalBox->addSpacing( 12 );
-//     cBpm = new QCheckBox( i18n("Calculate BPM tags"), this );
-//     cBpm->hide();
-//     optionalBox->addWidget( cBpm );
-//     connect( cBpm, SIGNAL(toggled(bool)), this, SLOT(somethingChanged()) );
     optionalBox->addStretch();
 
     QLabel *lInfo = new QLabel( text, this );
-    grid->addWidget( lInfo, 4, 0, Qt::AlignVCenter | Qt::AlignCenter );
+    grid->addWidget( lInfo, 4, 0, 1, 4, Qt::AlignVCenter | Qt::AlignCenter );
     grid->setRowStretch( 4, 1 );
+
+    grid->setColumnStretch( 1, 1 );
+    grid->setColumnStretch( 3, 1 );
 }
 
 OptionsSimple::~OptionsSimple()
@@ -120,7 +126,6 @@ void OptionsSimple::setReplayGainEnabled( bool enabled, const QString& toolTip )
     if( !enabled )
     {
         QPalette notificationPalette = cReplayGain->palette();
-//         notificationPalette.setColor( QPalette::Disabled, QPalette::WindowText, QColor(181,96,101) );
         notificationPalette.setColor( QPalette::Disabled, QPalette::WindowText, QColor(174,127,130) );
         cReplayGain->setPalette( notificationPalette );
     }
@@ -175,97 +180,104 @@ void OptionsSimple::updateProfiles()
 
 void OptionsSimple::profileInfo()
 {
-    QString sProfileString = cProfile->currentText();
+    const QString sProfileString = cProfile->currentText();
+
+    QString info;
 
     if( sProfileString == i18n("Very low") )
     {
-        KMessageBox::information( this,
-            i18n("This produces sound files of a very low quality.\nThat can be useful if you have a mobile device where your storage space is limited. It is not recommended to save your music in this quality without a copy with higher quality."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files with a very low quality can be useful if you have a mobile device where your storage space is limited.\nIt is not recommended to save your music in this quality without a copy of higher quality.");
     }
     else if( sProfileString == i18n("Low") )
     {
-        KMessageBox::information( this,
-            i18n("This produces sound files of a low quality.\nThat can be useful if you have a mobile device where your storage space is limited. It is not recommended to save your music in this quality without a copy with higher quality."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files with a low quality can be useful if you have a mobile device where your storage space is limited.\nIt is not recommended to save your music in this quality without a copy of higher quality.");
     }
     else if( sProfileString == i18n("Medium") )
     {
-        KMessageBox::information( this,
-            i18n("This produces sound files of a medium quality.\nIf your disc space is limited, you can use this to save your music."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files with a medium quality is a compromise between quality and file size.\nMost people might not hear much of a difference to the original files but you should only use it to save music if your storage space is limited.");
     }
     else if( sProfileString == i18n("High") )
     {
-        KMessageBox::information( this,
-            i18n("This produces sound files of a high quality.\nIf you have enough disc space available, you can use this to save your music."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files with a high quality is a good choice if you have enough storage space available. You can use this to save your music.");
     }
     else if( sProfileString == i18n("Very high") )
     {
-        KMessageBox::information( this,
-            i18n("This produces sound files of a very high quality.\nYou should only use this, if you are a quality freak and have enough disc space available."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files with a very high quality is fine if you have enough storage space.");
     }
     else if( sProfileString == i18n("Lossless") )
     {
-        KMessageBox::information( this,
-            i18n("This produces files, that have exact the same quality as the input files.\nThis files are very big and definitely only for quality freaks."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("Encoding files lossless will preserve the quality of the original file.\nIt is only then useful if the original file has a good quality (e.g. audio CD).\nThe file size will be big, so you should only use it if you have enough storage space.");
     }
     else if( sProfileString == i18n("Hybrid") )
     {
-        KMessageBox::information( this,
-            i18n("This produces two files. One lossy compressed playable file and one correction file.\nBoth files together result in a file that is equivalent to the input file."),
-            i18n("Profile info for %1",sProfileString) );
+        // info = i18n("This produces two files. One lossy compressed playable file and one correction file.\nBoth files together result in a file that is equivalent to the input file.");
     }
     else if( sProfileString == i18n("User defined") )
     {
-        KMessageBox::information( this,
-            i18n("You can define your own profile in the \"detailed\" tab."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("You can define your own profile in the \"Detailed\" tab.");
     }
     else // the info button is hidden when showing user defined profiles
     {
-        KMessageBox::information( this,
-            i18n("This is a user defined profile."),
-            i18n("Profile info for %1",sProfileString) );
+        info = i18n("This is a user defined profile.");
     }
+
+    KMessageBox::information( this, info, i18n("Profile info for %1",sProfileString) );
 }
 
 void OptionsSimple::profileRemove()
 {
-    int ret = KMessageBox::questionYesNo( this, i18n("Do you really want to remove the profile: %1").arg(cProfile->currentText()), i18n("Remove profile?") );
+    const QString profileName = cProfile->currentText();
+
+    const int ret = KMessageBox::questionYesNo( this, i18n("Do you really want to remove the profile: %1").arg(profileName), i18n("Remove profile?") );
     if( ret == KMessageBox::Yes )
     {
-        for( int i=0; i<config->data.profiles.count(); i++ )
+        QDomDocument list("soundkonverter_profilelist");
+
+        QFile listFile( KStandardDirs::locateLocal("data","soundkonverter/profiles.xml") );
+        if( listFile.open( QIODevice::ReadOnly ) )
         {
-            if( config->data.profiles.at(i).profileName == cProfile->currentText() )
+            if( list.setContent( &listFile ) )
             {
-                QFile::remove( KStandardDirs::locateLocal("data",QString("soundkonverter/profiles/")) + config->data.profiles.at(i).fileName );
-                config->data.profiles.removeAt(i);
-                updateProfiles();
-                emit customProfilesEdited();
-                return;
+                QDomElement root = list.documentElement();
+                if( root.nodeName() == "soundkonverter" && root.attribute("type") == "profilelist" )
+                {
+                    QDomElement profileElement;
+                    QDomNodeList conversionOptionsElements = root.elementsByTagName("conversionOptions");
+                    for( int i=0; i<conversionOptionsElements.count(); i++ )
+                    {
+                        if( conversionOptionsElements.at(i).toElement().attribute("profileName") == profileName )
+                        {
+                            delete config->data.profiles[profileName];
+                            config->data.profiles.remove(profileName);
+                            root.removeChild(conversionOptionsElements.at(i));
+                            break;
+                        }
+                    }
+                }
             }
+            listFile.close();
+        }
+
+        if( listFile.open( QIODevice::WriteOnly ) )
+        {
+            updateProfiles();
+            emit customProfilesEdited();
+
+            QTextStream stream(&listFile);
+            stream << list.toString();
+            listFile.close();
         }
     }
 }
 
 void OptionsSimple::formatInfo()
 {
-    QString format = cFormat->currentText();
-    QString info = config->pluginLoader()->codecDescription(format);
+    const QString format = cFormat->currentText();
+    const QString info = config->pluginLoader()->codecDescription(format);
 
     if( !info.isEmpty() )
     {
         KMessageBox::information( this, info, i18n("Format info for %1",format), QString(), KMessageBox::Notify | KMessageBox::AllowLink );
-/*        QMessageBox *messageBox = new QMessageBox( this );
-        messageBox->setIcon( QMessageBox::Information );
-        messageBox->setWindowTitle( i18n("Format info for %1",format) );
-        messageBox->setText( info.replace("\n","<br>") );
-        messageBox->setTextFormat( Qt::RichText );
-        messageBox->exec();*/
     }
     else
     {
@@ -296,23 +308,25 @@ void OptionsSimple::profileChanged()
     }
     else if( profile == i18n("User defined") )
     {
-        cFormat->addItems( config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid)) );
+        cFormat->addItems( config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid)) );
     }
     else
     {
-        for( int i=0; i<config->data.profiles.count(); i++ )
+        foreach( const QString profileName, config->data.profiles.keys() )
         {
-            if( config->data.profiles.at(i).profileName == profile )
+            if( profileName == profile )
             {
-                cFormat->addItem( config->data.profiles.at(i).codecName );
-                QDomElement root = config->data.profiles.at(i).data.documentElement();
-                QDomElement outputOptions = root.elementsByTagName("outputOptions").at(0).toElement();
-                outputDirectory->setMode( (OutputDirectory::Mode)outputOptions.attribute("mode").toInt() );
-                outputDirectory->setDirectory( outputOptions.attribute("directory") );
-                QDomElement features = root.elementsByTagName("features").at(0).toElement();
-                cReplayGain->setChecked( features.attribute("replaygain").toInt() );
-                pProfileRemove->show();
-                pProfileInfo->hide();
+                ConversionOptions *conversionOptions = config->data.profiles.value( profileName );
+                if( conversionOptions )
+                {
+                    cFormat->addItem( conversionOptions->codecName );
+                    outputDirectory->setMode( (OutputDirectory::Mode)conversionOptions->outputDirectoryMode );
+                    outputDirectory->setDirectory( conversionOptions->outputDirectory );
+                    cReplayGain->setChecked( conversionOptions->replaygain );
+                    pProfileRemove->show();
+                    pProfileInfo->hide();
+                }
+                break;
             }
         }
     }
@@ -349,21 +363,14 @@ void OptionsSimple::profileChanged()
 
 void OptionsSimple::outputDirectoryChanged()
 {
-    if( config->customProfiles().indexOf(cProfile->currentText()) != -1 )
+    const QString profileName = cProfile->currentText();
+    ConversionOptions *conversionOptions = config->data.profiles.value( profileName );
+    if( conversionOptions )
     {
-        for( int i=0; i<config->data.profiles.count(); i++ )
+        if( conversionOptions->outputDirectoryMode != outputDirectory->mode() || conversionOptions->outputDirectory != outputDirectory->directory() )
         {
-            if( config->data.profiles.at(i).profileName == cProfile->currentText() )
-            {
-                QDomElement root = config->data.profiles.at(i).data.documentElement();
-                QDomElement outputOptions = root.elementsByTagName("outputOptions").at(0).toElement();
-                if( outputOptions.attribute("mode").toInt() != outputDirectory->mode() || outputOptions.attribute("directory") != outputDirectory->directory() )
-                {
-                    cProfile->setCurrentIndex( cProfile->findText(i18n("User defined")) );
-                    profileChanged();
-                }
-                return;
-            }
+            cProfile->setCurrentIndex( cProfile->findText(i18n("User defined")) );
+            profileChanged();
         }
     }
 }
