@@ -1,16 +1,12 @@
 
 #include "outputdirectory.h"
-// #include "filelist.h"
 #include "filelistitem.h"
 #include "core/conversionoptions.h"
-// #include "tagengine.h"
 #include "config.h"
 
 #include <QLayout>
-#include <QToolTip>
 #include <QDir>
 #include <QFileInfo>
-#include <QRegExp>
 #include <QString>
 #include <QStringList>
 #include <QLabel>
@@ -18,7 +14,6 @@
 #include <QProcess>
 
 #include <KLocale>
-#include <KMessageBox>
 #include <KFileDialog>
 #include <KComboBox>
 #include <KLineEdit>
@@ -32,14 +27,11 @@ OutputDirectory::OutputDirectory( Config *_config, QWidget *parent )
     config( _config )
 {
     QGridLayout *grid = new QGridLayout( this );
-    grid->setContentsMargins( 0, 0, 0, 0 );
+    grid->setMargin( 0 );
 
     QHBoxLayout *box = new QHBoxLayout( );
     grid->addLayout( box, 0, 0 );
 
-    QLabel *lOutput = new QLabel( i18n("Output")+":", this );
-    box->addWidget( lOutput );
-
     cMode = new KComboBox( this );
     cMode->addItem( i18n("By meta data") );
     cMode->addItem( i18n("Source directory") );
@@ -63,7 +55,6 @@ OutputDirectory::OutputDirectory( Config *_config, QWidget *parent )
     pDirGoto->setToolTip( i18n("Open the output directory with Dolphin") );
     connect( pDirGoto, SIGNAL(clicked()), this, SLOT(gotoDir()) );
 
-    modeJustChanged = false;
     setMode( (OutputDirectory::Mode)config->data.general.lastOutputDirectoryMode );
 }
 
@@ -125,7 +116,7 @@ QString OutputDirectory::filesystemForDirectory( const QString& dir )
     return mp->mountType();
 }
 
-KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QString extension, bool fast )
+KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, const QStringList& usedOutputNames )
 {
     ConversionOptions *options = config->conversionOptionsManager()->getConversionOptions(fileListItem->conversionOptionsId);
     if( !options )
@@ -134,7 +125,8 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
     QString path;
     KUrl url;
 
-    if( extension.isEmpty() && config->pluginLoader()->codecExtensions(options->codecName).count() > 0 )
+    QString extension;
+    if( config->pluginLoader()->codecExtensions(options->codecName).count() > 0 )
         extension = config->pluginLoader()->codecExtensions(options->codecName).first();
 
     if( extension.isEmpty() )
@@ -146,13 +138,6 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
     else
         fileName =  QString().sprintf("%02i",fileListItem->tags->track) + " - " + fileListItem->tags->artist + " - " + fileListItem->tags->title + "." + extension;
 
-    // if the user wants to change the output directory/file name per file! TODO
-//     if( !fileListItem->options.outputFilePathName.isEmpty() ) {
-//         path = uniqueFileName( changeExtension(fileListItem->options.outputFilePathName,extension) );
-//         if( config->data.general.useVFATNames || options->outputFilesystem == "vfat" ) path = vfatPath( path );
-//         return path;
-//     }
-
     if( options->outputDirectoryMode == Specify )
     {
         path = options->outputDirectory+"/"+fileName;
@@ -166,7 +151,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
         url = changeExtension( KUrl(path), extension );
 
         if( config->data.general.conflictHandling == Config::Data::General::NewFileName )
-            url = uniqueFileName( url );
+            url = uniqueFileName( url, usedOutputNames );
 
         return url;
     }
@@ -175,18 +160,24 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
         path = options->outputDirectory;
 
         // TODO a little bit redundant, adding %f if file name wasn't set properly
+        // TODO these restrictions could be a little bit over the top
         if( path.right(1) == "/" )
             path += "%f";
         else if( path.lastIndexOf(QRegExp("%[abcdfgnpty]")) < path.lastIndexOf("/") )
             path += "/%f";
-//         else if( path.lastIndexOf(QRegExp("%[aAbBcCdDfFgGnNpPtTyY]{1,1}")) < path.lastIndexOf("/") ) path += "/%f";
 
         const int fileNameBegin = path.lastIndexOf("/");
-        if( fileListItem->tags == 0 || ( path.mid(fileNameBegin).contains("%n") && fileListItem->tags->track == 0 ) || ( path.mid(fileNameBegin).contains("%t") && fileListItem->tags->title.isEmpty() ) )
+        if( fileListItem->tags == 0 ||
+            ( path.mid(fileNameBegin).contains("%n") && fileListItem->tags->track == 0 ) ||
+            ( path.mid(fileNameBegin).contains("%t") && fileListItem->tags->title.isEmpty() )
+          )
         {
             path = path.left( fileNameBegin ) + "/%f";
         }
 
+        path.replace( "\\[", "$quared_bracket_open$" );
+        path.replace( "\\]", "$quared_bracket_close$" );
+
         QRegExp reg( "\\[(.*)%([abcdfgnpty])(.*)\\]" );
         reg.setMinimal( true );
         while( path.indexOf(reg) != -1 )
@@ -213,6 +204,9 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
             }
         }
 
+        path.replace( "$quared_bracket_open$", "[" );
+        path.replace( "$quared_bracket_close$", "]" );
+
         while( path.contains("//") )
             path.replace( "//", "/" );
 
@@ -273,7 +267,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
         url = KUrl( path + "." + extension );
 
         if( config->data.general.conflictHandling == Config::Data::General::NewFileName )
-            url = uniqueFileName( url );
+            url = uniqueFileName( url, usedOutputNames );
 
         return url;
     }
@@ -298,7 +292,7 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
         url = changeExtension( KUrl(path), extension );
 
         if( config->data.general.conflictHandling == Config::Data::General::NewFileName )
-            url = uniqueFileName( url );
+            url = uniqueFileName( url, usedOutputNames );
 
         return url;
     }
@@ -306,18 +300,10 @@ KUrl OutputDirectory::calcPath( FileListItem *fileListItem, Config *config, QStr
     {
         path = fileListItem->url.toLocalFile();
 
-        const QString outputFilesystem = fast ? "" : filesystemForDirectory(path);
-
-        if( config->data.general.useVFATNames || outputFilesystem == "vfat" )
-            path = vfatPath( path );
-
-        if( outputFilesystem == "ntfs" )
-            path = ntfsPath( path );
-
         url = changeExtension( KUrl(path), extension );
 
         if( config->data.general.conflictHandling == Config::Data::General::NewFileName )
-            url = uniqueFileName( url );
+            url = uniqueFileName( url, usedOutputNames );
 
         return url;
     }
@@ -502,20 +488,21 @@ void OutputDirectory::gotoDir()
 
 void OutputDirectory::modeChangedSlot( int mode )
 {
-    modeJustChanged = true;
+    config->data.general.lastOutputDirectoryMode = mode;
+
+    disconnect( cDir, SIGNAL(editTextChanged(const QString&)), 0, 0 );
 
     updateMode( (Mode)mode );
 
-    emit modeChanged( mode );
+    connect( cDir, SIGNAL(editTextChanged(const QString&)),  this, SLOT(directoryChangedSlot(const QString&)) );
 
-    modeJustChanged = false;
+    emit modeChanged( mode );
 }
 
 void OutputDirectory::updateMode( Mode mode )
 {
     if( mode == MetaData )
     {
-//         if( config->data.general.metaDataOutputDirectory.isEmpty() ) config->data.general.metaDataOutputDirectory = QDir::homeDirPath() + "/soundKonverter/%b/%d - %n - %a - %t";
         cDir->clear();
         cDir->addItems( config->data.general.lastMetaDataOutputDirectoryPaths );
         cDir->setEditText( config->data.general.metaDataOutputDirectory );
@@ -523,8 +510,10 @@ void OutputDirectory::updateMode( Mode mode )
         pDirSelect->setEnabled( true );
         pDirGoto->setEnabled( true );
         cMode->setToolTip( i18n("Name all converted files according to the specified pattern") );
-//         cDir->setToolTip( i18n("<p>The following strings are wildcards, that will be replaced by the information in the meta data:</p><p>%a - Artist<br>%b - Album<br>%c - Comment<br>%d - Disc number<br>%g - Genre<br>%n - Track number<br>%p - Composer<br>%t - Title<br>%y - Year<br>%f - Original file name<p>") );
-        cDir->setToolTip( i18n("The following strings are wildcards, that will be replaced\nby the information in the meta data:\n\n%a - Artist\n%b - Album\n%c - Comment\n%d - Disc number\n%g - Genre\n%n - Track number\n%p - Composer\n%t - Title\n%y - Year\n%f - Original file name") );
+        cDir->setToolTip( i18n("The following strings are wildcards that will be replaced\nby the information in the meta data:\n\n"
+                "%a - Artist\n%b - Album\n%c - Comment\n%d - Disc number\n%g - Genre\n%n - Track number\n%p - Composer\n%t - Title\n%y - Year\n%f - Original file name\n\n"
+                "You may parenthesize these wildcards and surrounding characters with squared brackets ('[' and ']')\nso they will be ignored if the replacement value is empty.\n"
+                "In order to use squared brackets you will have to escape them with a backslash ('\\[' and '\\]').") );
     }
     else if( mode == Source )
     {
@@ -538,7 +527,6 @@ void OutputDirectory::updateMode( Mode mode )
     }
     else if( mode == Specify )
     {
-//         if( config->data.general.specifyOutputDirectory.isEmpty() ) config->data.general.specifyOutputDirectory = QDir::homeDirPath() + "/soundKonverter";
         cDir->clear();
         cDir->addItems( config->data.general.lastNormalOutputDirectoryPaths );
         cDir->setEditText( config->data.general.specifyOutputDirectory );
@@ -550,7 +538,6 @@ void OutputDirectory::updateMode( Mode mode )
     }
     else if( mode == CopyStructure )
     {
-//         if( config->data.general.copyStructureOutputDirectory.isEmpty() ) config->data.general.copyStructureOutputDirectory = QDir::homeDirPath() + "/soundKonverter";
         cDir->clear();
         cDir->addItems( config->data.general.lastNormalOutputDirectoryPaths );
         cDir->setEditText( config->data.general.copyStructureOutputDirectory );
@@ -568,22 +555,14 @@ void OutputDirectory::updateMode( Mode mode )
 
 void OutputDirectory::directoryChangedSlot( const QString& directory )
 {
-    if( modeJustChanged ) {
-        modeJustChanged = false;
-        return;
-    }
-
     Mode mode = (Mode)cMode->currentIndex();
 
-    if( mode == MetaData ) {
+    if( mode == MetaData )
         config->data.general.metaDataOutputDirectory = directory;
-    }
-    else if( mode == Specify ) {
+    else if( mode == Specify )
         config->data.general.specifyOutputDirectory = directory;
-    }
-    else if( mode == CopyStructure ) {
+    else if( mode == CopyStructure )
         config->data.general.copyStructureOutputDirectory = directory;
-    }
 
     emit directoryChanged( directory );
 }
@@ -625,10 +604,3 @@ void OutputDirectory::directoryChangedSlot( const QString& directory )
     }
 }*/
 
-/*void OutputDirectory::dirInfo()
-{
-    KMessageBox::information( this,
-        i18n("<p>The following strings are space holders, that will be replaced by the information in the metatags.</p><p>%a - Artist<br>%b - Album<br>%c - Comment<br>%d - Disc number<br>%g - Genre<br>%n - Track number<br>%p - Composer<br>%t - Title<br>%y - Year<br>%f - Original file name<p>"),
-        QString(i18n("Legend")) );
-}*/
-
