@@ -4,10 +4,11 @@
 
 #include "../../core/codecwidget.h"
 
-class KComboBox;
+class QLabel;
 class QSlider;
 class QSpinBox;
 class QCheckBox;
+class KComboBox;
 class KLineEdit;
 
 class FFmpegCodecWidget : public CodecWidget
@@ -22,18 +23,13 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
+    QLabel *lBitrate;
     QSlider *sBitrate;
     QSpinBox *iBitrate;
     KComboBox *cBitrate;
-    QCheckBox *chChannels;
-    KComboBox *cChannels;
-    QCheckBox *chSamplerate;
-    KComboBox *cSamplerate;
     QCheckBox *cCmdArguments;
     KLineEdit *lCmdArguments;
 
@@ -42,11 +38,6 @@ private:
 private slots:
     void qualitySliderChanged( int bitrate );
     void qualitySpinBoxChanged( int bitrate );
-    void channelsToggled( bool enabled );
-    void samplerateToggled( bool enabled );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // FFMPEGCODECWIDGET_H
\ No newline at end of file
