@@ -2,8 +2,9 @@
 #include "ffmpegcodecglobal.h"
 
 #include "soundkonverter_codec_ffmpeg.h"
-#include "../../core/conversionoptions.h"
 #include "ffmpegcodecwidget.h"
+#include "../../core/conversionoptions.h"
+#include "../../metadata/tagengine.h"
 
 #include <KMessageBox>
 #include <KDialog>
@@ -27,15 +28,19 @@ soundkonverter_codec_ffmpeg::soundkonverter_codec_ffmpeg( QObject *parent, const
     group = conf->group( "Plugin-"+name() );
     configVersion = group.readEntry( "configVersion", 0 );
     experimentalCodecsEnabled = group.readEntry( "experimentalCodecsEnabled", false );
+    ffmpegVersionMajor = group.readEntry( "ffmpegVersionMajor", 0 );
+    ffmpegVersionMinor = group.readEntry( "ffmpegVersionMinor", 0 );
     ffmpegLastModified = group.readEntry( "ffmpegLastModified", QDateTime() );
     ffmpegCodecList = group.readEntry( "codecList", QStringList() ).toSet();
 
     CodecData data;
     FFmpegCodecData ffmpegData;
 
+    // WARNING enabled codecs need to be rescanned everytime new codecs are added here -> increase plugin version
+
     data.ffmpegCodecList.clear();
     data.codecName = "wav";
-    ffmpegData.name = "pcm_s16le";
+    ffmpegData.name = "wav";
     ffmpegData.external = false;
     ffmpegData.experimental = false;
     data.ffmpegCodecList.append( ffmpegData );
@@ -53,12 +58,24 @@ soundkonverter_codec_ffmpeg::soundkonverter_codec_ffmpeg( QObject *parent, const
     data.ffmpegCodecList.append( ffmpegData );
     codecList.append( data );
 
+//     data.ffmpegCodecList.clear();
+//     data.codecName = "opus";
+//     ffmpegData.name = "opus";
+//     ffmpegData.external = true;
+//     ffmpegData.experimental = false;
+//     data.ffmpegCodecList.append( ffmpegData );
+//     codecList.append( data );
+
     data.ffmpegCodecList.clear();
     data.codecName = "mp3";
     ffmpegData.name = "libmp3lame";
     ffmpegData.external = true;
     ffmpegData.experimental = false;
     data.ffmpegCodecList.append( ffmpegData );
+    ffmpegData.name = "mp3";
+    ffmpegData.external = true;
+    ffmpegData.experimental = false;
+    data.ffmpegCodecList.append( ffmpegData );
     codecList.append( data );
 
     data.ffmpegCodecList.clear();
@@ -94,7 +111,7 @@ soundkonverter_codec_ffmpeg::soundkonverter_codec_ffmpeg( QObject *parent, const
     codecList.append( data );
 
     data.ffmpegCodecList.clear();
-    data.codecName = "m4a";
+    data.codecName = "m4a/aac";
     ffmpegData.name = "libfaac";
     ffmpegData.external = true;
     ffmpegData.experimental = false;
@@ -114,7 +131,7 @@ soundkonverter_codec_ffmpeg::soundkonverter_codec_ffmpeg( QObject *parent, const
     codecList.append( data );
 
     data.ffmpegCodecList.clear();
-    data.codecName = "alac";
+    data.codecName = "m4a/alac";
     ffmpegData.name = "alac";
     ffmpegData.external = false;
     ffmpegData.experimental = false;
@@ -135,6 +152,10 @@ soundkonverter_codec_ffmpeg::soundkonverter_codec_ffmpeg( QObject *parent, const
     ffmpegData.external = true;
     ffmpegData.experimental = false;
     data.ffmpegCodecList.append( ffmpegData );
+    ffmpegData.name = "amr_nb";
+    ffmpegData.external = true;
+    ffmpegData.experimental = false;
+    data.ffmpegCodecList.append( ffmpegData );
     codecList.append( data );
 
 //     codecMap["sonic"] = "sonic";
@@ -177,12 +198,13 @@ QList<ConversionPipeTrunk> soundkonverter_codec_ffmpeg::codecTable()
     /// decode
     fromCodecs += "wav";
     fromCodecs += "ogg vorbis";
+//     fromCodecs += "opus";
     fromCodecs += "mp3";
     fromCodecs += "flac";
     fromCodecs += "wma";
     fromCodecs += "aac";
     fromCodecs += "ac3";
-    fromCodecs += "alac";
+    fromCodecs += "m4a/alac";
     fromCodecs += "mp2";
 //     fromCodecs += "sonic";
 //     fromCodecs += "sonic lossless";
@@ -192,7 +214,7 @@ QList<ConversionPipeTrunk> soundkonverter_codec_ffmpeg::codecTable()
     fromCodecs += "ape";
 //     fromCodecs += "e-ac3";
     fromCodecs += "speex";
-    fromCodecs += "m4a";
+    fromCodecs += "m4a/aac";
     fromCodecs += "mp1";
     fromCodecs += "musepack";
     fromCodecs += "shorten";
@@ -283,9 +305,12 @@ QList<ConversionPipeTrunk> soundkonverter_codec_ffmpeg::codecTable()
                                 ffmpegProblemInfo.append( i18n("Compile ffmpeg with %1 support.",codecList.at(k).ffmpegCodecList.at(l).name) );
                             }
                         }
+                        break;
                     }
                 }
             }
+            if( fromCodecs.at(i) == "opus" && ffmpegVersionMajor < 1 )
+                codecEnabled = false;
 
             ConversionPipeTrunk newTrunk;
             newTrunk.codecFrom = fromCodecs.at(i);
@@ -392,7 +417,7 @@ void soundkonverter_codec_ffmpeg::showInfo( QWidget *parent )
     Q_UNUSED(parent)
 }
 
-QWidget *soundkonverter_codec_ffmpeg::newCodecWidget()
+CodecWidget *soundkonverter_codec_ffmpeg::newCodecWidget()
 {
     FFmpegCodecWidget *widget = new FFmpegCodecWidget();
     if( lastUsedConversionOptions )
@@ -401,10 +426,10 @@ QWidget *soundkonverter_codec_ffmpeg::newCodecWidget()
         delete lastUsedConversionOptions;
         lastUsedConversionOptions = 0;
     }
-    return qobject_cast<QWidget*>(widget);
+    return qobject_cast<CodecWidget*>(widget);
 }
 
-int soundkonverter_codec_ffmpeg::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
+unsigned int soundkonverter_codec_ffmpeg::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
 {
     Q_UNUSED(inputCodec)
     Q_UNUSED(tags)
@@ -432,19 +457,10 @@ int soundkonverter_codec_ffmpeg::convert( const KUrl& inputFile, const KUrl& out
                 break;
             }
         }
-        if( outputCodec != "alac" && outputCodec != "flac" )
+        if( outputCodec != "m4a/alac" && outputCodec != "flac" )
         {
             command += "-ab";
             command += QString::number(conversionOptions->bitrate) + "k";
-            if(  conversionOptions->samplingRate > 0 )
-            {
-                command += "-ar";
-                command += QString::number(conversionOptions->samplingRate);
-            }
-            if( conversionOptions->channels > 0 )
-            {
-                command += "-ac 1";
-            }
         }
         if( conversionOptions->pluginName == name() )
         {
@@ -467,11 +483,14 @@ int soundkonverter_codec_ffmpeg::convert( const KUrl& inputFile, const KUrl& out
     connect( newItem->process, SIGNAL(readyRead()), this, SLOT(processOutput()) );
     connect( newItem->process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(processExit(int,QProcess::ExitStatus)) );
 
+    if( tags )
+        newItem->data.length = tags->length;
+
     newItem->process->clearProgram();
     newItem->process->setShellCommand( command.join(" ") );
     newItem->process->start();
 
-    emit log( newItem->id, command.join(" ") );
+    logCommand( newItem->id, command.join(" ") );
 
     backendItems.append( newItem );
     return newItem->id;
@@ -500,10 +519,15 @@ float soundkonverter_codec_ffmpeg::parseOutput( const QString& output, int *leng
     {
         *length = regLength.cap(1).toInt()*3600 + regLength.cap(2).toInt()*60 + regLength.cap(3).toInt();
     }
-    QRegExp reg("time=(\\d{2}):(\\d{2}):(\\d{2})\\.(\\d{2})");
-    if( output.contains(reg) )
+    QRegExp reg1("time=(\\d{2}):(\\d{2}):(\\d{2})\\.(\\d{2})");
+    QRegExp reg2("time=(\\d+)\\.\\d");
+    if( output.contains(reg1) )
     {
-        return reg.cap(1).toInt()*3600 + reg.cap(2).toInt()*60 + reg.cap(3).toInt();;
+        return reg1.cap(1).toInt()*3600 + reg1.cap(2).toInt()*60 + reg1.cap(3).toInt();
+    }
+    else if( output.contains(reg2) )
+    {
+        return reg2.cap(1).toInt();
     }
 
     // TODO error handling
@@ -529,7 +553,7 @@ void soundkonverter_codec_ffmpeg::processOutput()
 
             float progress = parseOutput( output, &pluginItem->data.length );
             if( progress == -1 && !output.simplified().isEmpty() )
-                emit log( backendItems.at(i)->id, output );
+                logOutput( backendItems.at(i)->id, output );
 
             progress = progress * 100 / pluginItem->data.length;
             if( progress > backendItems.at(i)->progress )
@@ -550,6 +574,13 @@ void soundkonverter_codec_ffmpeg::infoProcessExit( int exitCode, QProcess::ExitS
     Q_UNUSED(exitStatus)
     Q_UNUSED(exitCode)
 
+    QRegExp regVersion("ffmpeg version (\\d+)\\.(\\d+) ");
+    if( infoProcessOutputData.contains( regVersion ) )
+    {
+        ffmpegVersionMajor = regVersion.cap(1).toInt();
+        ffmpegVersionMinor = regVersion.cap(2).toInt();
+    }
+
     ffmpegCodecList.clear();
 
     for( int i=0; i<codecList.count(); i++ )
@@ -571,6 +602,8 @@ void soundkonverter_codec_ffmpeg::infoProcessExit( int exitCode, QProcess::ExitS
 
     group = conf->group( "Plugin-"+name() );
     group.writeEntry( "configVersion", version() );
+    group.writeEntry( "ffmpegVersionMajor", ffmpegVersionMajor );
+    group.writeEntry( "ffmpegVersionMinor", ffmpegVersionMinor );
     group.writeEntry( "ffmpegLastModified", ffmpegLastModified );
     group.writeEntry( "codecList", ffmpegCodecList.toList() );
 
@@ -578,6 +611,5 @@ void soundkonverter_codec_ffmpeg::infoProcessExit( int exitCode, QProcess::ExitS
     infoProcess.data()->deleteLater();
 }
 
-
 #include "soundkonverter_codec_ffmpeg.moc"
 
