@@ -74,7 +74,7 @@ void soundkonverter_codec_flac::showInfo( QWidget *parent )
     Q_UNUSED(parent)
 }
 
-QWidget *soundkonverter_codec_flac::newCodecWidget()
+CodecWidget *soundkonverter_codec_flac::newCodecWidget()
 {
     FlacCodecWidget *widget = new FlacCodecWidget();
     if( lastUsedConversionOptions )
@@ -83,14 +83,14 @@ QWidget *soundkonverter_codec_flac::newCodecWidget()
         delete lastUsedConversionOptions;
         lastUsedConversionOptions = 0;
     }
-    return qobject_cast<QWidget*>(widget);
+    return qobject_cast<CodecWidget*>(widget);
 }
 
-int soundkonverter_codec_flac::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
+unsigned int soundkonverter_codec_flac::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
 {
     QStringList command = convertCommand( inputFile, outputFile, inputCodec, outputCodec, _conversionOptions, tags, replayGain );
     if( command.isEmpty() )
-        return -1;
+        return BackendPlugin::UnknownError;
 
     CodecPluginItem *newItem = new CodecPluginItem( this );
     newItem->id = lastId++;
@@ -103,7 +103,7 @@ int soundkonverter_codec_flac::convert( const KUrl& inputFile, const KUrl& outpu
     newItem->process->setShellCommand( command.join(" ") );
     newItem->process->start();
 
-    emit log( newItem->id, command.join(" ") );
+    logCommand( newItem->id, command.join(" ") );
 
     backendItems.append( newItem );
     return newItem->id;
@@ -113,7 +113,6 @@ QStringList soundkonverter_codec_flac::convertCommand( const KUrl& inputFile, co
 {
     Q_UNUSED(inputCodec)
     Q_UNUSED(tags)
-    Q_UNUSED(replayGain)
 
     if( !_conversionOptions )
         return QStringList();
@@ -132,7 +131,7 @@ QStringList soundkonverter_codec_flac::convertCommand( const KUrl& inputFile, co
         {
             command += "--compression-level-"+QString::number((int)conversionOptions->compressionLevel);
         }
-        if( conversionOptions->replaygain )
+        if( conversionOptions->replaygain && replayGain )
         {
             command += "--replay-gain";
         }
