@@ -16,15 +16,10 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
     QString currentFormat; // holds the current output file format
-
-signals:
-    void somethingChanged();
 };
 
 #endif // FLUIDSYNTHCODECWIDGET_H
