@@ -122,7 +122,7 @@ void soundkonverter_codec_fluidsynth::showInfo( QWidget *parent )
     Q_UNUSED(parent)
 }
 
-QWidget *soundkonverter_codec_fluidsynth::newCodecWidget()
+CodecWidget *soundkonverter_codec_fluidsynth::newCodecWidget()
 {
     FluidsynthCodecWidget *widget = new FluidsynthCodecWidget();
     if( lastUsedConversionOptions )
@@ -131,21 +131,21 @@ QWidget *soundkonverter_codec_fluidsynth::newCodecWidget()
         delete lastUsedConversionOptions;
         lastUsedConversionOptions = 0;
     }
-    return qobject_cast<QWidget*>(widget);
+    return qobject_cast<CodecWidget*>(widget);
 }
 
-int soundkonverter_codec_fluidsynth::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
+unsigned int soundkonverter_codec_fluidsynth::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
 {
     if( soundFontFile.isEmpty() )
     {
         emit log( 1000, i18n("FluidSynth is not configured, yet. You need to set a SoundFont file.") );
-        return -100;
+        return BackendPlugin::BackendNeedsConfiguration;
     }
 
     const QStringList command = convertCommand( inputFile, outputFile, inputCodec, outputCodec, _conversionOptions, tags, replayGain );
     if( command.isEmpty() )
     {
-        return -1;
+        return BackendPlugin::UnknownError;
     }
 
     CodecPluginItem *newItem = new CodecPluginItem( this );
@@ -159,7 +159,7 @@ int soundkonverter_codec_fluidsynth::convert( const KUrl& inputFile, const KUrl&
     newItem->process->setShellCommand( command.join(" ") );
     newItem->process->start();
 
-    emit log( newItem->id, command.join(" ") );
+    logCommand( newItem->id, command.join(" ") );
 
     backendItems.append( newItem );
     return newItem->id;
