@@ -20,7 +20,7 @@ public:
     soundkonverter_codec_fluidsynth( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_codec_fluidsynth();
+    ~soundkonverter_codec_fluidsynth();
 
     QString name();
 
@@ -29,9 +29,9 @@ public:
     void showConfigDialog( ActionType action, const QString& format, QWidget *parent );
     bool hasInfo();
     void showInfo( QWidget *parent );
-    QWidget *newCodecWidget();
+    CodecWidget *newCodecWidget();
 
-    int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
+    unsigned int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output );
 
