@@ -5,12 +5,12 @@
 #include "lameconversionoptions.h"
 
 #include <QLayout>
+#include <QBoxLayout>
 #include <QLabel>
 #include <QCheckBox>
 #include <KLocale>
 #include <KComboBox>
 #include <QSpinBox>
-// #include <QSlider>
 
 #include <KLineEdit>
 
@@ -28,7 +28,7 @@ LameCodecWidget::LameCodecWidget()
     QHBoxLayout *presetBox = new QHBoxLayout();
     grid->addLayout( presetBox, 0, 0 );
 
-    QLabel *lPreset = new QLabel( i18n("Preset")+":", this );
+    QLabel *lPreset = new QLabel( i18n("Preset:"), this );
     presetBox->addWidget( lPreset );
     cPreset = new KComboBox( this );
     cPreset->addItem( i18nc("Backend profile","Medium") );
@@ -38,7 +38,7 @@ LameCodecWidget::LameCodecWidget()
     cPreset->addItem( i18n("Specify bitrate") );
     cPreset->addItem( i18n("User defined") );
     connect( cPreset, SIGNAL(activated(const QString&)), this, SLOT(presetChanged(const QString&)) );
-    connect( cPreset, SIGNAL(activated(int)), SIGNAL(somethingChanged()) );
+    connect( cPreset, SIGNAL(activated(int)), SIGNAL(optionsChanged()) );
     presetBox->addWidget( cPreset );
 //     cPreset->setToolTip( i18n("Either use one of lames's presets or your own settings.") );
 
@@ -47,20 +47,20 @@ LameCodecWidget::LameCodecWidget()
     iPresetBitrate->setSuffix( " kbps" );
     iPresetBitrate->setValue( 192 );
     connect( iPresetBitrate, SIGNAL(valueChanged(int)), this, SLOT(presetBitrateChanged(int)) );
-    connect( iPresetBitrate, SIGNAL(valueChanged(int)), SIGNAL(somethingChanged()) );
+    connect( iPresetBitrate, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
     presetBox->addWidget( iPresetBitrate );
 
     cPresetBitrateCbr = new QCheckBox( i18n("cbr"), this );
-    connect( cPresetBitrateCbr, SIGNAL(toggled(bool)), SIGNAL(somethingChanged()) );
+    connect( cPresetBitrateCbr, SIGNAL(toggled(bool)), SIGNAL(optionsChanged()) );
     presetBox->addWidget( cPresetBitrateCbr );
     cPresetBitrateCbr->setToolTip( i18n("Encode using a constant bitrate.\nOnly works with 80, 96, 112, 128, 160, 192, 224, 256 and 320 kbps") );
 
     presetBox->addSpacing( 12 );
 
     cPresetFast = new QCheckBox( i18n("Fast encoding"), this );
-    connect( cPresetFast, SIGNAL(toggled(bool)), SIGNAL(somethingChanged()) );
+    connect( cPresetFast, SIGNAL(toggled(bool)), SIGNAL(optionsChanged()) );
     presetBox->addWidget( cPresetFast );
-    cPresetFast->setToolTip( i18n("Use a faster encoding alogrithm (results in a slightly lower output quality).") );
+    cPresetFast->setToolTip( i18n("Use a faster encoding algorithm (results in a slightly lower output quality).") );
 
     presetBox->addStretch();
 
@@ -77,23 +77,20 @@ LameCodecWidget::LameCodecWidget()
     QHBoxLayout *userdefinedTopBox = new QHBoxLayout();
     userdefinedBoxLayout->addLayout( userdefinedTopBox );
 
-    QLabel *lMode = new QLabel( i18n("Mode")+":", userdefinedBox );
+    QLabel *lMode = new QLabel( i18n("Mode:"), userdefinedBox );
     userdefinedTopBox->addWidget( lMode );
 
     cMode = new KComboBox( userdefinedBox );
     cMode->addItem( i18n("Quality") );
     cMode->addItem( i18n("Bitrate") );
     connect( cMode, SIGNAL(activated(int)), this, SLOT(modeChanged(int)) );
-    connect( cMode, SIGNAL(activated(int)), SIGNAL(somethingChanged()) );
+    connect( cMode, SIGNAL(activated(int)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( cMode );
 
     sQuality = new QSlider( Qt::Horizontal, userdefinedBox );
     sQuality->setRange( 8, 320 );
-//     sQuality->setTickInterval( 32 );
-//     sQuality->setTickPosition( QSlider::TicksBelow );
-//     sQuality->setFixedWidth( sQuality->sizeHint().width() );
     connect( sQuality, SIGNAL(valueChanged(int)), this, SLOT(qualitySliderChanged(int)) );
-    connect( sQuality, SIGNAL(valueChanged(int)), SIGNAL(somethingChanged()) );
+    connect( sQuality, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( sQuality );
 
     iQuality = new QSpinBox( userdefinedBox );
@@ -101,98 +98,63 @@ LameCodecWidget::LameCodecWidget()
     iQuality->setSuffix( " kbps" );
     iQuality->setFixedWidth( iQuality->sizeHint().width() );
     connect( iQuality, SIGNAL(valueChanged(int)), this, SLOT(qualitySpinBoxChanged(int)) );
-    connect( iQuality, SIGNAL(valueChanged(int)), SIGNAL(somethingChanged()) );
+    connect( iQuality, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( iQuality );
 
     userdefinedTopBox->addSpacing( 12 );
 
-    QLabel *lBitrateMode = new QLabel( i18n("Bitrate mode")+":", this );
+    QLabel *lBitrateMode = new QLabel( i18n("Bitrate mode:"), this );
     userdefinedTopBox->addWidget( lBitrateMode );
     cBitrateMode = new KComboBox( this );
     cBitrateMode->addItem( i18n("Variable") );
-    cBitrateMode->addItem( i18n("Avarage") );
+    cBitrateMode->addItem( i18n("Average") );
     cBitrateMode->addItem( i18n("Constant") );
     cBitrateMode->setFixedWidth( cBitrateMode->sizeHint().width() );
-    connect( cBitrateMode, SIGNAL(activated(int)), SIGNAL(somethingChanged()) );
+    connect( cBitrateMode, SIGNAL(activated(int)), SIGNAL(optionsChanged()) );
     userdefinedTopBox->addWidget( cBitrateMode );
 
-    /*
-    QLabel *lBitrateRange = new QLabel( i18n("Bitrate range")+":", userdefinedBox );
-    userdefinedTopBox->addWidget( lBitrateRange );
-    QSpinBox *iMinBitrate = new QSpinBox( userdefinedBox );
-    iMinBitrate->setRange( 8, 320 );
-//     iMinBitrate->setSuffix( " kbps" );
-//     iMinBitrate->setFixedHeight( cMode->minimumSizeHint().height() );
-    userdefinedTopBox->addWidget( iMinBitrate );
-    QLabel *lBitrateRangeTo = new QLabel( "-", userdefinedBox );
-    userdefinedTopBox->addWidget( lBitrateRangeTo );
-    QSpinBox *iMaxBitrate = new QSpinBox( userdefinedBox );
-    iMaxBitrate->setRange( 8, 320 );
-//     iMaxBitrate->setSuffix( " kbps" );
-//     iMaxBitrate->setFixedHeight( cMode->minimumSizeHint().height() );
-    userdefinedTopBox->addWidget( iMaxBitrate );
-    */
-
     userdefinedTopBox->addStretch();
 
-    // mid box ----------------------------------------
+    // bottom box
 
-    QHBoxLayout *userdefinedMidBox = new QHBoxLayout();
-    userdefinedBoxLayout->addLayout( userdefinedMidBox );
+    QHBoxLayout *bottomBox = new QHBoxLayout();
+    grid->addLayout( bottomBox, 2, 0 );
 
-    chChannels = new QCheckBox( i18n("Channels")+":", userdefinedBox );
-    connect( chChannels, SIGNAL(toggled(bool)), SIGNAL(somethingChanged()) );
-    userdefinedMidBox->addWidget( chChannels );
-    cChannels = new KComboBox( userdefinedBox );
-    cChannels->addItem( i18n("Mono") );
-    cChannels->addItem( i18n("Joint Stereo") );
-    cChannels->addItem( i18n("Simple Stereo") );
-    cChannels->addItem( i18n("Forced Joint Stereo") );
-    cChannels->addItem( i18n("Dual Mono") );
-    cChannels->setEnabled( false );
-    connect( cChannels, SIGNAL(activated(int)), SIGNAL(somethingChanged()) );
-    userdefinedMidBox->addWidget( cChannels );
-    connect( chChannels, SIGNAL(toggled(bool)), cChannels, SLOT(setEnabled(bool)) );
+    QLabel *lCompressionLevel = new QLabel( i18n("Compression level:"), this );
+    bottomBox->addWidget( lCompressionLevel );
 
-    userdefinedMidBox->addSpacing( 12 );
+    sCompressionLevel = new QSlider( Qt::Horizontal, this );
+    sCompressionLevel->setRange( 0, 9 );
+    sCompressionLevel->setSingleStep( 1 );
+    sCompressionLevel->setPageStep( 1 );
+    connect( sCompressionLevel, SIGNAL(valueChanged(int)), this, SLOT(compressionLevelSliderChanged(int)) );
+    connect( sCompressionLevel, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
+    bottomBox->addWidget( sCompressionLevel );
+    sCompressionLevel->setToolTip( i18n("Compression level from 9 to 0 where 0 is the highest quality.\n(The higher the quality, the slower the conversion and vice versa.)\nA value of 2 is recommended.") );
 
-    chSamplerate = new QCheckBox( i18n("Resample")+":", userdefinedBox );
-    connect( chSamplerate, SIGNAL(toggled(bool)), SIGNAL(somethingChanged()) );
-    userdefinedMidBox->addWidget( chSamplerate );
-    cSamplerate = new KComboBox( userdefinedBox );
-    cSamplerate->addItem( "8000 Hz" );
-    cSamplerate->addItem( "11025 Hz" );
-    cSamplerate->addItem( "12000 Hz" );
-    cSamplerate->addItem( "16000 Hz" );
-    cSamplerate->addItem( "22050 Hz" );
-    cSamplerate->addItem( "24000 Hz" );
-    cSamplerate->addItem( "32000 Hz" );
-    cSamplerate->addItem( "44100 Hz" );
-    cSamplerate->addItem( "48000 Hz" );
-    cSamplerate->setCurrentIndex( 4 );
-    cSamplerate->setEnabled( false );
-    connect( cSamplerate, SIGNAL(activated(int)), SIGNAL(somethingChanged()) );
-    userdefinedMidBox->addWidget( cSamplerate );
-    connect( chSamplerate, SIGNAL(toggled(bool)), cSamplerate, SLOT(setEnabled(bool)) );
+    iCompressionLevel = new QSpinBox( this );
+    iCompressionLevel->setRange( 0, 9 );
+    iCompressionLevel->setSingleStep( 1 );
+    iCompressionLevel->setFixedWidth( iCompressionLevel->sizeHint().width() );
+    connect( iCompressionLevel, SIGNAL(valueChanged(int)), this, SLOT(compressionLevelSpinBoxChanged(int)) );
+    connect( iCompressionLevel, SIGNAL(valueChanged(int)), SIGNAL(optionsChanged()) );
+    bottomBox->addWidget( iCompressionLevel );
+    iCompressionLevel->setToolTip( i18n("Compression level from 9 to 0 where 0 is the highest quality.\n(The higher the quality, the slower the conversion and vice versa.)\nA value of 2 is recommended.") );
 
-    userdefinedMidBox->addStretch();
+    bottomBox->addSpacing( 12 );
 
-    // cmd arguments box
-
-    QHBoxLayout *cmdArgumentsBox = new QHBoxLayout();
-    grid->addLayout( cmdArgumentsBox, 2, 0 );
-
-    cCmdArguments = new QCheckBox( i18n("Additional encoder arguments")+":", this );
-    cmdArgumentsBox->addWidget( cCmdArguments );
+    cCmdArguments = new QCheckBox( i18n("Additional encoder arguments:"), this );
+    bottomBox->addWidget( cCmdArguments );
     lCmdArguments = new KLineEdit( this );
     lCmdArguments->setEnabled( false );
-    cmdArgumentsBox->addWidget( lCmdArguments );
+    bottomBox->addWidget( lCmdArguments );
     connect( cCmdArguments, SIGNAL(toggled(bool)), lCmdArguments, SLOT(setEnabled(bool)) );
 
     grid->setRowStretch( 3, 1 );
 
     presetChanged( cPreset->currentText() );
     modeChanged( 0 );
+    iCompressionLevel->setValue( 2 );
 }
 
 LameCodecWidget::~LameCodecWidget()
@@ -222,32 +184,24 @@ ConversionOptions *LameCodecWidget::currentConversionOptions()
         options->qualityMode = ConversionOptions::Quality;
         options->quality = iQuality->value();
         options->bitrate = bitrateForQuality( options->quality );
-        options->bitrateMode = ConversionOptions::Vbr;
-        options->bitrateMin = 0;
-        options->bitrateMax = 0;
     }
     else
     {
         options->qualityMode = ConversionOptions::Bitrate;
         options->bitrate = iQuality->value();
         options->quality = qualityForBitrate( options->bitrate );
-        options->bitrateMode = ( cBitrateMode->currentText()==i18n("Avarage") ) ? ConversionOptions::Abr : ConversionOptions::Cbr;
-        options->bitrateMin = 0;
-        options->bitrateMax = 0;
+        options->bitrateMode = ( cBitrateMode->currentText()==i18n("Average") ) ? ConversionOptions::Abr : ConversionOptions::Cbr;
     }
-    if( chSamplerate->isChecked() ) options->samplingRate = cSamplerate->currentText().replace(" Hz","").toInt();
-    else options->samplingRate = 0;
-    if( chChannels->isChecked() ) options->channels = cChannels->currentIndex() + 1;
-    else options->channels = 0;
-    if( cCmdArguments->isChecked() ) options->cmdArguments = lCmdArguments->text();
-    else options->cmdArguments = "";
+    options->compressionLevel = iCompressionLevel->value();
+    options->cmdArguments = cCmdArguments->isChecked() ? lCmdArguments->text() : "";
 
     return options;
 }
 
 bool LameCodecWidget::setCurrentConversionOptions( ConversionOptions *_options )
 {
-    if( !_options || _options->pluginName != global_plugin_name ) return false;
+    if( !_options || _options->pluginName != global_plugin_name )
+        return false;
 
     LameConversionOptions *options = static_cast<LameConversionOptions*>(_options);
     cPreset->setCurrentIndex( (int)options->data.preset );
@@ -267,22 +221,26 @@ bool LameCodecWidget::setCurrentConversionOptions( ConversionOptions *_options )
         cMode->setCurrentIndex( cMode->findText(i18n("Bitrate")) );
         modeChanged( cMode->currentIndex() );
         iQuality->setValue( options->bitrate );
-        if( options->bitrateMode == ConversionOptions::Abr ) cBitrateMode->setCurrentIndex( cBitrateMode->findText(i18n("Avarage")) );
-        else cBitrateMode->setCurrentIndex( cBitrateMode->findText(i18n("Constant")) );
+        if( options->bitrateMode == ConversionOptions::Abr )
+            cBitrateMode->setCurrentIndex( cBitrateMode->findText(i18n("Average")) );
+        else
+            cBitrateMode->setCurrentIndex( cBitrateMode->findText(i18n("Constant")) );
     }
-    chSamplerate->setChecked( options->samplingRate != 0 );
-    if( options->samplingRate != 0 ) cSamplerate->setCurrentIndex( cSamplerate->findText(QString::number(options->samplingRate)+" Hz") );
-    chChannels->setChecked( options->channels != 0 );
-    if( options->channels != 0 ) cChannels->setCurrentIndex( options->channels - 1 );
+    iCompressionLevel->setValue( options->compressionLevel );
     cCmdArguments->setChecked( !options->cmdArguments.isEmpty() );
-    if( !options->cmdArguments.isEmpty() ) lCmdArguments->setText( options->cmdArguments );
+    if( !options->cmdArguments.isEmpty() )
+        lCmdArguments->setText( options->cmdArguments );
+    else
+        lCmdArguments->clear();
 
     return true;
 }
 
 void LameCodecWidget::setCurrentFormat( const QString& format )
 {
-    if( currentFormat == format ) return;
+    if( currentFormat == format )
+        return;
+
     currentFormat = format;
     setEnabled( currentFormat != "wav" );
 }
@@ -293,23 +251,23 @@ QString LameCodecWidget::currentProfile()
     {
         return i18n("Lossless");
     }
-    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 6 && chChannels->isChecked() && cChannels->currentIndex() == 0 && chSamplerate->isChecked() && cSamplerate->currentIndex() == 4 )
+    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 6 )
     {
         return i18n("Very low");
     }
-    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 5 && !chChannels->isChecked() && chSamplerate->isChecked() && cSamplerate->currentIndex() == 4 )
+    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 5 )
     {
         return i18n("Low");
     }
-    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 4 && !chChannels->isChecked() && !chSamplerate->isChecked() )
+    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 4 )
     {
         return i18n("Medium");
     }
-    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 3 && !chChannels->isChecked() && !chSamplerate->isChecked() )
+    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 3 )
     {
         return i18n("High");
     }
-    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 2 && !chChannels->isChecked() && !chSamplerate->isChecked() )
+    else if( cPreset->currentIndex() == 5 && cMode->currentIndex() == 0 && iQuality->value() == 2 )
     {
         return i18n("Very high");
     }
@@ -319,6 +277,9 @@ QString LameCodecWidget::currentProfile()
 
 bool LameCodecWidget::setCurrentProfile( const QString& profile )
 {
+    cCmdArguments->setChecked( false );
+    lCmdArguments->clear();
+
     if( profile == i18n("Very low") )
     {
         cPreset->setCurrentIndex( 5 );
@@ -328,11 +289,6 @@ bool LameCodecWidget::setCurrentProfile( const QString& profile )
         sQuality->setValue( 6 );
         iQuality->setValue( 6 );
         cBitrateMode->setCurrentIndex( 0 );
-        chChannels->setChecked( true );
-        cChannels->setCurrentIndex( 0 );
-        chSamplerate->setChecked( true );
-        cSamplerate->setCurrentIndex( 4 );
-        cCmdArguments->setChecked( false );
         return true;
     }
     else if( profile == i18n("Low") )
@@ -344,10 +300,6 @@ bool LameCodecWidget::setCurrentProfile( const QString& profile )
         sQuality->setValue( 5 );
         iQuality->setValue( 5 );
         cBitrateMode->setCurrentIndex( 0 );
-        chChannels->setChecked( false );
-        chSamplerate->setChecked( true );
-        cSamplerate->setCurrentIndex( 4 );
-        cCmdArguments->setChecked( false );
         return true;
     }
     else if( profile == i18n("Medium") )
@@ -359,9 +311,6 @@ bool LameCodecWidget::setCurrentProfile( const QString& profile )
         sQuality->setValue( 4 );
         iQuality->setValue( 4 );
         cBitrateMode->setCurrentIndex( 0 );
-        chChannels->setChecked( false );
-        chSamplerate->setChecked( false );
-        cCmdArguments->setChecked( false );
         return true;
     }
     else if( profile == i18n("High") )
@@ -373,9 +322,6 @@ bool LameCodecWidget::setCurrentProfile( const QString& profile )
         sQuality->setValue( 3 );
         iQuality->setValue( 3 );
         cBitrateMode->setCurrentIndex( 0 );
-        chChannels->setChecked( false );
-        chSamplerate->setChecked( false );
-        cCmdArguments->setChecked( false );
         return true;
     }
     else if( profile == i18n("Very high") )
@@ -387,69 +333,12 @@ bool LameCodecWidget::setCurrentProfile( const QString& profile )
         sQuality->setValue( 2 );
         iQuality->setValue( 2 );
         cBitrateMode->setCurrentIndex( 0 );
-        chChannels->setChecked( false );
-        chSamplerate->setChecked( false );
-        cCmdArguments->setChecked( false );
         return true;
     }
 
     return false;
 }
 
-QDomDocument LameCodecWidget::customProfile()
-{
-    QDomDocument profile("soundkonverter_profile");
-    QDomElement root = profile.createElement("soundkonverter");
-    root.setAttribute("type","profile");
-    root.setAttribute("codecName",currentFormat);
-    profile.appendChild(root);
-    QDomElement encodingOptions = profile.createElement("encodingOptions");
-    encodingOptions.setAttribute("qualityMode",cMode->currentIndex());
-    encodingOptions.setAttribute("quality",iQuality->value());
-    encodingOptions.setAttribute("bitrateMode",cBitrateMode->currentIndex());
-    encodingOptions.setAttribute("channelsEnabled",chChannels->isChecked() && chChannels->isEnabled());
-    encodingOptions.setAttribute("channels",cChannels->currentIndex());
-    encodingOptions.setAttribute("samplerateEnabled",chSamplerate->isChecked() && chSamplerate->isEnabled());
-    encodingOptions.setAttribute("samplerate",cSamplerate->currentIndex());
-    encodingOptions.setAttribute("cmdArgumentsEnabled",cCmdArguments->isChecked() && cCmdArguments->isEnabled());
-    encodingOptions.setAttribute("cmdArguments",lCmdArguments->text());
-    root.appendChild(encodingOptions);
-    QDomElement data = profile.createElement("data");
-    data.setAttribute("preset",cPreset->currentIndex());
-    data.setAttribute("presetBitrate",iPresetBitrate->value());
-    data.setAttribute("presetBitrateCbr",cPresetBitrateCbr->isChecked() && cPresetBitrateCbr->isEnabled());
-    data.setAttribute("presetFast",cPresetFast->isChecked() && cPresetFast->isEnabled());
-    encodingOptions.appendChild(data);
-    return profile;
-}
-
-bool LameCodecWidget::setCustomProfile( const QString& profile, const QDomDocument& document )
-{
-    Q_UNUSED(profile)
-
-    QDomElement root = document.documentElement();
-    QDomElement encodingOptions = root.elementsByTagName("encodingOptions").at(0).toElement();
-    QDomElement data = encodingOptions.elementsByTagName("data").at(0).toElement();
-    cPreset->setCurrentIndex( data.attribute("preset").toInt() );
-    presetChanged( cPreset->currentText() );
-    iPresetBitrate->setValue( data.attribute("presetBitrate").toInt() );
-    presetBitrateChanged( iPresetBitrate->value() );
-    cPresetBitrateCbr->setChecked( data.attribute("presetBitrateCbr").toInt() );
-    cPresetFast->setChecked( data.attribute("presetFast").toInt() );
-    cMode->setCurrentIndex( encodingOptions.attribute("qualityMode").toInt() );
-    modeChanged( cMode->currentIndex() );
-    sQuality->setValue( 9 - encodingOptions.attribute("quality").toInt() );
-    iQuality->setValue( encodingOptions.attribute("quality").toInt() );
-    cBitrateMode->setCurrentIndex( encodingOptions.attribute("bitrateMode").toInt() );
-    chChannels->setChecked( encodingOptions.attribute("channelsEnabled").toInt() );
-    cChannels->setCurrentIndex( encodingOptions.attribute("channels").toInt() );
-    chSamplerate->setChecked( encodingOptions.attribute("samplerateEnabled").toInt() );
-    cSamplerate->setCurrentIndex( encodingOptions.attribute("samplerate").toInt() );
-    cCmdArguments->setChecked( encodingOptions.attribute("cmdArgumentsEnabled").toInt() );
-    lCmdArguments->setText( encodingOptions.attribute("cmdArguments") );
-    return true;
-}
-
 int LameCodecWidget::currentDataRate()
 {
     int dataRate = 0;
@@ -490,21 +379,6 @@ int LameCodecWidget::currentDataRate()
             {
                 dataRate = iQuality->value()/8*60*1000;
             }
-            if( chChannels->isChecked() )
-            {
-                if( cChannels->currentIndex() == 0 )
-                {
-                    dataRate *= 0.9f;
-                }
-                else if( cChannels->currentIndex() == 4 )
-                {
-                    dataRate *= 1.5f;
-                }
-            }
-            if( chSamplerate->isChecked() && cSamplerate->currentText().replace(" Hz","").toInt() <= 22050 )
-            {
-                dataRate *= 0.9f;
-            }
         }
         if( cPresetFast->isEnabled() && cPresetFast->isChecked() )
         {
@@ -591,7 +465,8 @@ void LameCodecWidget::modeChanged( int mode )
         iQuality->setValue( 5 );
 //         dQuality->setValue( qualityForBitrate(dQuality->value()) );
 //         qualitySpinBoxChanged( dQuality->value() );
-        iQuality->setToolTip( i18n("Quality level from 9 to 0 where 0 is the highes quality.") );
+        sQuality->setToolTip( i18n("Quality level from 9 to 0 where 0 is the highest quality.\n(The higher the quality, the bigger the file size and vice versa.)") );
+        iQuality->setToolTip( i18n("Quality level from 9 to 0 where 0 is the highest quality.\n(The higher the quality, the bigger the file size and vice versa.)") );
 
         cBitrateMode->clear();
         cBitrateMode->addItem( i18n("Variable") );
@@ -612,7 +487,7 @@ void LameCodecWidget::modeChanged( int mode )
         iQuality->setToolTip( i18n("Bitrate") );
 
         cBitrateMode->clear();
-        cBitrateMode->addItem( i18n("Avarage") );
+        cBitrateMode->addItem( i18n("Average") );
         cBitrateMode->addItem( i18n("Constant") );
         cBitrateMode->setEnabled( true );
     }
@@ -642,4 +517,14 @@ void LameCodecWidget::qualitySpinBoxChanged( int quality )
     }
 }
 
+void LameCodecWidget::compressionLevelSliderChanged( int quality )
+{
+    iCompressionLevel->setValue( 9 - quality );
+}
+
+void LameCodecWidget::compressionLevelSpinBoxChanged( int quality )
+{
+    sCompressionLevel->setValue( 9 - quality );
+}
+
 
