@@ -4,9 +4,12 @@
 
 #include "../../core/codecplugin.h"
 
+#include <QWeakPointer>
 #include <KUrl>
 
 class ConversionOptions;
+class KDialog;
+class KComboBox;
 
 
 class soundkonverter_codec_lame : public CodecPlugin
@@ -17,7 +20,7 @@ public:
     soundkonverter_codec_lame( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_codec_lame();
+    ~soundkonverter_codec_lame();
 
     QString name();
 
@@ -27,13 +30,25 @@ public:
     void showConfigDialog( ActionType action, const QString& codecName, QWidget *parent );
     bool hasInfo();
     void showInfo( QWidget *parent );
-    QWidget *newCodecWidget();
+    CodecWidget *newCodecWidget();
 
-    int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
+    unsigned int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     QStringList convertCommand( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
     float parseOutput( const QString& output );
 
-    ConversionOptions *conversionOptionsFromXml( QDomElement conversionOptions );
+    ConversionOptions *conversionOptionsFromXml( QDomElement conversionOptions, QList<QDomElement> *filterOptionsElements = 0 );
+
+private:
+    QWeakPointer<KDialog> configDialog;
+    KComboBox *configDialogStereoModeComboBox;
+
+    int configVersion;
+    QString stereoMode;
+
+private slots:
+    void configDialogSave();
+    void configDialogDefault();
+
 };
 
 K_EXPORT_SOUNDKONVERTER_CODEC( lame, soundkonverter_codec_lame )
