@@ -23,8 +23,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
@@ -48,9 +46,6 @@ private slots:
     // user defined options
     void qualitySliderChanged( int quality );
     void qualitySpinBoxChanged( double quality );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // MUSEPACKCODECWIDGET_H
\ No newline at end of file
