@@ -75,7 +75,7 @@ void soundkonverter_codec_vorbistools::showInfo( QWidget *parent )
     Q_UNUSED(parent)
 }
 
-QWidget *soundkonverter_codec_vorbistools::newCodecWidget()
+CodecWidget *soundkonverter_codec_vorbistools::newCodecWidget()
 {
     VorbisToolsCodecWidget *widget = new VorbisToolsCodecWidget();
     if( lastUsedConversionOptions )
@@ -84,14 +84,14 @@ QWidget *soundkonverter_codec_vorbistools::newCodecWidget()
         delete lastUsedConversionOptions;
         lastUsedConversionOptions = 0;
     }
-    return qobject_cast<QWidget*>(widget);
+    return qobject_cast<CodecWidget*>(widget);
 }
 
-int soundkonverter_codec_vorbistools::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
+unsigned int soundkonverter_codec_vorbistools::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
 {
     QStringList command = convertCommand( inputFile, outputFile, inputCodec, outputCodec, _conversionOptions, tags, replayGain );
     if( command.isEmpty() )
-        return -1;
+        return BackendPlugin::UnknownError;
 
     CodecPluginItem *newItem = new CodecPluginItem( this );
     newItem->id = lastId++;
@@ -104,7 +104,7 @@ int soundkonverter_codec_vorbistools::convert( const KUrl& inputFile, const KUrl
     newItem->process->setShellCommand( command.join(" ") );
     newItem->process->start();
 
-    emit log( newItem->id, command.join(" ") );
+    logCommand( newItem->id, command.join(" ") );
 
     backendItems.append( newItem );
     return newItem->id;
@@ -125,10 +125,10 @@ QStringList soundkonverter_codec_vorbistools::convertCommand( const KUrl& inputF
     if( outputCodec == "ogg vorbis" )
     {
         command += binaries["oggenc"];
-        if( inputFile.isEmpty() )
-        {
-            command += "--raw";
-        }
+//         if( inputFile.isEmpty() )
+//         {
+//             command += "--raw";
+//         }
         if( conversionOptions->qualityMode == ConversionOptions::Quality )
         {
             command += "-q";
@@ -140,20 +140,6 @@ QStringList soundkonverter_codec_vorbistools::convertCommand( const KUrl& inputF
             {
                 command += "-b";
                 command += QString::number(conversionOptions->bitrate);
-                if( conversionOptions->bitrateMin > 0 || conversionOptions->bitrateMax > 0 )
-                {
-                    command += "--managed";
-                    if( conversionOptions->bitrateMin > 0 )
-                    {
-                        command += "-m";
-                        command += QString::number(conversionOptions->bitrateMin);
-                    }
-                    if( conversionOptions->bitrateMax > 0 )
-                    {
-                        command += "-M";
-                        command += QString::number(conversionOptions->bitrateMax);
-                    }
-                }
             }
             else if( conversionOptions->bitrateMode == ConversionOptions::Cbr )
             {
@@ -162,15 +148,6 @@ QStringList soundkonverter_codec_vorbistools::convertCommand( const KUrl& inputF
                 command += QString::number(conversionOptions->bitrate);
             }
         }
-        if( conversionOptions->samplingRate > 0 )
-        {
-            command += "--resample";
-            command += QString::number(conversionOptions->samplingRate);
-        }
-        if( conversionOptions->channels > 0 )
-        {
-            command += "--downmix";
-        }
         command += "\"" + escapeUrl(inputFile) + "\"";
         command += "-o";
         command += "\"" + escapeUrl(outputFile) + "\"";
@@ -194,7 +171,8 @@ float soundkonverter_codec_vorbistools::parseOutput( const QString& output )
 {
     //         [ 99.5%]
 
-    if( output == "" || !output.contains("%") || output.contains("error",Qt::CaseInsensitive) ) return -1;
+    if( output == "" || !output.contains("%") || output.contains("error",Qt::CaseInsensitive) )
+        return -1;
 
     QString data = output;
     data.remove( 0, data.indexOf("[")+1 );
