@@ -11,6 +11,18 @@
 class ConversionOptions;
 class KDialog;
 class QComboBox;
+class QCheckBox;
+
+
+class AacGainPluginItem : public ReplayGainPluginItem
+{
+    Q_OBJECT
+public:
+    AacGainPluginItem( QObject *parent=0 );
+    ~AacGainPluginItem();
+
+    KUrl::List undoFileList;
+};
 
 
 class soundkonverter_replaygain_aacgain : public ReplayGainPlugin
@@ -21,7 +33,7 @@ public:
     soundkonverter_replaygain_aacgain( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_replaygain_aacgain();
+    ~soundkonverter_replaygain_aacgain();
 
     QString name();
 
@@ -32,16 +44,16 @@ public:
     bool hasInfo();
     void showInfo( QWidget *parent );
 
-    int apply( const KUrl::List& fileList, ApplyMode mode = Add );
+    unsigned int apply( const KUrl::List& fileList, ApplyMode mode = Add );
     float parseOutput( const QString& output );
 
 private:
-    KUrl::List undoFileList;
-
     QWeakPointer<KDialog> configDialog;
-    QComboBox *configDialogTagLabelComboBox;
+    QComboBox *configDialogTagModeComboBox;
+    QCheckBox *configDialogModifyAudioStreamCheckBox;
 
     int tagMode;
+    bool modifyAudioStream;
 
 private slots:
     /** The undo process has exited */
