@@ -17,7 +17,7 @@ public:
     soundkonverter_ripper_cdparanoia( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_ripper_cdparanoia();
+    ~soundkonverter_ripper_cdparanoia();
 
     QString name();
 
@@ -28,7 +28,7 @@ public:
     bool hasInfo();
     void showInfo( QWidget *parent );
 
-    int rip( const QString& device, int track, int tracks, const KUrl& outputFile );
+    unsigned int rip( const QString& device, int track, int tracks, const KUrl& outputFile );
     QStringList ripCommand( const QString& device, int track, int tracks, const KUrl& outputFile );
     float parseOutput( const QString& output, int *fromSector, int *toSector );
     float parseOutput( const QString& output );
