@@ -7,7 +7,6 @@
 
 #include <KUrl>
 #include <QTime>
-#include <QTimer>
 
 class Config;
 class Logger;
@@ -41,13 +40,13 @@ public:
     ReplayGainFileList( Config *_config, Logger *_logger, QWidget *parent=0 );
 
     /** Destructor */
-    virtual ~ReplayGainFileList();
+    ~ReplayGainFileList();
 
     ReplayGainFileListItem *topLevelItem( int index ) const { return static_cast<ReplayGainFileListItem*>( QTreeWidget::topLevelItem(index) ); }
 
     void addFiles( const KUrl::List& fileList, const QString& _codecName = "" );
 
-    void calcAllReplayGain( bool force = false );
+    void startProcessing( ReplayGainPlugin::ApplyMode _mode );
     void removeAllReplayGain();
     void cancelProcess();
 
@@ -55,10 +54,10 @@ private:
     Config *config;
     Logger *logger;
 
-    QTimer updateTimer;
-
-    /** Lists all file in a directory and adds them to the file list, if fast is false. The number of listed files is returned */
-    int listDir( const QString& directory, const QStringList& filter, bool recursive, bool fast = false, int count = 0 );
+    /** Counts all files in a directory */
+    int countDir( const QString& directory, bool recursive, int count = 0 );
+    /** Lists all files in a directory and adds them to the file list */
+    int listDir( const QString& directory, const QStringList& filter, bool recursive, int count = 0 );
     /** A progressbar, that is shown, when a directory is added recursive */
     QProgressBar *pScanStatus;
     /** Update timer for the scan status */
@@ -70,50 +69,51 @@ private:
 
     void resizeEvent( QResizeEvent *event );
 
-//     bool processing;        // true, if the progress is active (hide some options in the context menu)
-
     bool queue;             // NOTE currently always true
-    bool killed;
     ReplayGainPlugin::ApplyMode mode;
-    ReplayGainPlugin *currentPlugin;
-    int currentId;
-    int currentTime;
-
-    int totalTime;
-    int processedTime;
-
-//     QList<ReplayGainFileListItem*> processedItems;
 
     QTreeWidgetItem *lastAlbumItem;
 
     QMenu *contextMenu;
     KAction *collapseAction;
     KAction *expandAction;
-//     KAction *startAction;
-//     KAction *stopAction;
+//     KAction *processAddAction;
+//     KAction *processRemoveAction;
+//     KAction *killAction;
+    KAction *moveAction;
     KAction *removeAction;
-//     KAction* paste;
-    KAction *newAction;
 
-    void processNextFile();
+    void processNextItem();
+    int waitingCount();
     int processingCount();
-    void processItems( const QList<ReplayGainFileListItem*>& itemList );
-    void updateItem( ReplayGainFileListItem *item );
+    void updateItem( ReplayGainFileListItem *item, bool initialUpdate = false );
 
 public slots:
     void addDir( const KUrl& directory, bool recursive, const QStringList& codecList );
 
 private slots:
-    void removeSelectedItems();
     void showContextMenu( const QPoint& point );
-    void pluginProcessFinished( int id, int exitCode );
-    void pluginLog( int id, const QString& message );
-    void updateProgress();
+//     void processAddSelectedItems();
+//     void processRemoveSelectedItems();
+//     void killSelectedItems();
+    void moveSelectedItems();
+    void removeSelectedItems();
+
+    // connected to ReplayGainProcessor
+    void itemFinished( ReplayGainFileListItem *item, ReplayGainFileListItem::ReturnCode returnCode );
 
 signals:
+    // connected to ProgressIndicator
+    void timeChanged( float timeDelta );
+    void finished( bool reset );
+
+    // connected to ReplayGainScanner
     void processStarted();
     void processStopped();
-    void updateProgress( int progress, int totalSteps );
+
+    // connected to ReplayGainProcessor
+    void processItem( ReplayGainFileListItem *item, ReplayGainPlugin::ApplyMode mode );
+    void killItem( ReplayGainFileListItem *item );
 };
 
 #endif // REPLAYGAINFILELIST_H
