@@ -2,20 +2,20 @@
 #ifndef REPLAYGAINFILELISTITEM_H
 #define REPLAYGAINFILELISTITEM_H
 
+#include "core/replaygainplugin.h"
+#include "metadata/tagengine.h"
+
 #include <QTreeWidget>
 #include <QItemDelegate>
 #include <QPointer>
 #include <KUrl>
 
-#include "metadata/tagengine.h"
-
 
 class ReplayGainFileListItem : public QTreeWidgetItem
 {
 public:
     ReplayGainFileListItem( QTreeWidget *parent );
     ReplayGainFileListItem( QTreeWidget *parent, QTreeWidgetItem *preceding );
-
     ReplayGainFileListItem( QTreeWidgetItem *parent );
 
     ~ReplayGainFileListItem();
@@ -28,26 +28,26 @@ public:
     enum State {
         Waiting,
         Processing,
-        Processed,
-        Failed
+        Stopped
     } state;
 
+    // code values will be displayed in the log files
+    enum ReturnCode {
+        Succeeded                       = 0,
+        SucceededWithProblems           = 1,
+        StoppedByUser                   = 2,
+        Skipped                         = 3,
+        BackendNeedsConfiguration       = 4,
+        Failed                          = 5
+    } returnCode;
+
     KUrl url;
     QString albumName;
     QString codecName;
     int samplingRate;
-    QPointer<TagData> tags;
-
-    int time;
-
-    int processId;
-    int take;
-
-// private:
-//     void dragEnterEvent( QDragEnterEvent *event );
-//     void dragMoveEvent( QDragMoveEvent *event );
-//     void dropEvent( QDropEvent *event );
+    TagData *tags;
 
+    int length;
 };
 
 class ReplayGainFileListItemDelegate : public QItemDelegate
