@@ -2,22 +2,9 @@
 #include "soundkonverterapp.h"
 #include "soundkonverter.h"
 
-// #include <qstringlist.h>
-// #include <qfile.h>
-// #include <qmovie.h>
-
-#include <kglobal.h>
-// #include <kstartupinfo.h>
-#include <kcmdlineargs.h>
-// #include <dcopclient.h>
-// #include <ksystemtray.h>
-// #include <kstandarddirs.h>
-#include <stdio.h>
-#include <KMessageBox>
+#include <KCmdLineArgs>
 #include <KStandardDirs>
-
-#include <kurl.h>
-
+#include <KUrl>
 #include <QFile>
 
 
@@ -25,7 +12,6 @@ soundKonverterApp::soundKonverterApp()
     : KUniqueApplication()
 {
     mainWindow = new soundKonverter();
-//     mainWindow->show();
     setActiveWindow( mainWindow );
 }
 
@@ -34,22 +20,21 @@ soundKonverterApp::~soundKonverterApp()
 
 int soundKonverterApp::newInstance()
 {
-    //KCmdLineArgs::setCwd(QDir::currentPath().toUtf8());
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    static bool first = true;
     bool visible = true;
     bool autoclose = false;
     bool autostart = false;
     bool activateMainWindow = true;
 
-    const QString device = args->getOption( "rip" );
-    if( !device.isEmpty() )
-    {
-        mainWindow->ripCd( device );
-    }
-
     autoclose = args->isSet( "autoclose" );
     autostart = args->isSet( "autostart" );
 
+    const QString profile = args->getOption( "profile" );
+    const QString format = args->getOption( "format" );
+    const QString directory = args->getOption( "output" );
+    const QString notifyCommand = args->getOption( "command" );
+
     if( args->isSet( "invisible" ) )
     {
         autoclose = true;
@@ -58,21 +43,35 @@ int soundKonverterApp::newInstance()
         mainWindow->showSystemTray();
     }
 
-    if( visible )
-        mainWindow->show();
-
-    mainWindow->setAutoClose( autoclose );
-
-    if( QFile::exists(KStandardDirs::locateLocal("data","soundkonverter/filelist_autosave.xml")) )
+    if( first && QFile::exists(KStandardDirs::locateLocal("data","soundkonverter/filelist_autosave.xml")) )
     {
+        if( !visible )
+        {
+            visible = true;
+            autoclose = false;
+            autostart = false;
+            mainWindow->show();
+        }
+        mainWindow->show();
         kapp->processEvents();
         mainWindow->loadAutosaveFileList();
     }
 
-    const QString profile = args->getOption( "profile" );
-    const QString format = args->getOption( "format" );
-    const QString directory = args->getOption( "output" );
-    const QString notifyCommand = args->getOption( "command" );
+    const QString device = args->getOption( "rip" );
+    if( !device.isEmpty() )
+    {
+        const bool success = mainWindow->ripCd( device, profile, format, directory, notifyCommand );
+        if( !success && first )
+        {
+            kapp->quit();
+            return 0;
+        }
+    }
+
+    if( visible )
+        mainWindow->show();
+
+    mainWindow->setAutoClose( autoclose );
 
     if( args->isSet( "replaygain" ) )
     {
@@ -97,6 +96,7 @@ int soundKonverterApp::newInstance()
         if( !urls.isEmpty() )
             mainWindow->addConvertFiles( urls, profile, format, directory, notifyCommand );
     }
+    first = false;
     args->clear();
 
     if( activateMainWindow )
@@ -106,37 +106,5 @@ int soundKonverterApp::newInstance()
         mainWindow->startConversion();
 
     return 0;
-
-
-
-/*
-        // no session.. just start up normally
-        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-
-        if( !mainWidget() )
-        {
-            soundKonverter *widget = new soundKonverter();
-            setMainWidget(widget);
-            //widget->show();
-        }
-        else
-            KStartupInfo::setNewStartupId( mainWidget(), kapp->startupId());
-
-        soundKonverter *widget = ::qt_cast<soundKonverter*>( mainWidget() );
-
-        widget->increaseInstances();
-
-        QCString device = args->getOption( "rip" );
-        if( device ) {
-            if( !args->isSet( "invisible" ) ) {
-                widget->visible = true;
-                widget->show();
-                widget->systemTray->hide();
-                widget->systemTray->setPixmap( 0 );
-            }
-            widget->device = device;
-            widget->showCdDialog( false );
-        }
-*/
 }
 
