@@ -10,6 +10,7 @@
 #include "progressindicator.h"
 #include "optionslayer.h"
 #include "config.h"
+#include "logger.h"
 #include "opener/fileopener.h"
 #include "opener/diropener.h"
 #include "opener/cdopener.h"
@@ -26,6 +27,7 @@
 #include <KMenu>
 #include <KAction>
 #include <KActionMenu>
+#include <KMessageBox>
 
 #include <QLabel>
 #include <QLayout>
@@ -33,8 +35,7 @@
 #include <QFont>
 #include <QTreeView>
 #include <QToolButton>
-// #include <QMessageBox>
-#include <KMessageBox>
+
 
 soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDManager *_cdManager, QWidget *parent )
     : QWidget( parent ),
@@ -42,21 +43,19 @@ soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDMana
       logger( _logger ),
       cdManager( _cdManager )
 {
-//     resize( 600, 400 );
     setAcceptDrops( true );
 
     // the grid for all widgets in the main window
     QGridLayout* gridLayout = new QGridLayout( this );
-    gridLayout->setContentsMargins( 6, 6, 6, 6 );
-//     gridLayout->setSpacing( 0 );
 
     fileList = new FileList( logger, config, this );
     gridLayout->addWidget( fileList, 1, 0 );
     gridLayout->setRowStretch( 1, 1 );
     connect( fileList, SIGNAL(fileCountChanged(int)), this, SLOT(fileCountChanged(int)) );
     connect( fileList, SIGNAL(conversionStarted()), this, SLOT(conversionStarted()) );
-    connect( fileList, SIGNAL(conversionStopped(int)), this, SLOT(conversionStopped(int)) );
+    connect( fileList, SIGNAL(conversionStopped(bool)), this, SLOT(conversionStopped(bool)) );
     connect( fileList, SIGNAL(queueModeChanged(bool)), this, SLOT(queueModeChanged(bool)) );
+    connect( fileList, SIGNAL(showLog(int)), this, SIGNAL(showLog(int)) );
 
     optionsLayer = new OptionsLayer( config, this );
     fileList->setOptionsLayer( optionsLayer );
@@ -67,9 +66,8 @@ soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDMana
 
 
     // add a horizontal box layout for the add combobutton to the grid
-    QHBoxLayout *addBox = new QHBoxLayout( 0 ); // TODO destroy
-    addBox->setContentsMargins( 0, 0, 0, 0 );
-//     addBox->setSpacing( 0 );
+    QHBoxLayout *addBox = new QHBoxLayout();
+    addBox->setContentsMargins( 1, 2, 1, 0 ); // determined by experiments
     gridLayout->addLayout( addBox, 3, 0 );
 
     // create the combobutton for adding files to the file list
@@ -84,7 +82,7 @@ soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDMana
     cAdd->insertItem( KIcon("network-workgroup"), i18n("Add url...") );
     cAdd->insertItem( KIcon("view-media-playlist"), i18n("Add playlist...") );
     cAdd->increaseHeight( 6 );
-    addBox->addWidget( cAdd );
+    addBox->addWidget( cAdd, 0, Qt::AlignVCenter );
     connect( cAdd, SIGNAL(clicked(int)), this, SLOT(addClicked(int)) );
     cAdd->setFocus();
 
@@ -97,11 +95,12 @@ soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDMana
     pStart->setFixedHeight( pStart->size().height() );
     pStart->setEnabled( false );
     startAction->setEnabled( false );
-    addBox->addWidget( pStart );
+    addBox->addWidget( pStart, 0, Qt::AlignVCenter );
     connect( pStart, SIGNAL(clicked()), fileList, SLOT(startConversion()) );
 
     stopActionMenu = new KActionMenu( KIcon("process-stop"), i18n("Stop"), this );
-    killAction = new KAction( KIcon("flag-red"), i18n("Stop imediatelly"), this );
+    stopActionMenu->setDelayed( false );
+    killAction = new KAction( KIcon("flag-red"), i18n("Stop immediatelly"), this );
     stopActionMenu->addAction( killAction );
     connect( killAction, SIGNAL(triggered()), fileList, SLOT(killConversion()) );
     stopAction = new KAction( KIcon("flag-yellow"), i18n("Stop after current conversions are completed"), this );
@@ -117,17 +116,25 @@ soundKonverterView::soundKonverterView( Logger *_logger, Config *_config, CDMana
     pStop->hide();
     stopActionMenu->setEnabled( false );
     pStop->setMenu( stopActionMenu->menu() );
-    addBox->addWidget( pStop );
+    addBox->addWidget( pStop, 0, Qt::AlignVCenter );
 
     addBox->addSpacing( 10 );
 
-    progressIndicator = new ProgressIndicator( /*systemTrayIcon,*/ this );
-    addBox->addWidget( progressIndicator );
+    progressIndicator = new ProgressIndicator( this, ProgressIndicator::Feature( ProgressIndicator::FeatureSpeed | ProgressIndicator::FeatureTime ) );
+    addBox->addWidget( progressIndicator, 0, Qt::AlignVCenter );
     connect( progressIndicator, SIGNAL(progressChanged(const QString&)), this, SIGNAL(progressChanged(const QString&)) );
     connect( fileList, SIGNAL(timeChanged(float)), progressIndicator, SLOT(timeChanged(float)) );
-    connect( fileList, SIGNAL(finished(float)), progressIndicator, SLOT(finished(float)) );
+    connect( fileList, SIGNAL(finished(bool)), progressIndicator, SLOT(finished(bool)) );
+
+    Convert *convert = new Convert( config, fileList, logger, this );
+    connect( fileList, SIGNAL(convertItem(FileListItem*)), convert, SLOT(add(FileListItem*)) );
+    connect( fileList, SIGNAL(killItem(FileListItem*)), convert, SLOT(kill(FileListItem*)) );
+    connect( fileList, SIGNAL(itemRemoved(FileListItem*)), convert, SLOT(itemRemoved(FileListItem*)) );
+    connect( convert, SIGNAL(finished(FileListItem*,FileListItem::ReturnCode,bool)), fileList, SLOT(itemFinished(FileListItem*,FileListItem::ReturnCode,bool)) );
+    connect( convert, SIGNAL(rippingFinished(const QString&)), fileList, SLOT(rippingFinished(const QString&)) );
+
+    connect( convert, SIGNAL(finishedProcess(int,bool,bool)), logger, SLOT(processCompleted(int,bool,bool)) );
 
-    Convert *convert = new Convert( config, fileList, logger );
     connect( convert, SIGNAL(updateTime(float)), progressIndicator, SLOT(update(float)) );
     connect( convert, SIGNAL(timeFinished(float)), progressIndicator, SLOT(timeFinished(float)) );
 }
@@ -164,90 +171,46 @@ void soundKonverterView::showFileDialog()
     FileOpener *dialog = new FileOpener( config, this );
 //     dialog->resize( size().width() - 10, size().height() );
 
-    connect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), fileList, SLOT(addFiles(const KUrl::List&,ConversionOptions*)) );
+    if( !dialog->dialogAborted )
+    {
+        connect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), fileList, SLOT(addFiles(const KUrl::List&,ConversionOptions*)) );
 
-    dialog->exec();
+        dialog->exec();
 
-    disconnect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), 0, 0 );
+        disconnect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), 0, 0 );
+
+        fileList->save( false );
+    }
 
     delete dialog;
-
-    fileList->save( false );
 }
 
 void soundKonverterView::showDirDialog()
 {
     DirOpener *dialog = new DirOpener( config, DirOpener::Convert, this );
 
-    connect( dialog, SIGNAL(open(const KUrl&,bool,const QStringList&,ConversionOptions*)), fileList, SLOT(addDir(const KUrl&,bool,const QStringList&,ConversionOptions*)) );
-
-    dialog->exec();
-
-    disconnect( dialog, SIGNAL(open(const KUrl&,bool,const QStringList&,ConversionOptions*)), 0, 0 );
-
-    delete dialog;
-
-    fileList->save( false );
-}
-
-void soundKonverterView::showCdDialog( const QString& device, bool intern )
-{
-    Q_UNUSED(intern)
-
-    /*
-    ConversionOptions conversionOptions = options->getCurrentOptions();
-
-    if( ( instances <= 1 || config->data.general.askForNewOptions ) && ( profile == "" || format == "" || directory == "" ) && !intern )
+    if( !dialog->dialogAborted )
     {
-        OptionsRequester* dialog = new OptionsRequester( config, "", this );
-
-        connect( dialog, SIGNAL(setCurrentOptions(const ConversionOptions&)),
-                 options, SLOT(setCurrentOptions(const ConversionOptions&))
-               );
-//         connect( dialog, SIGNAL(addFiles(QStringList)),
-//                    fileList, SLOT(addFiles(QStringList))
-//                  );
-
-        Q_CHECK_PTR( dialog );
-
-        if( profile != "" ) {
-            dialog->setProfile( profile );
-            profile = "";
-        }
-        if( format != "" ) {
-            dialog->setFormat( format );
-            format = "";
-        }
-        if( directory != "" ) {
-            dialog->setOutputDirectory( directory );
-            directory = "";
-        }
+        connect( dialog, SIGNAL(open(const KUrl&,bool,const QStringList&,ConversionOptions*)), fileList, SLOT(addDir(const KUrl&,bool,const QStringList&,ConversionOptions*)) );
 
         dialog->exec();
 
-        disconnect( dialog, SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
-//         disconnect( dialog, SIGNAL(addFiles(QStringList)), 0, 0 );
+        disconnect( dialog, SIGNAL(open(const KUrl&,bool,const QStringList&,ConversionOptions*)), 0, 0 );
 
-        delete dialog;
-    }
-    else
-    {
-        if( profile != "" ) {
-            options->setProfile( profile );
-            profile = "";
-        }
-        if( format != "" ) {
-            options->setFormat( format );
-            format = "";
-        }
-        if( directory != "" ) {
-            options->setOutputDirectory( directory );
-            directory = "";
-        }
+        fileList->save( false );
     }
 
-    kapp->eventLoop()->exitLoop();
-*/
+    delete dialog;
+}
+
+bool soundKonverterView::showCdDialog( const QString& device, QString _profile, QString _format, const QString& directory, const QString& notifyCommand )
+{
+    QString profile = _profile;
+    QString format = _format;
+
+    cleanupParameters( &profile, &format );
+
+    bool success = false;
 
     QString message;
     QStringList errorList;
@@ -260,7 +223,7 @@ void soundKonverterView::showCdDialog( const QString& device, bool intern )
         problemList += problem;
         CodecProblems *problemsDialog = new CodecProblems( CodecProblems::AudioCd, problemList, this );
         problemsDialog->exec();
-        return;
+        return false;
     }
 
     // create a new CDOpener object for letting the user add some tracks from a CD
@@ -268,26 +231,38 @@ void soundKonverterView::showCdDialog( const QString& device, bool intern )
 
     if( !dialog->noCdFound )
     {
-        connect( dialog, SIGNAL(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*)), fileList, SLOT(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*)) );
+        if( !profile.isEmpty() )
+            dialog->setProfile( profile );
+
+        if( !format.isEmpty() )
+            dialog->setFormat( format );
+
+        if( !directory.isEmpty() )
+            dialog->setOutputDirectory( directory );
+
+        if( !notifyCommand.isEmpty() )
+            dialog->setCommand( notifyCommand );
+
+        connect( dialog, SIGNAL(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*,const QString&)), fileList, SLOT(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*,const QString&)) );
 
         dialog->exec();
 
-        disconnect( dialog, SIGNAL(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*)), 0, 0 );
+        disconnect( dialog, SIGNAL(addTracks(const QString&,QList<int>,int,QList<TagData*>,ConversionOptions*,const QString&)), 0, 0 );
+
+        if( dialog->result() == QDialog::Accepted )
+        {
+            success = true;
+            fileList->save( false );
+        }
     }
     else
     {
-//         KMessageBox::information( this, i18n("No audio CD found.") );
         KMessageBox::error( this, i18n("No CD device found") );
     }
 
     delete dialog;
-/*
-    kapp->eventLoop()->enterLoop();
 
-    options->setCurrentOptions( conversionOptions );
-*/
-
-    fileList->save( false );
+    return success;
 }
 
 void soundKonverterView::showUrlDialog()
@@ -310,15 +285,18 @@ void soundKonverterView::showPlaylistDialog()
     PlaylistOpener *dialog = new PlaylistOpener( config, this );
 //     dialog->resize( size().width() - 10, size().height() );
 
-    connect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), fileList, SLOT(addFiles(const KUrl::List&,ConversionOptions*)) );
+    if( !dialog->dialogAborted )
+    {
+        connect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), fileList, SLOT(addFiles(const KUrl::List&,ConversionOptions*)) );
 
-    dialog->exec();
+        dialog->exec();
 
-    disconnect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), 0, 0 );
+        disconnect( dialog, SIGNAL(open(const KUrl::List&,ConversionOptions*)), 0, 0 );
+
+        fileList->save( false );
+    }
 
     delete dialog;
-
-    fileList->save( false );
 }
 
 void soundKonverterView::addConvertFiles( const KUrl::List& urls, QString _profile, QString _format, const QString& directory, const QString& notifyCommand )
@@ -329,9 +307,14 @@ void soundKonverterView::addConvertFiles( const KUrl::List& urls, QString _profi
     QMap< QString, QList<QStringList> > problems;
     QString fileName;
 
+    const bool canDecodeAac = config->pluginLoader()->canDecode( "m4a/aac" );
+    const bool canDecodeAlac = config->pluginLoader()->canDecode( "m4a/alac" );
+    const bool checkM4a = ( !canDecodeAac || !canDecodeAlac ) && canDecodeAac != canDecodeAlac;
+
     for( int i=0; i<urls.size(); i++ )
     {
-        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i) );
+        QString mimeType;
+        QString codecName = config->pluginLoader()->getCodecFromFile( urls.at(i), &mimeType, checkM4a );
 
         if( codecName == "inode/directory" || config->pluginLoader()->canDecode(codecName,&errorList) )
         {
@@ -340,7 +323,12 @@ void soundKonverterView::addConvertFiles( const KUrl::List& urls, QString _profi
         else
         {
             fileName = urls.at(i).pathOrUrl();
-            if( codecName.isEmpty() ) codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
+            if( codecName.isEmpty() )
+                codecName = mimeType;
+            if( codecName.isEmpty() )
+                codecName = fileName.right(fileName.length()-fileName.lastIndexOf(".")-1);
+
             if( problems.value(codecName).count() < 2 )
             {
                 problems[codecName] += QStringList();
@@ -405,78 +393,10 @@ void soundKonverterView::addConvertFiles( const KUrl::List& urls, QString _profi
 
     if( k_urls.count() > 0 )
     {
-        QString profile;
-        QString format;
-        QStringList formatList = config->pluginLoader()->formatList( PluginLoader::Encode, PluginLoader::CompressionType(PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
-        for( int i=0; i<formatList.count(); i++ )
-        {
-            if( _format == formatList.at(i) || config->pluginLoader()->codecExtensions(formatList.at(i)).contains(_format) )
-            {
-                format = formatList.at(i);
-                break;
-            }
-        }
-        bool lossy = false;
-        if( _profile.toLower() == i18n("Very low").toLower() || _profile.toLower() == "very low" || _profile.toLower() == "very_low" )
-        {
-            profile = i18n("Very low");
-            lossy = true;
-        }
-        else if( _profile.toLower() == i18n("Low").toLower() || _profile.toLower() == "low" )
-        {
-            profile = i18n("Low");
-            lossy = true;
-        }
-        else if( _profile.toLower() == i18n("Medium").toLower() || _profile.toLower() == "medium" )
-        {
-            profile = i18n("Medium");
-            lossy = true;
-        }
-        else if( _profile.toLower() == i18n("High").toLower() || _profile.toLower() == "high" )
-        {
-            profile = i18n("High");
-            lossy = true;
-        }
-        else if( _profile.toLower() == i18n("Very high").toLower() || _profile.toLower() == "very high" || _profile.toLower() == "very_high" )
-        {
-            profile = i18n("Very high");
-            lossy = true;
-        }
-        else if( _profile.toLower() == i18n("Lossless").toLower() || _profile.toLower() == "lossless" )
-        {
-            profile = i18n("Lossless");
-            format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::Lossless).contains(format) ? format : "";
-        }
-        else if( _profile.toLower() == i18n("Hybrid").toLower() || _profile.toLower() == "hybrid" )
-        {
-            profile = i18n("Hybrid");
-            format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::Hybrid).contains(format) ? format : "";
-        }
-        else
-        {
-            for( int i=0; i<config->data.profiles.count(); i++ )
-            {
-                if( config->data.profiles.at(i).profileName == _profile )
-                {
-                    profile = _profile;
-                    format = config->data.profiles.at(i).codecName;
-                }
-            }
-        }
+        QString profile = _profile;
+        QString format = _format;
 
-        if( lossy )
-        {
-            format = "";
-            QStringList formatList = config->pluginLoader()->formatList( PluginLoader::Encode, PluginLoader::Lossy );
-            for( int i=0; i<formatList.count(); i++ )
-            {
-                if( _format == formatList.at(i) || config->pluginLoader()->codecExtensions(formatList.at(i)).contains(_format) )
-                {
-                    format = formatList.at(i);
-                    break;
-                }
-            }
-        }
+        cleanupParameters( &profile, &format );
 
         if( !profile.isEmpty() && !format.isEmpty() && !directory.isEmpty() )
         {
@@ -501,10 +421,19 @@ void soundKonverterView::addConvertFiles( const KUrl::List& urls, QString _profi
         else
         {
             optionsLayer->addUrls( k_urls );
-            if( !profile.isEmpty() ) optionsLayer->setProfile( profile );
-            if( !format.isEmpty() ) optionsLayer->setFormat( format );
-            if( !directory.isEmpty() ) optionsLayer->setOutputDirectory( directory );
-            if( !notifyCommand.isEmpty() ) optionsLayer->setCommand( notifyCommand );
+
+            if( !profile.isEmpty() )
+                optionsLayer->setProfile( profile );
+
+            if( !format.isEmpty() )
+                optionsLayer->setFormat( format );
+
+            if( !directory.isEmpty() )
+                optionsLayer->setOutputDirectory( directory );
+
+            if( !notifyCommand.isEmpty() )
+                optionsLayer->setCommand( notifyCommand );
+
             optionsLayer->fadeIn();
         }
     }
@@ -542,13 +471,13 @@ void soundKonverterView::conversionStarted()
     emit signalConversionStarted();
 }
 
-void soundKonverterView::conversionStopped( int state )
+void soundKonverterView::conversionStopped( bool failed )
 {
     pStart->show();
     startAction->setEnabled( true );
     pStop->hide();
     stopActionMenu->setEnabled( false );
-    emit signalConversionStopped( state );
+    emit signalConversionStopped( failed );
 }
 
 void soundKonverterView::queueModeChanged( bool enabled )
@@ -572,4 +501,77 @@ void soundKonverterView::updateFileList()
     fileList->updateAllItems();
 }
 
+void soundKonverterView::cleanupParameters( QString *profile, QString *format )
+{
+    QString old_profile = *profile;
+    QString old_format = *format;
+
+    QString new_profile;
+    QString new_format;
+
+    const QStringList formatList = config->pluginLoader()->formatList( PluginLoader::Encode, PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy|PluginLoader::Lossless|PluginLoader::Hybrid) );
+    if( formatList.contains(old_format) )
+    {
+        new_format = old_format;
+    }
+    else
+    {
+        foreach( const QString format, formatList )
+        {
+            if( config->pluginLoader()->codecExtensions(format).contains(old_format) )
+            {
+                new_format = format;
+                break;
+            }
+        }
+    }
+
+    if( old_profile.toLower() == i18n("Very low").toLower() || old_profile.toLower() == "very low" || old_profile.toLower() == "very_low" )
+    {
+        new_profile = i18n("Very low");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy)).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("Low").toLower() || old_profile.toLower() == "low" )
+    {
+        new_profile = i18n("Low");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy)).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("Medium").toLower() || old_profile.toLower() == "medium" )
+    {
+        new_profile = i18n("Medium");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy)).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("High").toLower() || old_profile.toLower() == "high" )
+    {
+        new_profile = i18n("High");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy)).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("Very high").toLower() || old_profile.toLower() == "very high" || old_profile.toLower() == "very_high" )
+    {
+        new_profile = i18n("Very high");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::CompressionType(PluginLoader::InferiorQuality|PluginLoader::Lossy)).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("Lossless").toLower() || old_profile.toLower() == "lossless" )
+    {
+        new_profile = i18n("Lossless");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::Lossless).contains(new_format) ? new_format : "";
+    }
+    else if( old_profile.toLower() == i18n("Hybrid").toLower() || old_profile.toLower() == "hybrid" )
+    {
+        new_profile = i18n("Hybrid");
+        new_format = config->pluginLoader()->formatList(PluginLoader::Encode,PluginLoader::Hybrid).contains(new_format) ? new_format : "";
+    }
+    else if( config->data.profiles.contains(old_profile) )
+    {
+        new_profile = old_profile;
+        ConversionOptions *conversionOptions = config->data.profiles.value( new_profile );
+        if( conversionOptions )
+            new_format += conversionOptions->codecName;
+    }
+
+    *profile = new_profile;
+    *format = new_format;
+}
+
+
 #include "soundkonverterview.moc"
