@@ -44,7 +44,7 @@ public:
     soundKonverterView( Logger *_logger, Config *_config, CDManager *_cdManager, QWidget *parent );
 
     /** Destructor */
-    virtual ~soundKonverterView();
+    ~soundKonverterView();
 
     void addConvertFiles( const KUrl::List& urls, QString _profile, QString _format, const QString& directory, const QString& notifyCommand = "" );
     void loadAutosaveFileList();
@@ -63,7 +63,7 @@ signals:
 //     void signalChangeCaption( const QString& text );
 
 public slots:
-    void showCdDialog( const QString& device = "", bool intern = true );
+    bool showCdDialog( const QString& device = "", QString _profile = "", QString _format = "", const QString& directory = "", const QString& notifyCommand = "" );
     void loadFileList( bool user = true );
     void saveFileList( bool user = true );
     void updateFileList();
@@ -81,7 +81,7 @@ private slots:
     /** The conversion has started */
     void conversionStarted();
     /** The conversion has stopped */
-    void conversionStopped( int state );
+    void conversionStopped( bool failed );
     /** Conversion will continue/stop after current files have been converted */
     void queueModeChanged( bool enabled );
 
@@ -112,10 +112,13 @@ private:
     /** Displays the current progress */
     ProgressIndicator *progressIndicator;
 
+    void cleanupParameters( QString *profile, QString *format );
+
 signals:
     void progressChanged( const QString& progress );
     void signalConversionStarted();
-    void signalConversionStopped( int state );
+    void signalConversionStopped( bool failed );
+    void showLog( const int logId );
 };
 
 #endif // _soundKonverterVIEW_H_
